@@ -29,7 +29,7 @@
 #define LOG_DOMAIN "g_control"
 
 #include <gui_gtk/aboutwindow.h>
-
+#include <gui_gtk/gtkutils.h>
 
 #if GTK_MINOR_VERSION >= 4
 #define GTK_2_4
@@ -49,12 +49,12 @@
 #define TYPE_VOLUME     16
 #define TYPE_TONE       17
 
-static bg_gtk_about_window_t * about_window = (bg_gtk_about_window_t*)0;
+static bg_gtk_about_window_t * about_window = NULL;
 
 static void about_window_close_callback(bg_gtk_about_window_t * w,
                                         void * data)
   {
-  about_window = (bg_gtk_about_window_t*)0;
+  about_window = NULL;
   }
 
 static GtkWidget * create_pixmap_toggle_button(const char * filename)
@@ -457,8 +457,6 @@ static void init_array(widget_array_t * ret, alsa_mixer_control_t * c,
         gtk_widget_set_size_request(ret->widgets[i].w, req_width, SLIDER_HEIGHT);
                 
         gtk_range_set_inverted(GTK_RANGE(ret->widgets[i].w), TRUE);
-        gtk_range_set_update_policy(GTK_RANGE(ret->widgets[i].w),
-                                    GTK_UPDATE_CONTINUOUS);
         
         ret->widgets[i].id = g_signal_connect(G_OBJECT(ret->widgets[i].w),
                                               "value_changed",
@@ -493,8 +491,6 @@ static void init_array(widget_array_t * ret, alsa_mixer_control_t * c,
         gtk_widget_set_size_request(ret->widgets[i].w, req_width, SLIDER_HEIGHT);
         
         gtk_range_set_inverted(GTK_RANGE(ret->widgets[i].w), TRUE);
-        gtk_range_set_update_policy(GTK_RANGE(ret->widgets[i].w),
-                                    GTK_UPDATE_CONTINUOUS);
         
         ret->widgets[i].id = g_signal_connect(G_OBJECT(ret->widgets[i].w),
                                               "value_changed",
@@ -529,14 +525,14 @@ static void init_array(widget_array_t * ret, alsa_mixer_control_t * c,
       for(i = 0; i < ret->num; i++)
         {
 #ifdef GTK_2_4
-        ret->widgets[i].w = gtk_combo_box_new_text();
+        ret->widgets[i].w = bg_gtk_combo_box_new_text();
         ret->widgets[i].handler_widget = ret->widgets[i].w;
         
         for(j = 0; j < num_items; j++)
           {
           snd_ctl_elem_info_set_item(info,j);
           snd_hctl_elem_info(hctl,info);
-          gtk_combo_box_append_text(GTK_COMBO_BOX(ret->widgets[i].w),
+          bg_gtk_combo_box_append_text(ret->widgets[i].w,
                                     snd_ctl_elem_info_get_item_name(info));
           }
         ret->widgets[i].id =
@@ -702,7 +698,7 @@ static void menu_callback(GtkWidget * w, gpointer data)
                                               VERSION,
                                               "mixer_icon.png",
                                               about_window_close_callback,
-                                              (void*)0);
+                                              NULL);
     }
   else if(w == wid->menu.help)
     bg_display_html_help("userguide/Alsamixer.html");
@@ -1290,10 +1286,7 @@ static gboolean button_press_callback(GtkWidget * w, GdkEventButton * evt,
     else
       gtk_widget_set_sensitive(wid->menu.about, 1);
     gtk_menu_popup(GTK_MENU(wid->menu.menu),
-                   (GtkWidget *)0,
-                   (GtkWidget *)0,
-                   (GtkMenuPositionFunc)0,
-                   (gpointer)0,
+                   NULL, NULL, NULL, NULL,
                    3, evt->time);
     return TRUE;
     }
@@ -1321,7 +1314,7 @@ control_widget_t * control_widget_create(alsa_mixer_group_t * c,
   {
   snd_ctl_elem_info_t * info;
   
-  control_widget_t * ret = (control_widget_t *)0;
+  control_widget_t * ret = NULL;
   snd_ctl_elem_type_t type;
 
   /* Check for volume controls */
