@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -140,8 +140,8 @@ static gboolean delete_callback(GtkWidget * wid, GdkEventAny * evt,
   section =
     bg_cfg_registry_find_section(w->cfg_reg, "General");
 
-  gtk_window_get_position(GTK_WINDOW(w->main_win), &(w->x), &(w->y));
-  gtk_window_get_size(GTK_WINDOW(w->main_win), &(w->width), &(w->height));
+  gtk_window_get_position(GTK_WINDOW(w->main_win), &w->x, &w->y);
+  gtk_window_get_size(GTK_WINDOW(w->main_win), &w->width, &w->height);
   bg_cfg_section_get(section, parameters, get_parameter, w);
 
   for(i = 0; i < w->num_cards; i++)
