@@ -56,19 +56,19 @@ bg_player_t * player;
 bg_plugin_registry_t * plugin_reg;
 bg_cfg_registry_t * cfg_reg;
 
-bg_plugin_handle_t * input_handle = (bg_plugin_handle_t*)0;
+bg_plugin_handle_t * input_handle = NULL;
 int display_time = 1;
 
-bg_plugin_handle_t * oa_handle = (bg_plugin_handle_t*)0;
-bg_plugin_handle_t * ov_handle = (bg_plugin_handle_t*)0;
+bg_plugin_handle_t * oa_handle = NULL;
+bg_plugin_handle_t * ov_handle = NULL;
 
-char ** gmls = (char **)0;
+char ** gmls = NULL;
 int gml_index = 0;
 
 /* Sections from the plugin registry */
-bg_cfg_section_t * oa_section = (bg_cfg_section_t*)0;
-bg_cfg_section_t * ov_section = (bg_cfg_section_t*)0;
-bg_cfg_section_t * i_section = (bg_cfg_section_t*)0;
+bg_cfg_section_t * oa_section = NULL;
+bg_cfg_section_t * ov_section = NULL;
+bg_cfg_section_t * i_section = NULL;
 
 /* Sections from the player */
 bg_cfg_section_t * audio_section;
@@ -76,10 +76,10 @@ bg_cfg_section_t * video_section;
 bg_cfg_section_t * osd_section;
 bg_cfg_section_t * input_section;
 
-char * input_plugin_name = (char*)0;
+char * input_plugin_name = NULL;
 
-const bg_plugin_info_t * ov_info = (const bg_plugin_info_t*)0;
-char * window_id = (char*)0;
+const bg_plugin_info_t * ov_info = NULL;
+char * window_id = NULL;
 
 /* Set up by registry */
 static bg_parameter_info_t oa_parameters[] =
@@ -129,7 +129,7 @@ const bg_parameter_info_t * video_parameters;
 const bg_parameter_info_t * input_parameters;
 
 
-char * track_spec = (char*)0;
+char * track_spec = NULL;
 char * track_spec_ptr;
 
 /*
@@ -167,7 +167,7 @@ static void opt_oa(void * data, int * argc, char *** _argv, int arg)
   
   if(!bg_cmdline_apply_options(oa_section,
                                set_oa_parameter,
-                               (void*)0,
+                               NULL,
                                oa_parameters,
                                (*_argv)[arg]))
     exit(-1);
@@ -212,7 +212,7 @@ static void opt_ov(void * data, int * argc, char *** _argv, int arg)
     }
   if(!bg_cmdline_apply_options(ov_section,
                                set_ov_parameter,
-                               (void*)0,
+                               NULL,
                                ov_parameters,
                                (*_argv)[arg]))
     exit(-1);
@@ -236,7 +236,7 @@ static void opt_i(void * data, int * argc, char *** _argv, int arg)
   
   if(!bg_cmdline_apply_options(i_section,
                                set_i_parameter,
-                               (void*)0,
+                               NULL,
                                i_parameters,
                                (*_argv)[arg]))
     exit(-1);
@@ -334,7 +334,7 @@ static void opt_vol(void * data, int * argc, char *** _argv, int arg)
     fprintf(stderr, "Option -vol requires an argument\n");
     exit(-1);
     }
-  bg_player_set_volume(player, strtod((*_argv[arg]), (char**)0));
+  bg_player_set_volume(player, strtod((*_argv[arg]), NULL));
   bg_cmdline_remove_arg(argc, _argv, arg);
   }
 
@@ -376,7 +376,6 @@ static void opt_v(void * data, int * argc, char *** _argv, int arg)
 
 // static void opt_help(void * data, int * argc, char *** argv, int arg);
 
-
 static bg_cmdline_arg_t global_options[] =
   {
     {
@@ -513,7 +512,7 @@ static int set_track_from_spec()
 static int play_track(bg_player_t * player, const char * gml,
                       const char * plugin_name)
   {
-  const bg_plugin_info_t * info = (const bg_plugin_info_t *)0;
+  const bg_plugin_info_t * info = NULL;
   bg_input_plugin_t * plugin;
   bg_track_info_t * track_info;
 
@@ -535,11 +534,11 @@ static int play_track(bg_player_t * player, const char * gml,
     if(input_handle)
       {
       bg_plugin_unref(input_handle);
-      input_handle = (bg_plugin_handle_t*)0;
+      input_handle = NULL;
       }
     if(!bg_input_plugin_load(plugin_reg, gml, info,
                              &input_handle,
-                             (bg_input_callbacks_t*)0, 0))
+                             NULL, 0))
       {
       bg_log(BG_LOG_ERROR, LOG_DOMAIN, "Cannot open %s", gml);
       return 0;
@@ -595,15 +594,15 @@ static int play_track(bg_player_t * player, const char * gml,
     
   if(track_info->url)
     {
-    redir_url    = bg_strdup((char*)0, track_info->url);
-    redir_plugin = bg_strdup((char*)0, input_handle->info->name);
+    redir_url    = bg_strdup(NULL, track_info->url);
+    redir_plugin = bg_strdup(NULL, input_handle->info->name);
 
     bg_log(BG_LOG_DEBUG, LOG_DOMAIN, "Got redirector %s (%d/%d)",
             redir_url, current_track+1, num_tracks);
 
     
     bg_plugin_unref(input_handle);
-    input_handle = (bg_plugin_handle_t*)0;
+    input_handle = NULL;
     
     result = play_track(player, redir_url, redir_plugin);
     free(redir_url);
@@ -657,21 +656,6 @@ static void print_time(gavl_time_t time)
   time_active = 1;
   }
 
-#define DO_PRINT(f, s) if(s)bg_log(BG_LOG_INFO, LOG_DOMAIN, f, s);
-
-static void dump_metadata(bg_metadata_t * m)
-  {
-  DO_PRINT("Artist:    %s", m->artist);
-  DO_PRINT("Author:    %s", m->author);
-  DO_PRINT("Title:     %s", m->title);
-  DO_PRINT("Album:     %s", m->album);
-  DO_PRINT("Genre:     %s", m->genre);
-  DO_PRINT("Copyright: %s", m->copyright);
-  DO_PRINT("Date:      %s", m->date);
-  DO_PRINT("Track:     %d", m->track);
-  DO_PRINT("Comment:   %s", m->comment);
-  }
-#undef DO_PRINT
 
 static int handle_message(bg_player_t * player,
                           bg_msg_t * message)
@@ -681,7 +665,7 @@ static int handle_message(bg_player_t * player,
   gavl_time_t t;
   gavl_audio_format_t audio_format;
   gavl_video_format_t video_format;
-  bg_metadata_t metadata;
+  gavl_metadata_t metadata;
 
   char * tmp_string_1;
   char * tmp_string_2;
@@ -701,6 +685,7 @@ static int handle_message(bg_player_t * player,
         {
         if(time_active) { putc('\n', stderr); time_active = 0; }
         bg_log(BG_LOG_INFO, LOG_DOMAIN, "Name: %s", arg_str1);
+        free(arg_str1);
         }
       break;
     case BG_PLAYER_MSG_TRACK_NUM_STREAMS:
@@ -749,32 +734,37 @@ static int handle_message(bg_player_t * player,
       free(tmp_string_1);
       free(tmp_string_2);
       break;
-    case BG_PLAYER_MSG_STREAM_DESCRIPTION:
-      arg_str1 = bg_msg_get_arg_string(message, 0);
-      bg_log(BG_LOG_INFO, LOG_DOMAIN, "Format: %s", arg_str1);
+    case BG_PLAYER_MSG_AUDIO_STREAM_INFO:
+      gavl_metadata_init(&metadata);
+      bg_msg_get_arg_metadata(message, 1, &metadata);
+      fprintf(stderr, "Audio stream\n");
+      gavl_metadata_dump(&metadata, 2);
+      gavl_metadata_free(&metadata);
       break;
-    case BG_PLAYER_MSG_AUDIO_DESCRIPTION:
-      arg_str1 = bg_msg_get_arg_string(message, 0);
-      bg_log(BG_LOG_INFO, LOG_DOMAIN, "Audio stream: %s", arg_str1);
+    case BG_PLAYER_MSG_VIDEO_STREAM_INFO:
+      gavl_metadata_init(&metadata);
+      bg_msg_get_arg_metadata(message, 1, &metadata);
+      fprintf(stderr, "Video stream\n");
+      gavl_metadata_dump(&metadata, 2);
+      gavl_metadata_free(&metadata);
       break;
-    case BG_PLAYER_MSG_VIDEO_DESCRIPTION:
-      arg_str1 = bg_msg_get_arg_string(message, 0);
-      bg_log(BG_LOG_INFO, LOG_DOMAIN, "Video stream: %s", arg_str1);
+    case BG_PLAYER_MSG_SUBTITLE_STREAM_INFO:
+      gavl_metadata_init(&metadata);
+      bg_msg_get_arg_metadata(message, 1, &metadata);
+      fprintf(stderr, "Subtitle stream\n");
+      gavl_metadata_dump(&metadata, 2);
+      gavl_metadata_free(&metadata);
       break;
-    case BG_PLAYER_MSG_SUBTITLE_DESCRIPTION:
-      arg_str1 = bg_msg_get_arg_string(message, 0);
-      bg_log(BG_LOG_INFO, LOG_DOMAIN, "Subtitle stream: %s", arg_str1);
-      free(arg_str1);
-      break;
-      /* Metadata */
     case BG_PLAYER_MSG_CLEANUP:
       bg_log(BG_LOG_DEBUG, LOG_DOMAIN, "Player cleaned up");
       break;
     case BG_PLAYER_MSG_METADATA:
-      memset(&metadata, 0, sizeof(metadata));
+      /* Metadata */
+      gavl_metadata_init(&metadata);
       bg_msg_get_arg_metadata(message, 0, &metadata);
-      dump_metadata(&metadata);
-      bg_metadata_free(&metadata);
+      fprintf(stderr, "Metadata:\n");
+      gavl_metadata_dump(&metadata, 2);
+      gavl_metadata_free(&metadata);
       break;
     case BG_PLAYER_MSG_STATE_CHANGED:
       arg_i1 = bg_msg_get_arg_int(message, 0);
@@ -908,7 +898,6 @@ int main(int argc, char ** argv)
 
   update_global_options();
   
-
 #ifdef INFO_WINDOW
   info_window =
     bg_gtk_info_window_create(player, info_close_callback, NULL);
@@ -1036,6 +1025,14 @@ int main(int argc, char ** argv)
 
   bg_msg_queue_destroy(message_queue);
 
+  if(oa_handle)
+    bg_plugin_unref(oa_handle);
+  if(ov_handle)
+    bg_plugin_unref(ov_handle);
+
+  if(input_handle)
+    bg_plugin_unref(input_handle);
+  
   tmp_path =  bg_search_file_read("generic", "config.xml");
   bg_cfg_registry_load(cfg_reg, tmp_path);
   if(tmp_path)
