@@ -23,8 +23,11 @@
 #include <string.h>
 
 #include <gmerlin/translation.h>
+
 #include "gmerlin.h"
 #include <gmerlin/utils.h>
+#include <gmerlin/subprocess.h>
+
 #include <gdk/gdkkeysyms.h>
 
 #include <gui_gtk/aboutwindow.h>
@@ -261,7 +264,7 @@ plugin_menu_set_plugin(plugin_menu_t * s, int index)
   if(s->plugin_handle)
     {
     bg_plugin_unref(s->plugin_handle);
-    s->plugin_handle = (bg_plugin_handle_t*)0;
+    s->plugin_handle = NULL;
     }
   if(s->plugin_info->parameters)
     gtk_widget_set_sensitive(s->options, 1);
@@ -295,7 +298,7 @@ plugin_menu_set_plugin(plugin_menu_t * s, int index)
           bg_plugin_registry_load_image(s->g->plugin_reg,
                                         icon_path,
                                         &icon_format,
-                                        (bg_metadata_t*)0);
+                                        NULL);
         }
       plugin->set_window_options(s->plugin_handle->priv,
                                  WINDOW_NAME, WINDOW_CLASS,
@@ -410,7 +413,7 @@ static void menu_callback(GtkWidget * w, gpointer data)
     }
   else if(w == the_menu->options_menu.kbd)
     {
-    system("gmerlin_kbd_config &");
+    bg_system("gmerlin_kbd_config &");
     }
   else if(w == the_menu->windows_menu.infowindow)
     {
@@ -466,15 +469,15 @@ static void menu_callback(GtkWidget * w, gpointer data)
     }
   else if(w == the_menu->accessories_menu.visualizer)
     {
-    system("gmerlin_visualizer &");
+    bg_system("gmerlin_visualizer &");
     }
   else if(w == the_menu->accessories_menu.mixer)
     {
-    system("gmerlin_alsamixer &");
+    bg_system("gmerlin_alsamixer &");
     }
   else if(w == the_menu->accessories_menu.transcoder)
     {
-    system("gmerlin_transcoder_remote -launch");
+    bg_system("gmerlin_transcoder_remote -launch");
     }
   /* Commands (== accelerators) */
   else if(w == the_menu->command_menu.inc_volume)
@@ -677,7 +680,7 @@ static void plugin_menu_init(plugin_menu_t * m, gmerlin_t * gmerlin,
   const bg_plugin_info_t * info;
   
   GtkWidget * w;
-  GSList * group = (GSList*)0;
+  GSList * group = NULL;
 
   m->type = plugin_type;
   m->flags = flags;
@@ -745,7 +748,7 @@ static void stream_menu_init(stream_menu_t * s, gmerlin_t * gmerlin,
   {
   GtkWidget * separator;
   s->menu = create_menu();
-  s->off_item = gtk_radio_menu_item_new_with_label((GSList*)0, TR("Off"));
+  s->off_item = gtk_radio_menu_item_new_with_label(NULL, TR("Off"));
   
   s->off_id = g_signal_connect(G_OBJECT(s->off_item), "activate",
                                G_CALLBACK(menu_callback),
@@ -793,7 +796,7 @@ static void visualization_menu_init(visualization_menu_t * s, gmerlin_t * gmerli
   s->enable =
     create_toggle_item(TR("Enable visualizations"),
                        gmerlin,
-                       s->menu, (guint *)0);
+                       s->menu, NULL);
   gtk_widget_show(s->enable);
 
   s->options = create_pixmap_item(TR("Options..."), "config_16.png",
@@ -920,18 +923,6 @@ void main_menu_set_num_chapters(main_menu_t * m,
   chapter_menu_set_num(m->g, &m->chapter_menu, num, timescale);
   }
 
-void main_menu_set_audio_info(main_menu_t * m, int stream,
-                              const char * info,
-                              const char * language)
-  {
-  char * label;
-  GtkWidget * w;
-  
-  label = bg_get_stream_label(stream, info, language);
-  w = m->audio_stream_menu.stream_items[stream];
-  gtk_label_set_text(GTK_LABEL(gtk_bin_get_child(GTK_BIN(w))), label);
-  free(label);
-  }
 
 void main_menu_set_chapter_info(main_menu_t * m, int chapter,
                                 const char * name,
@@ -968,24 +959,24 @@ void main_menu_chapter_changed(main_menu_t * m, int chapter)
   }
 
 
-
-
-void main_menu_set_video_info(main_menu_t * m, int stream,
-                              const char * info,
-                              const char * language)
+void main_menu_set_audio_info(main_menu_t * m, int stream,
+                              const gavl_metadata_t * metadata)
   {
   char * label;
   GtkWidget * w;
-  if(info && language && *language)
-    label = bg_sprintf("%s [%s]", info, bg_get_language_name(language));
-  else if(info)
-    label = bg_sprintf("%s", info);
-  else if(language && *language)
-    label = bg_sprintf(TR("Stream %d [%s]"), stream+1,
-                       bg_get_language_name(language));
-  else
-    label = bg_sprintf(TR("Stream %d"), stream+1);
-  
+  label = bg_get_stream_label(stream, metadata);
+  w = m->audio_stream_menu.stream_items[stream];
+  gtk_label_set_text(GTK_LABEL(gtk_bin_get_child(GTK_BIN(w))), label);
+  free(label);
+  }
+
+
+void main_menu_set_video_info(main_menu_t * m, int stream,
+                              const gavl_metadata_t * metadata)
+  {
+  char * label;
+  GtkWidget * w;
+  label = bg_get_stream_label(stream, metadata);
   w = m->video_stream_menu.stream_items[stream];
   gtk_label_set_text(GTK_LABEL(gtk_bin_get_child(GTK_BIN(w))), label);
 
@@ -994,21 +985,11 @@ void main_menu_set_video_info(main_menu_t * m, int stream,
   }
 
 void main_menu_set_subtitle_info(main_menu_t * m, int stream,
-                                 const char * info,
-                                 const char * language)
+                                 const gavl_metadata_t * metadata)
   {
   char * label;
   GtkWidget * w;
-  if(info && language && *language)
-    label = bg_sprintf("%s [%s]", info, bg_get_language_name(language));
-  else if(info)
-    label = bg_sprintf("%s", info);
-  else if(language && *language)
-    label = bg_sprintf(TR("Stream %d [%s]"), stream+1,
-                       bg_get_language_name(language));
-  else
-    label = bg_sprintf(TR("Stream %d"), stream+1);
-  
+  label = bg_get_stream_label(stream, metadata);
   w = m->subtitle_stream_menu.stream_items[stream];
   gtk_label_set_text(GTK_LABEL(gtk_bin_get_child(GTK_BIN(w))), label);
   free(label);
@@ -1166,15 +1147,15 @@ main_menu_t * main_menu_create(gmerlin_t * gmerlin)
 
   ret->accessories_menu.menu = create_menu();
 
-  if(bg_search_file_exec("gmerlin_transcoder", (char**)0))
+  if(bg_search_file_exec("gmerlin_transcoder", NULL))
     ret->accessories_menu.transcoder =
       create_item(TR("Transcoder"), gmerlin, ret->accessories_menu.menu);
 
-  if(bg_search_file_exec("gmerlin_visualizer", (char**)0))
+  if(bg_search_file_exec("gmerlin_visualizer", NULL))
     ret->accessories_menu.visualizer =
       create_item(TR("Visualizer"), gmerlin, ret->accessories_menu.menu);
 
-  if(bg_search_file_exec("gmerlin_alsamixer", (char**)0))
+  if(bg_search_file_exec("gmerlin_alsamixer", NULL))
     ret->accessories_menu.mixer =
       create_item(TR("Mixer"), gmerlin, ret->accessories_menu.menu);
 
