@@ -373,7 +373,6 @@ static void handle_message(player_window_t * win,
   int arg_i_3;
   float arg_f_1;
   char * arg_str_1;
-  char * arg_str_2;
   gavl_time_t time;
 
   id = bg_msg_get_id(msg);
@@ -388,6 +387,7 @@ static void handle_message(player_window_t * win,
         if(win->duration != GAVL_TIME_UNDEFINED)
           bg_gtk_slider_set_pos(win->seek_slider,
                                 (float)(time) / (float)(win->duration));
+        win->gmerlin->remote_data.time = time;
         }
       break;
     case BG_PLAYER_MSG_VOLUME_CHANGED:
@@ -451,6 +451,9 @@ static void handle_message(player_window_t * win,
     case BG_PLAYER_MSG_TRACK_NAME:
       arg_str_1 = bg_msg_get_arg_string(msg, 0);
       display_set_track_name(win->display, arg_str_1);
+      win->gmerlin->remote_data.name =
+        bg_strdup(win->gmerlin->remote_data.name,
+                  arg_str_1);
       free(arg_str_1);
       break;
     case BG_PLAYER_MSG_TRACK_NUM_STREAMS:
@@ -531,7 +534,7 @@ static void handle_message(player_window_t * win,
       break;
     case BG_PLAYER_MSG_TRACK_DURATION:
       win->duration = bg_msg_get_arg_time(msg, 0);
-
+      win->gmerlin->remote_data.duration = win->duration;
       arg_i_2 = bg_msg_get_arg_int(msg, 1);
 
       if(arg_i_2)
@@ -544,6 +547,11 @@ static void handle_message(player_window_t * win,
         bg_gtk_slider_set_state(win->seek_slider,
                                 BG_GTK_SLIDER_HIDDEN);
       break;
+    case BG_PLAYER_MSG_METADATA:
+      gavl_metadata_free(&win->gmerlin->remote_data.metadata);
+      bg_msg_get_arg_metadata(msg, 0,
+                              &win->gmerlin->remote_data.metadata);
+      break;
     case BG_PLAYER_MSG_AUDIO_STREAM:
       arg_i_1 = bg_msg_get_arg_int(msg, 0);
       main_menu_set_audio_index(win->main_menu, arg_i_1);
@@ -556,41 +564,37 @@ static void handle_message(player_window_t * win,
       arg_i_1 = bg_msg_get_arg_int(msg, 0);
       main_menu_set_subtitle_index(win->main_menu, arg_i_1);
       break;
-    case BG_PLAYER_MSG_AUDIO_DESCRIPTION:
-      break;
-    case BG_PLAYER_MSG_VIDEO_DESCRIPTION:
-      break;
-    case BG_PLAYER_MSG_SUBTITLE_DESCRIPTION:
-      break;
-    case BG_PLAYER_MSG_STREAM_DESCRIPTION:
-      break;
     case BG_PLAYER_MSG_AUDIO_STREAM_INFO:
+      {
+      gavl_metadata_t m;
+      gavl_metadata_init(&m);
       arg_i_1 = bg_msg_get_arg_int(msg, 0);
-      arg_str_1 = bg_msg_get_arg_string(msg, 1);
-      arg_str_2 = bg_msg_get_arg_string(msg, 2);
-      main_menu_set_audio_info(win->main_menu, arg_i_1, arg_str_1, arg_str_2);
-      if(arg_str_1) free(arg_str_1);
-      if(arg_str_2) free(arg_str_2);
+      bg_msg_get_arg_metadata(msg, 1, &m);
+      main_menu_set_audio_info(win->main_menu, arg_i_1, &m);
+      gavl_metadata_free(&m);
+      }
       break;
     case BG_PLAYER_MSG_VIDEO_STREAM_INFO:
+      {
+      gavl_metadata_t m;
+      gavl_metadata_init(&m);
       arg_i_1 = bg_msg_get_arg_int(msg, 0);
-      arg_str_1 = bg_msg_get_arg_string(msg, 1);
-      arg_str_2 = bg_msg_get_arg_string(msg, 2);
-      main_menu_set_video_info(win->main_menu, arg_i_1, arg_str_1, arg_str_2);
-      if(arg_str_1) free(arg_str_1);
-      if(arg_str_2) free(arg_str_2);
+      bg_msg_get_arg_metadata(msg, 1, &m);
+      main_menu_set_video_info(win->main_menu, arg_i_1, &m);
+      gavl_metadata_free(&m);
+      }
       break;
     case BG_PLAYER_MSG_SUBTITLE_STREAM_INFO:
+      {
+      gavl_metadata_t m;
+      gavl_metadata_init(&m);
       arg_i_1 = bg_msg_get_arg_int(msg, 0);
-      arg_str_1 = bg_msg_get_arg_string(msg, 1);
-      arg_str_2 = bg_msg_get_arg_string(msg, 2);
-      main_menu_set_subtitle_info(win->main_menu, arg_i_1, arg_str_1,
-                                  arg_str_2);
-      if(arg_str_1) free(arg_str_1);
-      if(arg_str_2) free(arg_str_2);
+      bg_msg_get_arg_metadata(msg, 1, &m);
+      main_menu_set_subtitle_info(win->main_menu, arg_i_1, &m);
+      gavl_metadata_free(&m);
+      }
       break;
     }
-  
   }
 
 void player_window_push_accel(player_window_t * w, int accel)
@@ -687,8 +691,7 @@ void player_window_create(gmerlin_t * g)
   gtk_window_add_accel_group (GTK_WINDOW(ret->window), ret->gmerlin->accel_group);
   gtk_window_add_accel_group (GTK_WINDOW(ret->window), ret->accel_group);
   
-  ret->layout = gtk_layout_new((GtkAdjustment*)0,
-                               (GtkAdjustment*)0);
+  ret->layout = gtk_layout_new(NULL, NULL);
   
   /* Set attributes */
 
