@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -674,6 +674,10 @@ int main(int argc, char ** argv)
   if(config_path)
     free(config_path);
 
+  bg_cfg_registry_destroy(cfg_reg);
+  bg_plugin_registry_destroy(reg);
+  
+  
   
   return 0;
   }
