@@ -39,6 +39,10 @@ int main(int argc, char ** argv)
   bg_cfg_section_t     * section;
   
   bg_recorder_window_t * win;
+
+  /* We must initialize the random number generator if we want the
+     Vorbis encoder to work */
+  srand(time(NULL));
   
   /* Create config registry */
   cfg_reg = bg_cfg_registry_create();
