@@ -51,8 +51,8 @@
 
 static void track_list_update(track_list_t * w);
 
-static GdkPixbuf * has_audio_pixbuf = (GdkPixbuf *)0;
-static GdkPixbuf * has_video_pixbuf = (GdkPixbuf *)0;
+static GdkPixbuf * has_audio_pixbuf = NULL;
+static GdkPixbuf * has_video_pixbuf = NULL;
 
 #define cp_tracks_name "gmerlin_transcoder_tracks"
 
@@ -165,6 +165,9 @@ typedef struct
   GtkWidget * configure_item;
   GtkWidget * encoder_item;
   GtkWidget * chapter_item;
+  GtkWidget * mass_tag_item;
+  GtkWidget * auto_number_item;
+  GtkWidget * auto_rename_item;
   GtkWidget * menu;
   } selected_menu_t;
 
@@ -214,8 +217,6 @@ struct track_list_s
 
   GtkWidget * delete_button;
   GtkWidget * config_button;
-  //  GtkWidget * up_button;
-  //  GtkWidget * down_button;
   GtkWidget * encoder_button;
   GtkWidget * chapter_button;
 
@@ -240,8 +241,6 @@ struct track_list_s
   const bg_parameter_info_t * encoder_parameters;
   
   bg_gtk_time_display_t * time_total;
-
-
   int show_tooltips;
 
   menu_t menu;
@@ -249,6 +248,7 @@ struct track_list_s
   encoder_pp_window_t * encoder_pp_window;
 
   char * open_path;
+  char * rename_mask;
   bg_gtk_filesel_t * filesel;
   
   char * clipboard;
@@ -283,7 +283,7 @@ static void select_row_callback(GtkTreeSelection * sel,
     {
     gtk_widget_set_sensitive(w->config_button, 0);
     gtk_widget_set_sensitive(w->encoder_button, 0);
-    w->selected_track = (bg_transcoder_track_t*)0;
+    w->selected_track = NULL;
     //    gtk_widget_set_sensitive(w->up_button, 0);
     //    gtk_widget_set_sensitive(w->down_button, 0);
     gtk_widget_set_sensitive(w->delete_button, 0);
@@ -336,6 +336,9 @@ static void select_row_callback(GtkTreeSelection * sel,
     gtk_widget_set_sensitive(w->menu.selected_menu.remove_item, 1);
     gtk_widget_set_sensitive(w->menu.selected_menu.encoder_item, 1);
     gtk_widget_set_sensitive(w->menu.selected_menu.chapter_item, 1);
+    gtk_widget_set_sensitive(w->menu.selected_menu.mass_tag_item, 1);
+    gtk_widget_set_sensitive(w->menu.selected_menu.auto_number_item, 1);
+    gtk_widget_set_sensitive(w->menu.selected_menu.auto_rename_item, 1);
 
     gtk_widget_set_sensitive(w->menu.edit_menu.cut_item, 1);
     gtk_widget_set_sensitive(w->menu.edit_menu.copy_item, 1);
@@ -346,7 +349,7 @@ static void select_row_callback(GtkTreeSelection * sel,
     {
     gtk_widget_set_sensitive(w->config_button, 0);
     gtk_widget_set_sensitive(w->encoder_button, 0);
-    w->selected_track = (bg_transcoder_track_t*)0;
+    w->selected_track = NULL;
     //    gtk_widget_set_sensitive(w->up_button, 0);
     //    gtk_widget_set_sensitive(w->down_button, 0);
     gtk_widget_set_sensitive(w->delete_button, 0);
@@ -360,6 +363,9 @@ static void select_row_callback(GtkTreeSelection * sel,
     gtk_widget_set_sensitive(w->menu.selected_menu.remove_item, 0);
     gtk_widget_set_sensitive(w->menu.selected_menu.encoder_item, 0);
     gtk_widget_set_sensitive(w->menu.selected_menu.chapter_item, 0);
+    gtk_widget_set_sensitive(w->menu.selected_menu.mass_tag_item, 0);
+    gtk_widget_set_sensitive(w->menu.selected_menu.auto_number_item, 0);
+    gtk_widget_set_sensitive(w->menu.selected_menu.auto_rename_item, 0);
 
     gtk_widget_set_sensitive(w->menu.edit_menu.cut_item, 0);
     gtk_widget_set_sensitive(w->menu.edit_menu.copy_item, 0);
@@ -367,7 +373,7 @@ static void select_row_callback(GtkTreeSelection * sel,
   else
     {
     gtk_widget_set_sensitive(w->config_button, 0);
-    w->selected_track = (bg_transcoder_track_t*)0;
+    w->selected_track = NULL;
     gtk_widget_set_sensitive(w->encoder_button, 1);
     //    gtk_widget_set_sensitive(w->up_button, 1);
     //    gtk_widget_set_sensitive(w->down_button, 1);
@@ -382,6 +388,9 @@ static void select_row_callback(GtkTreeSelection * sel,
     gtk_widget_set_sensitive(w->menu.selected_menu.remove_item, 1);
     gtk_widget_set_sensitive(w->menu.selected_menu.encoder_item, 1);
     gtk_widget_set_sensitive(w->menu.selected_menu.chapter_item, 0);
+    gtk_widget_set_sensitive(w->menu.selected_menu.mass_tag_item, 1);
+    gtk_widget_set_sensitive(w->menu.selected_menu.auto_number_item, 1);
+    gtk_widget_set_sensitive(w->menu.selected_menu.auto_rename_item, 1);
     
     gtk_widget_set_sensitive(w->menu.edit_menu.cut_item, 1);
     gtk_widget_set_sensitive(w->menu.edit_menu.copy_item, 1);
@@ -579,7 +588,7 @@ static void clipboard_clear_func(GtkClipboard *clipboard,
   if(w->clipboard)
     {
     free(w->clipboard);
-    w->clipboard = (char*)0;
+    w->clipboard = NULL;
     }
   }
 
@@ -711,6 +720,7 @@ static void move_down(track_list_t * l)
   }
 
 static void add_file_callback(char ** files, const char * plugin,
+                              int prefer_edl,
                               void * data)
   {
   const bg_plugin_info_t * plugin_info;
@@ -723,14 +733,15 @@ static void add_file_callback(char ** files, const char * plugin,
   if(plugin)
     plugin_info = bg_plugin_find_by_name(l->plugin_reg, plugin);
   else
-    plugin_info = (const bg_plugin_info_t*)0;
+    plugin_info = NULL;
   while(files[i])
     {
-    
     new_track =
       bg_transcoder_track_create(files[i], plugin_info,
+                                 prefer_edl,
                                  -1, l->plugin_reg,
-                                 l->track_defaults_section, l->encoder_section, (char*)0);
+                                 l->track_defaults_section,
+                                 l->encoder_section, NULL);
     add_track(l, new_track);
     track_list_update(l);
     i++;
@@ -738,7 +749,8 @@ static void add_file_callback(char ** files, const char * plugin,
 
   /* Remember open path */
   if(l->filesel)
-    l->open_path = bg_strdup(l->open_path, bg_gtk_filesel_get_directory(l->filesel));
+    l->open_path = bg_strdup(l->open_path,
+                             bg_gtk_filesel_get_directory(l->filesel));
   }
 
 static void filesel_close_callback(bg_gtk_filesel_t * f , void * data)
@@ -746,7 +758,7 @@ static void filesel_close_callback(bg_gtk_filesel_t * f , void * data)
   track_list_t * t;
   t = (track_list_t*)data;
   gtk_widget_set_sensitive(t->add_file_button, 1);
-  t->filesel = (bg_gtk_filesel_t *)0;
+  t->filesel = NULL;
   }
 
 static void urlsel_close_callback(bg_gtk_urlsel_t * f , void * data)
@@ -788,7 +800,6 @@ static void set_encoder_parameter(void * data, const char * name,
 
 static void configure_encoders(track_list_t * l)
   {
-  
   bg_cfg_section_t * s;
   bg_dialog_t * dlg;
   
@@ -840,6 +851,216 @@ static void configure_encoders(track_list_t * l)
   bg_cfg_section_destroy(s);
   }
 
+static void mass_tag(track_list_t * l)
+  {
+  bg_dialog_t * dlg;
+  bg_transcoder_track_t * first_selected;
+  bg_parameter_info_t * params;
+  bg_cfg_section_t * s;
+  encoder_parameter_data d;
+  int i;
+  bg_parameter_value_t val;
+  d.changed = 0;
+
+  first_selected = l->tracks;
+  while(first_selected && !first_selected->selected)
+    first_selected = first_selected->next;
+  
+  if(!first_selected)
+    return;
+  
+  params = bg_metadata_get_parameters_common(NULL);
+  s = bg_cfg_section_create_from_parameters("Mass tag", params);
+
+  /* Copy parameters from the first selected track. Also set the
+     help string. */
+  i = 0;
+  while(params[i].name)
+    {
+    memset(&val, 0, sizeof(val));
+
+    bg_cfg_section_get_parameter(first_selected->metadata_section,
+                                 &params[i],
+                                 &val);
+    bg_cfg_section_set_parameter(s,
+                                 &params[i],
+                                 &val);
+    bg_parameter_value_free(&val, params[i].type);
+
+    params[i].help_string = bg_strdup(params[i].help_string,
+                                      TRS("Use \"-\" to clear this field for all tracks. Empty string means to leave it unchanged for all tracks"));
+    
+    i++;
+    }
+
+  /* Create and show dialog */
+  dlg = bg_dialog_create(s,
+                         set_encoder_parameter,
+                         NULL,
+                         &d,
+                         params,
+                         TR("Mass tag"));
+  bg_dialog_show(dlg, l->widget);
+
+  /* Apply values */
+  if(d.changed)
+    {
+    while(first_selected)
+      {
+      if(first_selected->selected)
+        {
+        i = 0;
+        while(params[i].name)
+          {
+          memset(&val, 0, sizeof(val));
+          bg_cfg_section_get_parameter(s,
+                                       &params[i],
+                                       &val);
+          if(params[i].type == BG_PARAMETER_STRING)
+            {
+            if(val.val_str && !strcmp(val.val_str, "-"))
+              {
+              bg_parameter_value_t val1;
+              val1.val_str = NULL;
+              bg_cfg_section_set_parameter(first_selected->metadata_section,
+                                           &params[i],
+                                           &val1);
+              }
+            else if(val.val_str && (val.val_str[0] != '\0'))
+              bg_cfg_section_set_parameter(first_selected->metadata_section,
+                                           &params[i],
+                                           &val);
+            }
+          bg_parameter_value_free(&val, params[i].type);
+          i++;
+          }
+        }
+      first_selected = first_selected->next;
+      }
+    }
+  
+  bg_dialog_destroy(dlg);
+  bg_cfg_section_destroy(s);
+  bg_parameter_info_destroy_array(params);
+  }
+
+static const bg_parameter_info_t auto_rename_parameters[] =
+  {
+    {
+      .name =        "rename_mask",
+      .long_name =   TRS("Format for track names"),
+      .type =        BG_PARAMETER_STRING,
+      .help_string = TRS("Format specifier for tracknames from\n\
+metadata\n\
+%p:    Artist\n\
+%a:    Album\n\
+%g:    Genre\n\
+%t:    Track name\n\
+%<d>n: Track number with <d> digits\n\
+%y:    Year\n\
+%c:    Comment"),
+      
+    },
+    { /* End */ },
+  };
+
+typedef struct
+  {
+  char * rename_mask;
+  } auto_rename_parameter_data;
+
+static void set_auto_rename_parameter(void * data, const char * name,
+                                      const bg_parameter_value_t * val)
+  {
+  auto_rename_parameter_data * d = data;
+
+  if(!name)
+    return;
+  if(!strcmp(name, "rename_mask"))
+    d->rename_mask = bg_strdup(d->rename_mask,
+                               val->val_str);
+  }
+
+static void auto_rename(track_list_t * l)
+  {
+  bg_parameter_info_t * metadata_params;
+  bg_parameter_info_t * auto_rename_params;
+  auto_rename_parameter_data d;
+  bg_dialog_t * dlg;
+  
+  metadata_params = bg_metadata_get_parameters(NULL);
+  auto_rename_params =
+    bg_parameter_info_copy_array(auto_rename_parameters);
+
+  auto_rename_params[0].val_default.val_str =
+    bg_strdup(NULL, l->rename_mask);
+
+  memset(&d, 0, sizeof(d));
+  
+  
+  /* Create dialog */
+  dlg = bg_dialog_create(NULL,
+                         set_auto_rename_parameter,
+                         NULL,
+                         &d,
+                         auto_rename_params,
+                         TR("Auto rename"));
+  bg_dialog_show(dlg, l->widget);
+  bg_dialog_destroy(dlg);
+  
+  if(d.rename_mask)
+    {
+    bg_transcoder_track_t * t = l->tracks;
+    while(t)
+      {
+      if(t->selected)
+        {
+        char * new_name;
+        gavl_metadata_t m;
+        gavl_metadata_init(&m);
+        bg_cfg_section_apply(t->metadata_section,
+                             metadata_params,
+                             bg_metadata_set_parameter,
+                             &m);
+        new_name = bg_create_track_name(&m, d.rename_mask);
+        bg_cfg_section_set_parameter_string(t->general_section,
+                                            "name", new_name);
+        free(new_name);
+        gavl_metadata_free(&m);
+        }
+      t = t->next;
+      }
+    /* Save for later use */
+    l->rename_mask = bg_strdup(l->rename_mask, d.rename_mask);
+    free(d.rename_mask);
+    track_list_update(l);
+    }
+  
+  bg_parameter_info_destroy_array(metadata_params);
+  bg_parameter_info_destroy_array(auto_rename_params);
+  }
+
+
+static void auto_number(track_list_t * l)
+  {
+  bg_transcoder_track_t * t;
+  int num = 1;
+  
+  t = l->tracks;
+
+  while(t)
+    {
+    if(t->selected)
+      {
+      bg_cfg_section_set_parameter_int(t->metadata_section, 
+                                       "track", num);
+      num++;
+      }
+    t = t->next;
+    }
+  }
+
+
 static void button_callback(GtkWidget * w, gpointer data)
   {
   track_list_t * t;
@@ -890,7 +1111,8 @@ static void button_callback(GtkWidget * w, gpointer data)
                                       add_file_callback,
                                       drivesel_close_callback,
                                       t, NULL  /* parent */,
-                                      t->plugin_reg, BG_PLUGIN_INPUT, BG_PLUGIN_REMOVABLE);
+                                      t->plugin_reg,
+                                      BG_PLUGIN_INPUT, BG_PLUGIN_REMOVABLE);
     gtk_widget_set_sensitive(t->add_removable_button, 0);
     bg_gtk_drivesel_run(drivesel, 0, t->add_removable_button);
     
@@ -937,6 +1159,19 @@ static void button_callback(GtkWidget * w, gpointer data)
     bg_gtk_chapter_dialog_show(&t->selected_track->chapter_list,
                                track_duration, t->treeview);
     }
+  else if(w == t->menu.selected_menu.mass_tag_item)
+    {
+    mass_tag(t);
+    }
+  else if(w == t->menu.selected_menu.auto_number_item)
+    {
+    auto_number(t);
+    }
+  else if(w == t->menu.selected_menu.auto_rename_item)
+    {
+    auto_rename(t);
+    }
+  
   else if((w == t->encoder_button) ||
           (w == t->menu.selected_menu.encoder_item))
     {
@@ -1012,6 +1247,12 @@ static void init_menu(track_list_t * t)
     create_item(t, t->menu.selected_menu.menu, TR("Configure..."), "config_16.png");
   t->menu.selected_menu.chapter_item =
     create_item(t, t->menu.selected_menu.menu, TR("Edit chapters..."), "chapter_16.png");
+  t->menu.selected_menu.mass_tag_item =
+    create_item(t, t->menu.selected_menu.menu, TR("Mass tag..."), NULL);
+  t->menu.selected_menu.auto_number_item =
+    create_item(t, t->menu.selected_menu.menu, TR("Auto numbering"), NULL);
+  t->menu.selected_menu.auto_rename_item =
+    create_item(t, t->menu.selected_menu.menu, TR("Auto rename..."), NULL);
   t->menu.selected_menu.encoder_item =
     create_item(t, t->menu.selected_menu.menu, TR("Change encoders..."), "plugin_16.png");
 
@@ -1040,25 +1281,25 @@ static void init_menu(track_list_t * t)
   t->menu.menu = gtk_menu_new();
   
   t->menu.add_item =
-    create_item(t, t->menu.menu, TR("Add..."), (char*)0);
+    create_item(t, t->menu.menu, TR("Add..."), NULL);
   
   gtk_menu_item_set_submenu(GTK_MENU_ITEM(t->menu.add_item),
                             t->menu.add_menu.menu);
 
   t->menu.selected_item =
-    create_item(t, t->menu.menu, TR("Selected..."), (char*)0);
+    create_item(t, t->menu.menu, TR("Selected..."), NULL);
 
   gtk_menu_item_set_submenu(GTK_MENU_ITEM(t->menu.selected_item),
                             t->menu.selected_menu.menu);
 
   t->menu.edit_item =
-    create_item(t, t->menu.menu, TR("Edit..."), (char*)0);
+    create_item(t, t->menu.menu, TR("Edit..."), NULL);
 
   gtk_menu_item_set_submenu(GTK_MENU_ITEM(t->menu.edit_item),
                             t->menu.edit_menu.menu);
   
   t->menu.pp_item =
-    create_item(t, t->menu.menu, TR("Postprocess..."), (char*)0);
+    create_item(t, t->menu.menu, TR("Postprocess..."), NULL);
 
   gtk_widget_set_sensitive(t->menu.selected_menu.move_up_item, 0);
   gtk_widget_set_sensitive(t->menu.selected_menu.move_down_item, 0);
@@ -1066,6 +1307,9 @@ static void init_menu(track_list_t * t)
   gtk_widget_set_sensitive(t->menu.selected_menu.remove_item, 0);
   gtk_widget_set_sensitive(t->menu.selected_menu.encoder_item, 0);
   gtk_widget_set_sensitive(t->menu.selected_menu.chapter_item, 0);
+  gtk_widget_set_sensitive(t->menu.selected_menu.mass_tag_item, 0);
+  gtk_widget_set_sensitive(t->menu.selected_menu.auto_number_item, 0);
+  gtk_widget_set_sensitive(t->menu.selected_menu.auto_rename_item, 0);
   
   gtk_widget_set_sensitive(t->menu.edit_menu.cut_item, 0);
   gtk_widget_set_sensitive(t->menu.edit_menu.copy_item, 0);
@@ -1084,10 +1328,10 @@ static gboolean button_press_callback(GtkWidget * w, GdkEventButton * evt,
   if(evt->button == 3)
     {
     gtk_menu_popup(GTK_MENU(t->menu.menu),
-                   (GtkWidget *)0,
-                   (GtkWidget *)0,
-                   (GtkMenuPositionFunc)0,
-                   (gpointer)0,
+                   NULL,
+                   NULL,
+                   NULL,
+                   NULL,
                    3, evt->time);
     return TRUE;
     }
@@ -1109,11 +1353,11 @@ static void column_resize_callback(GtkTreeViewColumn * col,
   width = col->width;
   
   gtk_tree_view_column_cell_get_size(col,
-                                     (GdkRectangle*)0,
-                                     (gint *)0,
-                                     (gint *)0,
+                                     NULL,
+                                     NULL,
+                                     NULL,
                                      &width_needed,
-                                     (gint *)0);
+                                     NULL);
   name_width = gtk_tree_view_column_get_fixed_width (w->col_name);
   
   if(width > width_needed)
@@ -1145,9 +1389,10 @@ void track_list_add_url(track_list_t * l, char * url)
   bg_transcoder_track_t * new_tracks;
   new_tracks =
     bg_transcoder_track_create(url,
-                               (const bg_plugin_info_t *)0,
+                               NULL, 0,
                                -1, l->plugin_reg,
-                               l->track_defaults_section, l->encoder_section, (char*)0);
+                               l->track_defaults_section, l->encoder_section,
+                               NULL);
   add_track(l, new_tracks);
   track_list_update(l);  
   }
@@ -1561,8 +1806,12 @@ void track_list_destroy(track_list_t * t)
 
   if(t->open_path)
     free(t->open_path);
+  if(t->rename_mask)
+    free(t->rename_mask);
   if(t->clipboard)
     free(t->clipboard);
+
+  bg_gtk_time_display_destroy(t->time_total);
   
   free(t);
   }
@@ -1590,7 +1839,7 @@ bg_transcoder_track_t * track_list_get_track(track_list_t * t)
   {
   bg_transcoder_track_t * ret;
   if(!t->tracks)
-    return (bg_transcoder_track_t*)0;
+    return NULL;
   ret = t->tracks;
   t->tracks = t->tracks->next;
   track_list_update(t);
@@ -1644,6 +1893,13 @@ bg_parameter_info_t parameters[] =
       .flags =       BG_PARAMETER_HIDE_DIALOG,
       .val_default = { .val_str = "." },
     },
+    {
+      .name =        "rename_mask",
+      .long_name =   "rename mask",
+      .type =        BG_PARAMETER_STRING,
+      .flags =       BG_PARAMETER_HIDE_DIALOG,
+      .val_default = { .val_str = "%p - %t" },
+    },
     { /* End of parameters */ }
   };
 
@@ -1664,6 +1920,8 @@ track_list_set_parameter(void * data, const char * name,
   
   if(!strcmp(name, "open_path"))
     t->open_path = bg_strdup(t->open_path, val->val_str);
+  if(!strcmp(name, "rename_mask"))
+    t->rename_mask = bg_strdup(t->rename_mask, val->val_str);
   }
 
 int track_list_get_parameter(void * data, const char * name, bg_parameter_value_t * val)
@@ -1679,5 +1937,10 @@ int track_list_get_parameter(void * data, const char * name, bg_parameter_value_
     val->val_str = bg_strdup(val->val_str, t->open_path);
     return 1;
     }
+  else if(!strcmp(name, "rename_mask"))
+    {
+    val->val_str = bg_strdup(val->val_str, t->rename_mask);
+    return 1;
+    }
   return 0;
   }
