@@ -108,7 +108,7 @@ void bg_cfg_registry_save(bg_cfg_registry_t * reg, const char * filename);
  */
 
 
-int bg_cfg_registry_has_section(bg_cfg_registry_t * r, const char * name);
+int bg_cfg_registry_has_section(bg_cfg_registry_t * reg, const char * name);
 
 
 /* The name and xml tag of the section must be set before */
@@ -121,7 +121,7 @@ int bg_cfg_registry_has_section(bg_cfg_registry_t * r, const char * name);
  *  See the libxml2 documentation for more infos
  */
 
-void bg_cfg_section_2_xml(bg_cfg_section_t * section, xmlNodePtr xml_section);
+void bg_cfg_section_2_xml(const bg_cfg_section_t * section, xmlNodePtr xml_section);
 
 /** \ingroup cfg_section
  *  \brief Convert libxml2 node into a configuration section
@@ -286,11 +286,11 @@ void bg_cfg_section_transfer_children(bg_cfg_section_t * src, bg_cfg_section_t *
 
 /** \ingroup cfg_section
  *  \brief Insert a reference to a section as child
- *  \param src s
- *  \param dst Child section to be added as reference
+ *  \param section Configuration section
+ *  \param ref Child section to be added as reference
  */
 
-void bg_cfg_section_add_ref(bg_cfg_section_t * s, bg_cfg_section_t * ref);
+void bg_cfg_section_add_ref(bg_cfg_section_t * section, bg_cfg_section_t * ref);
 
 /*
  *  Get/Set section names
@@ -385,6 +385,13 @@ void bg_cfg_section_get_parameter(bg_cfg_section_t * section,
 void bg_cfg_section_delete_subsection(bg_cfg_section_t * section,
                                       bg_cfg_section_t * subsection);
 
+/** \ingroup cfg_section
+ *  \brief Delete all subsections
+ *  \param section The configuration section
+ */
+
+void bg_cfg_section_delete_subsections(bg_cfg_section_t * section);
+
 
 /*
  *  Type specific get/set functions, which don't require
@@ -547,7 +554,7 @@ int bg_cfg_section_has_subsection(bg_cfg_section_t * section,
  *  \param info Parameter info
  */ 
 
-void bg_cfg_section_restore_defaults(bg_cfg_section_t * s,
+void bg_cfg_section_restore_defaults(bg_cfg_section_t * section,
                                      const bg_parameter_info_t * info);
 
 
