@@ -308,7 +308,7 @@ void bg_msg_get_arg_video_format(bg_msg_t * msg, int arg,
  */
 
 void bg_msg_set_arg_metadata(bg_msg_t * msg, int arg,
-                             const bg_metadata_t * m);
+                             const gavl_metadata_t * m);
 
 /** \brief Get a matadata argument
  *  \param msg A message
@@ -319,7 +319,7 @@ void bg_msg_set_arg_metadata(bg_msg_t * msg, int arg,
  */
 
 void bg_msg_get_arg_metadata(bg_msg_t * msg, int arg,
-                             bg_metadata_t * m);
+                             gavl_metadata_t * m);
 
 /*
  *  This on will be used for remote controls,
@@ -389,6 +389,7 @@ int bg_msg_write_audio_frame(bg_msg_t * msg,
  *  \param frame An audio frame
  *  \param cb Callback
  *  \param cb_data Data to pass to callback
+ *  \param big_endian 1 if data should be sent in big endian format
  *  \returns 1 on success, 0 on error
  *
  *  Before you can use this function, msg must contain
