@@ -31,7 +31,6 @@
 
 #define BG_ALBUM_ENTRY_ERROR      (1<<0)
 #define BG_ALBUM_ENTRY_SELECTED   (1<<1)
-#define BG_ALBUM_ENTRY_PRIVNAME   (1<<2)
 #define BG_ALBUM_ENTRY_REDIRECTOR (1<<3)
 #define BG_ALBUM_ENTRY_SAVE_AUTH  (1<<4)
 #define BG_ALBUM_ENTRY_EDL        (1<<5)
@@ -246,11 +245,13 @@ int bg_album_is_open(bg_album_t * a);
 void bg_album_insert_urls_before(bg_album_t * a,
                                  char ** urls,
                                  const char * plugin,
+                                 int prefer_edl,
                                  bg_album_entry_t * after);
 
 void bg_album_insert_urls_after(bg_album_t * a,
                                 char ** urls,
                                 const char * plugin,
+                                int prefer_edl,
                                 bg_album_entry_t * before);
 
 /* Inserts an xml-string */
@@ -311,6 +312,16 @@ void bg_album_insert_albums_after(bg_album_t * a,
 
 void bg_album_save(bg_album_t * a, const char * filename);
 
+/* Export to playlist formats */
+
+int
+bg_album_entries_save_extm3u(bg_album_entry_t * e, const char * name,
+                             int strip_dirs, const char * prefix);
+
+int
+bg_album_entries_save_pls(bg_album_entry_t * e, const char * name,
+                          int strip_dirs, const char * prefix);
+
 /* Create a struing containing the xml code for the album */
 /* Can be used for Drag & Drop for example                */
 
@@ -398,7 +409,8 @@ void bg_media_tree_add_directory(bg_media_tree_t * t, bg_album_t * parent,
                                  int recursive,
                                  int subdirs_to_subalbums,
                                  int watch,
-                                 const char * plugin);
+                                 const char * plugin,
+                                 int prefer_edl);
 
 /* Gets a root album */
 
@@ -472,6 +484,14 @@ void bg_media_tree_set_current(void * data,
                                bg_album_t * album,
                                const bg_album_entry_t * entry);
 
+/* Get the parent directory of the last added directory */
+
+const char *
+bg_media_tree_get_add_directory_path(bg_media_tree_t * t);
+
+void
+bg_media_tree_set_add_directory_path(bg_media_tree_t * t, const char *);
+
 /* Set the next and previous track */
 
 int bg_media_tree_next(bg_media_tree_t *, int wrap,
@@ -490,6 +510,11 @@ const bg_parameter_info_t * bg_media_tree_get_parameters(bg_media_tree_t*);
 void bg_media_tree_set_parameter(void * priv, const char * name,
                                  const bg_parameter_value_t * val);
 
+int
+bg_media_tree_get_parameter(void * priv, const char * name,
+                            bg_parameter_value_t * val);
+
+
 /* Mark the current entry as error */
 
 void bg_media_tree_mark_error(bg_media_tree_t * , int err);
