@@ -23,6 +23,7 @@
 #define __BG_UTILS_H_
 
 #include <gavl/gavl.h>
+#include <gavl/metadata.h>
 
 /** \defgroup utils Utilities
  *  \brief Utility functions
@@ -136,7 +137,7 @@ char * bg_canonical_filename(const char * name);
 
 /** \brief Ensure a file extension
  *  \param filename Filename (with or without extension)
- *  \param extension Extension to look for
+ *  \param ext Extension to look for
  *  \returns A newly allocated filename
  *
  *  This function checks case insensitively if filename
@@ -244,7 +245,7 @@ int bg_url_split(const char * url,
 
 /** \brief Get MD5 hash of a filename
  *  \param gml
- *  \ret Returns the MD5 sum
+ *  \param ret Returns the MD5 sum
  *
  *  This creates an MD5 hash of a gml. For regular
  *  files this is compatible with the thumbnailing
@@ -414,12 +415,11 @@ char * bg_video_format_to_string(gavl_video_format_t * format, int use_tabs);
 
 /** \brief Create a stream label
  *  \param index Index of the stream (starting with 0)
- *  \param info Information (or NULL)
- *  \param language Language (or NULL)
+ *  \param m Metadata
  *  \returns A newly allocated string
  */
 
-char * bg_get_stream_label(int index, const char * info, const char * language);
+char * bg_get_stream_label(int index, const gavl_metadata_t * m);
 
 /** \brief Dump to stderr
  *  \param format Format (printf compatible)
@@ -434,6 +434,32 @@ void bg_dprintf(const char * format, ...) __attribute__ ((format (printf, 1, 2))
 
 void bg_diprintf(int indent, const char * format, ...) __attribute__ ((format (printf, 2, 3)));
 
+/** \brief Read an entire file into a buffer
+ *  \param filename Name of the file
+ *  \param len Returns the length in bytes
+ *  \returns A buffer containing the entire file
+ */
+
+void * bg_read_file(const char * filename, int * len);
+
+/** \brief Write an entire file into a buffer
+ *  \param filename Name of the file
+ *  \param data Data to write
+ *  \param len Length in bytes
+ *  \returns 1 on success, 0 on failure
+ */
+
+int bg_write_file(const char * filename, void * data, int len);
+
+
+/** \brief Convert a ISO 639-2/B language code to a ISO 639-2/T code
+ *  \param code ISO 639-2/B
+ *  \returns ISO 639-2/T code
+ */
+
+const char * bg_iso639_b_to_t(const char * code);
+
+
 /* @} */
 
 extern char const * const bg_language_codes[];
