@@ -42,6 +42,13 @@
 #define FLAG_DO_RECORD      (1<<2) 
 #define FLAG_INTERRUPTED    (1<<3)
 
+typedef enum
+  {
+    BG_RECORDER_METADATA_STATIC,
+    BG_RECORDER_METADATA_INPUT,
+    BG_RECORDER_METADATA_PLAYER,
+  } bg_recoder_metadata_mode_t;
+
 typedef struct 
   {
   int flags;
@@ -85,10 +92,16 @@ typedef struct
 
   int enc_index;
 
-  char language[4];
+  int eof;
+  pthread_mutex_t eof_mutex;
+
+  gavl_metadata_t m;
   
   } bg_recorder_audio_stream_t;
 
+void bg_recorder_audio_set_eof(bg_recorder_audio_stream_t*, int eof);
+int  bg_recorder_audio_get_eof(bg_recorder_audio_stream_t*);
+
 typedef struct 
   {
   int flags;
@@ -143,7 +156,7 @@ typedef struct
   
   /* Frames */
   gavl_video_frame_t * pipe_frame;
-  gavl_video_frame_t * monitor_frame;
+  gavl_video_frame_t * pipe_frame_priv;
   gavl_video_frame_t * snapshot_frame;
   gavl_video_frame_t * enc_frame;
   
@@ -154,6 +167,8 @@ typedef struct
   
   gavl_time_t last_frame_time;
   gavl_time_t last_capture_duration;
+
+  int do_limit_fps;
   
   int limit_timescale;
   int limit_duration;
@@ -173,9 +188,15 @@ typedef struct
   gavl_time_t last_snapshot_time;
   
   int snapshot_counter;
+
+  int eof;
+  pthread_mutex_t eof_mutex;
   
   } bg_recorder_video_stream_t;
 
+void bg_recorder_video_set_eof(bg_recorder_video_stream_t*, int eof);
+int  bg_recorder_video_get_eof(bg_recorder_video_stream_t*);
+
 struct bg_recorder_s
   {
   bg_recorder_audio_stream_t as;
@@ -198,14 +219,12 @@ struct bg_recorder_s
   
   bg_encoder_t * enc;
   
-  pthread_mutex_t enc_mutex;
-  
   char * output_directory;
   char * output_filename_mask;
   char * snapshot_directory;
   char * snapshot_filename_mask;
   
-  bg_metadata_t m;
+  gavl_metadata_t m;
   bg_parameter_info_t * metadata_parameters;
 
   gavl_time_t recording_time;
@@ -214,9 +233,15 @@ struct bg_recorder_s
 
   int snapshot;
   
-
   pthread_mutex_t snapshot_mutex;
+  bg_recoder_metadata_mode_t metadata_mode;
+
+  gavl_metadata_t updated_metadata;
+  char * updated_name;
   
+  bg_recorder_callbacks_t recorder_cb;
+  
+  int encoding_finalized;
   };
 
 void bg_recorder_create_audio(bg_recorder_t*);
