@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -128,7 +128,7 @@ void bg_x11_window_get_size(bg_x11_window_t * win, int * width, int * height);
 void bg_x11_window_set_gl(bg_x11_window_t *);
 void bg_x11_window_unset_gl(bg_x11_window_t *);
 
-void bg_x11_window_start_gl(bg_x11_window_t * win);
+int bg_x11_window_start_gl(bg_x11_window_t * win);
 void bg_x11_window_stop_gl(bg_x11_window_t * win);
 
 
