@@ -53,7 +53,7 @@ bg_cfg_section_t * bg_cfg_section_find_subsection(bg_cfg_section_t * s,
     }
 
   section = s->children;
-  prev_section = (bg_cfg_section_t *)0;
+  prev_section = NULL;
   
   while(section)
     {
@@ -85,13 +85,14 @@ bg_cfg_section_find_subsection_by_index(bg_cfg_section_t * s,
   for(i = 0; i < index; i++)
     {
     if(!section)
-      return (bg_cfg_section_t*)0;
+      return NULL;
     section = section->next;
     }
   return section;
   }
 
-static char * make_unique_name(bg_cfg_section_t * section, const char * template)
+static char * make_unique_name(bg_cfg_section_t * section,
+                               const char * template)
   {
   int i = 0;
   char * ret;
@@ -108,12 +109,13 @@ static char * make_unique_name(bg_cfg_section_t * section, const char * template
   return ret;
   }
 
-bg_cfg_section_t * bg_cfg_section_create_subsection_at_pos(bg_cfg_section_t * section,
-                                                           int pos)
+bg_cfg_section_t *
+bg_cfg_section_create_subsection_at_pos(bg_cfg_section_t * section,
+                                        int pos)
   {
   int i;
   char * name;
-  bg_cfg_section_t * before = (bg_cfg_section_t *)0;
+  bg_cfg_section_t * before = NULL;
   bg_cfg_section_t * tmp;
   bg_cfg_section_t * ret;
   if(pos)
@@ -219,7 +221,7 @@ bg_cfg_item_t * bg_cfg_section_find_item(bg_cfg_section_t * section,
     return section->items;
     }
   ret = section->items;
-  prev = (bg_cfg_item_t*)0;
+  prev = NULL;
 
   while(ret)
     {
@@ -305,7 +307,7 @@ static char * parse_string(const char * str, int * len_ret)
   {
   const char * end_c;
   char cpy_str[2];
-  char * ret = (char*)0;
+  char * ret = NULL;
   end_c = str;
 
   cpy_str[1] = '\0';
@@ -347,24 +349,31 @@ static char * parse_string(const char * str, int * len_ret)
 
 static const bg_parameter_info_t *
 find_parameter(const bg_parameter_info_t * info,
-               const char * str, int * len)
+               const char * str, int * len, char ** subsection_name)
   {
   FILE * out = stderr;
   int i;
   const char * end;
+
+  *subsection_name = NULL;
+  
   /* Get the options name */
   end = str;
   while((*end != '=') && (*end != '\0'))
     end++;
   
   if(*end == '\0')
-    return (bg_parameter_info_t*)0;
+    return NULL;
   
   /* Now, find the parameter info */
   i = 0;
-  
+
   while(info[i].name)
     {
+    if((info[i].type == BG_PARAMETER_SECTION) &&
+       (info[i].flags & BG_PARAMETER_OWN_SECTION))
+      *subsection_name = info[i].name;
+    
     if(!info[i].opt)
       {
       if((strlen(info[i].name) == (end - str)) &&
@@ -385,7 +394,7 @@ find_parameter(const bg_parameter_info_t * info,
     fprintf(out, "No such option ");
     fwrite(str, 1, end - str, out);
     fprintf(out, "\n");
-    return (bg_parameter_info_t*)0;
+    return NULL;
     }
   *len = (end - str + 1); // Skip '=' as well
   return &info[i];
@@ -408,7 +417,7 @@ static int check_option(const bg_parameter_info_t * info,
 
 
 /* Returns characters read or 0 */
-int bg_cfg_section_set_parameters_from_string(bg_cfg_section_t * section,
+int bg_cfg_section_set_parameters_from_string(bg_cfg_section_t * sec,
                                               const bg_parameter_info_t * parameters,
                                               const char * str_start)
   {
@@ -418,6 +427,9 @@ int bg_cfg_section_set_parameters_from_string(bg_cfg_section_t * section,
   bg_cfg_item_t * item;
   int len = 0, i, index;
   const bg_parameter_info_t * info;
+  char * real_section_name;
+  
+  bg_cfg_section_t * real_section;
   bg_cfg_section_t * subsection;
   char * tmp_string;
   
@@ -428,8 +440,13 @@ int bg_cfg_section_set_parameters_from_string(bg_cfg_section_t * section,
     if((*str == '\0') || (*str == '}'))
       return str - str_start;
     
-    info = find_parameter(parameters, str, &len);
+    info = find_parameter(parameters, str, &len, &real_section_name);
 
+    if(real_section_name)
+      real_section = bg_cfg_section_find_subsection(sec, real_section_name);
+    else
+      real_section = sec;
+    
     if(!info || (info->type == BG_PARAMETER_SECTION) ||
        (info->type == BG_PARAMETER_BUTTON))
       {
@@ -438,7 +455,7 @@ int bg_cfg_section_set_parameters_from_string(bg_cfg_section_t * section,
       fprintf(out, "\n");
       goto fail;
       }
-    item = bg_cfg_section_find_item(section, info);
+    item = bg_cfg_section_find_item(real_section, info);
 
     str += len;
     
@@ -478,7 +495,7 @@ int bg_cfg_section_set_parameters_from_string(bg_cfg_section_t * section,
         if(item->value.val_str)
           {
           free(item->value.val_str);
-          item->value.val_str = (char*)0;
+          item->value.val_str = NULL;
           }
         item->value.val_str = parse_string(str, &len);
 
@@ -496,7 +513,7 @@ int bg_cfg_section_set_parameters_from_string(bg_cfg_section_t * section,
         if(item->value.val_str)
           {
           free(item->value.val_str);
-          item->value.val_str = (char*)0;
+          item->value.val_str = NULL;
           }
         if(*str != '{')
           {
@@ -511,9 +528,9 @@ int bg_cfg_section_set_parameters_from_string(bg_cfg_section_t * section,
 
         if(info->type == BG_PARAMETER_MULTI_CHAIN)
           {
-          while(section->children)
-            bg_cfg_section_delete_subsection(section,
-                                             section->children);
+          while(real_section->children)
+            bg_cfg_section_delete_subsection(real_section,
+                                             real_section->children);
           }
         
         index = 0;
@@ -533,7 +550,7 @@ int bg_cfg_section_set_parameters_from_string(bg_cfg_section_t * section,
           if(*str == '{')
             {
             str++;
-            subsection = bg_cfg_section_find_subsection(section, info->name);
+            subsection = bg_cfg_section_find_subsection(real_section, info->name);
 
             if(info->type == BG_PARAMETER_MULTI_LIST)
               subsection = bg_cfg_section_find_subsection(subsection, tmp_string);
@@ -573,7 +590,7 @@ int bg_cfg_section_set_parameters_from_string(bg_cfg_section_t * section,
         if(item->value.val_str)
           {
           free(item->value.val_str);
-          item->value.val_str = (char*)0;
+          item->value.val_str = NULL;
           }
         item->value.val_str = parse_string(str, &len);
 
@@ -587,7 +604,7 @@ int bg_cfg_section_set_parameters_from_string(bg_cfg_section_t * section,
         if(*str == '{')
           {
           str++;
-          subsection = bg_cfg_section_find_subsection(section, info->name);
+          subsection = bg_cfg_section_find_subsection(real_section, info->name);
           subsection = bg_cfg_section_find_subsection(subsection, item->value.val_str);
           i = 0;
 
@@ -804,7 +821,7 @@ static void do_apply(bg_cfg_section_t * section,
                                                            item->value.val_str);
             do_apply(subsubsection,
                      infos[num].multi_parameters[selected],
-                     func, callback_data, (const char*)0, terminate);
+                     func, callback_data, NULL, terminate);
             }
 
           }
@@ -893,7 +910,7 @@ void bg_cfg_section_apply(bg_cfg_section_t * section,
                           bg_set_parameter_func_t func,
                           void * callback_data)
   {
-  do_apply(section, infos, func, callback_data, (const char*)0, 1);
+  do_apply(section, infos, func, callback_data, NULL, 1);
   }
 
 void bg_cfg_section_apply_noterminate(bg_cfg_section_t * section,
@@ -901,7 +918,7 @@ void bg_cfg_section_apply_noterminate(bg_cfg_section_t * section,
                                       bg_set_parameter_func_t func,
                                       void * callback_data)
   {
-  do_apply(section, infos, func, callback_data, (const char*)0, 0);
+  do_apply(section, infos, func, callback_data, NULL, 0);
   }
 
 void bg_cfg_section_get(bg_cfg_section_t * section,
@@ -940,7 +957,7 @@ static bg_cfg_item_t * find_item_by_name(bg_cfg_section_t * section,
     return section->items;
     }
   ret = section->items;
-  prev = (bg_cfg_item_t*)0;
+  prev = NULL;
 
   while(ret)
     {
@@ -954,7 +971,7 @@ static bg_cfg_item_t * find_item_by_name(bg_cfg_section_t * section,
     prev->next = bg_cfg_item_create_empty(name);
     return prev->next;
     }
-  return (bg_cfg_item_t*)0;
+  return NULL;
   }
 
 void bg_cfg_section_set_parameter_int(bg_cfg_section_t * section,
@@ -1045,9 +1062,9 @@ int bg_cfg_section_get_parameter_time(bg_cfg_section_t * section,
 static void copy_contents(const bg_cfg_section_t * src, bg_cfg_section_t * ret)
   {
   bg_cfg_item_t * src_item;
-  bg_cfg_item_t * end_item = (bg_cfg_item_t*)0;
+  bg_cfg_item_t * end_item = NULL;
   bg_cfg_section_t * src_child;
-  bg_cfg_section_t * end_child = (bg_cfg_section_t*)0;
+  bg_cfg_section_t * end_child = NULL;
   
   /* Copy items */
   
@@ -1174,7 +1191,7 @@ void bg_cfg_section_transfer(bg_cfg_section_t * src, bg_cfg_section_t * dst)
 const char * bg_cfg_section_get_name(bg_cfg_section_t * s)
   {
   if(!s)
-    return (const char*)0;
+    return NULL;
   return s->name;
   }
 
@@ -1182,14 +1199,14 @@ const char * bg_cfg_section_get_name(bg_cfg_section_t * s)
 char * bg_cfg_section_get_name_translated(bg_cfg_section_t * s)
   {
   if(!s)
-    return (char*)0;
+    return NULL;
   if(s->gettext_domain && s->gettext_directory)
     {
     bg_bindtextdomain(s->gettext_domain, s->gettext_directory);
-    return bg_strdup((char*)0, dgettext(s->gettext_domain, s->name));
+    return bg_strdup(NULL, dgettext(s->gettext_domain, s->name));
     }
   else
-    return bg_strdup((char*)0, s->name);
+    return bg_strdup(NULL, s->name);
   }
 
 
@@ -1318,6 +1335,19 @@ void bg_cfg_section_delete_subsection(bg_cfg_section_t * section,
   
   }
 
+void bg_cfg_section_delete_subsections(bg_cfg_section_t * section)
+  {
+  bg_cfg_section_t * tmp;
+
+  while(section->children)
+    {
+    tmp = section->children->next;
+    bg_cfg_section_destroy(section->children);
+    section->children = tmp;
+    }
+  
+  }
+
 void bg_cfg_section_add_ref(bg_cfg_section_t * s, bg_cfg_section_t * ref)
   {
   int i;
