@@ -245,7 +245,7 @@ static void print_help(const bg_cmdline_arg_t* args, bg_help_format_t format)
           print_italic(out, args[i].help_arg, format);
           }
         fprintf(out, "\n");
-        dump_string_term(out, args[i].help_string, 0, (const char*)0, format);
+        dump_string_term(out, args[i].help_string, 0, NULL, format);
     
         break;
       case BG_HELP_FORMAT_TEXI:
@@ -265,7 +265,7 @@ static void print_help(const bg_cmdline_arg_t* args, bg_help_format_t format)
           print_italic(out, args[i].help_arg, format);
         fprintf(out, "\n");
         fprintf(out, ".RS 2\n");
-        dump_string_term(out, args[i].help_string, 0, (const char*)0, format);
+        dump_string_term(out, args[i].help_string, 0, NULL, format);
         fprintf(out, ".RE\n");
 
         break;
@@ -342,7 +342,7 @@ void bg_cmdline_print_help(char * argv0, bg_help_format_t format)
           print_bold(stdout, app_data->env[i].name, format);
           printf("\n");
           dump_string_term(stdout, app_data->env[i].desc,
-                           0, (const char*)0, format);
+                           0, NULL, format);
           i++;
           print_linebreak(stdout, format);
           }
@@ -356,7 +356,7 @@ void bg_cmdline_print_help(char * argv0, bg_help_format_t format)
           print_bold(stdout, app_data->files[i].name, format);
           printf("\n");
           dump_string_term(stdout, app_data->files[i].desc,
-                           0, (const char*)0, format);
+                           0, NULL, format);
           print_linebreak(stdout, format);
           i++;
           }
@@ -421,7 +421,7 @@ void bg_cmdline_print_help(char * argv0, bg_help_format_t format)
           printf("\n");
           printf(".RS 2\n");
           dump_string_term(stdout, app_data->env[i].desc,
-                           0, (const char*)0, format);
+                           0, NULL, format);
           printf(".RE\n");
           i++;
           }
@@ -436,7 +436,7 @@ void bg_cmdline_print_help(char * argv0, bg_help_format_t format)
           printf("\n");
           printf(".RS 2\n");
           dump_string_term(stdout, app_data->files[i].desc,
-                           0, (const char*)0, format);
+                           0, NULL, format);
           printf(".RE\n");
           print_linebreak(stdout, format);
           i++;
@@ -522,8 +522,6 @@ static void opt_help_texi(void * data, int * argc, char *** argv, int arg)
 
 static void opt_version(void * data, int * argc, char *** argv, int arg)
   {
-  bg_cmdline_app_data_t * app_data =
-    (bg_cmdline_app_data_t*)data;
   print_version(app_data);
   exit(0);
   }
@@ -622,7 +620,7 @@ char ** bg_cmdline_get_locations_from_args(int * argc, char *** _argv)
     }
 
   if(!num_locations)
-    return (char**)0;
+    return NULL;
   
   /* Allocate return value */
 
@@ -664,8 +662,8 @@ int bg_cmdline_apply_options(bg_cfg_section_t * section,
                                                 option_string))
     return 0;
   /* Now, apply the section */
-  
-  bg_cfg_section_apply(section, parameters, set_parameter, data);
+  if(set_parameter)
+    bg_cfg_section_apply(section, parameters, set_parameter, data);
   return 1;
   }
 
@@ -684,7 +682,7 @@ static void print_help_parameters(int indent,
   char time_string[GAVL_TIME_STRING_LEN];
   char * tmp_string;
 
-  const char * translation_domain = (const char *)0;
+  const char * translation_domain = NULL;
 
   indent += 2;
   if(format == BG_HELP_FORMAT_MAN)
@@ -933,21 +931,27 @@ static void print_help_parameters(int indent,
 
         pos += fprintf(out, TR("Supported options: "));
         j = 0;
-        while(parameters[i].multi_names[j])
-          {
-          if(j) pos += fprintf(out, " ");
 
-          if(pos + strlen(parameters[i].multi_names[j]) > MAX_COLS)
+        if(parameters[i].multi_names)
+          {
+          while(parameters[i].multi_names[j])
             {
-            if(format != BG_HELP_FORMAT_MAN)
-              fprintf(out, "\n");
-            pos = 0;
-            do_indent(out, indent+2, format);
-            pos += indent+2;
+            if(j) pos += fprintf(out, " ");
+
+            if(pos + strlen(parameters[i].multi_names[j]) > MAX_COLS)
+              {
+              if(format != BG_HELP_FORMAT_MAN)
+                fprintf(out, "\n");
+              pos = 0;
+              do_indent(out, indent+2, format);
+              pos += indent+2;
+              }
+            pos += fprintf(out, "%s", parameters[i].multi_names[j]);
+            j++;
             }
-          pos += fprintf(out, "%s", parameters[i].multi_names[j]);
-          j++;
           }
+        else
+          pos += fprintf(out, TR("<None>"));
 
         print_linebreak(out, format);
         
