@@ -96,7 +96,7 @@ static bg_edl_segment_t * copy_segments(const bg_edl_segment_t * src, int len)
   for(i = 0; i < len; i++)
     {
     /* Copy pointers */
-    ret[i].url = bg_strdup((char*)0, src[i].url);
+    ret[i].url = bg_strdup(NULL, src[i].url);
     }
   return ret;
   }
@@ -132,7 +132,11 @@ static bg_edl_track_t * copy_tracks(const bg_edl_track_t * src, int len)
     {
     /* Copy pointers */
 
-    ret[i].name = bg_strdup((char*)0, src[i].name);
+    ret[i].name = bg_strdup(NULL, src[i].name);
+
+    memset(&ret[i].metadata, 0, sizeof(ret[i].metadata));
+    
+    gavl_metadata_copy(&ret[i].metadata, &src[i].metadata);
     
     ret[i].audio_streams = copy_streams(src[i].audio_streams,
                                         src[i].num_audio_streams);
@@ -156,7 +160,7 @@ bg_edl_t * bg_edl_copy(const bg_edl_t * e)
   
   /* Copy pointers */
   ret->tracks = copy_tracks(e->tracks, e->num_tracks);
-  ret->url = bg_strdup((char*)0, e->url);
+  ret->url = bg_strdup(NULL, e->url);
   return ret;
   }
 
@@ -187,22 +191,29 @@ static void free_tracks(bg_edl_track_t * s, int len)
     free(s->name);
   for(i = 0; i < len; i++)
     {
+    gavl_metadata_free(&s[i].metadata);
+    
     if(s[i].audio_streams)
       free_streams(s[i].audio_streams, s[i].num_audio_streams);
     if(s[i].video_streams)
-      free_streams(s[i].video_streams, s[i].num_video_streams);
+      free_streams(s[i].video_streams,
+                   s[i].num_video_streams);
     if(s[i].subtitle_text_streams)
-      free_streams(s[i].subtitle_text_streams, s[i].num_subtitle_text_streams);
+      free_streams(s[i].subtitle_text_streams,
+                   s[i].num_subtitle_text_streams);
     if(s[i].subtitle_overlay_streams)
-      free_streams(s[i].subtitle_overlay_streams, s[i].num_subtitle_overlay_streams);
+      free_streams(s[i].subtitle_overlay_streams,
+                   s[i].num_subtitle_overlay_streams);
     }
   free(s);
   }
 
 void bg_edl_destroy(bg_edl_t * e)
   {
-  if(e->tracks) free_tracks(e->tracks, e->num_tracks);
-  if(e->url) free(e->url);
+  if(e->tracks)
+    free_tracks(e->tracks, e->num_tracks);
+  if(e->url)
+    free(e->url);
   free(e);
   }
 
@@ -304,7 +315,7 @@ void bg_edl_append_track_info(bg_edl_t * e, const bg_track_info_t * info,
       seg->dst_duration = gavl_time_rescale(GAVL_TIME_SCALE, s->timescale, info->duration);
     seg->speed_num = 1;
     seg->speed_den = 1;
-    seg->url = bg_strdup((char*)0, url);
+    seg->url = bg_strdup(NULL, url);
     seg->track = index;
     seg->stream = i;
     }
@@ -321,7 +332,7 @@ void bg_edl_append_track_info(bg_edl_t * e, const bg_track_info_t * info,
       seg->dst_duration = gavl_time_rescale(GAVL_TIME_SCALE, s->timescale, info->duration);
     seg->speed_num = 1;
     seg->speed_den = 1;
-    seg->url = bg_strdup((char*)0, url);
+    seg->url = bg_strdup(NULL, url);
     seg->track = index;
     seg->stream = i;
     }
@@ -343,7 +354,7 @@ void bg_edl_append_track_info(bg_edl_t * e, const bg_track_info_t * info,
                                             info->duration);
     seg->speed_num = 1;
     seg->speed_den = 1;
-    seg->url = bg_strdup((char*)0, url);
+    seg->url = bg_strdup(NULL, url);
     seg->track = index;
     seg->stream = i;
     }
