@@ -28,6 +28,9 @@
 #include <gmerlin/converters.h>
 #include <gmerlin/utils.h>
 
+#include <pluginreg_priv.h>
+
+
 #include <gmerlin/log.h>
 #define LOG_DOMAIN "edldec"
 
@@ -169,7 +172,6 @@ typedef struct
   const bg_edl_t * edl;
 
   bg_plugin_registry_t * plugin_reg;
-  const bg_plugin_info_t * plugin_info;
   bg_input_callbacks_t * callbacks;
 
   gavl_audio_options_t * a_opt;
@@ -251,14 +253,14 @@ find_same_source(const bg_edl_segment_t * segments,
       }
     return segments;
     }
-  return (bg_edl_segment_t *)0;
+  return NULL;
   }
                            
 static void add_audio_segment(edl_dec_t * dec, int track, int stream,
                               const bg_edl_segment_t * seg)
   {
   int i;
-  audio_source_t * source = (audio_source_t*)0;
+  audio_source_t * source = NULL;
   const bg_edl_segment_t * same_source_seg;
   
   bg_audio_info_t * ai;
@@ -317,7 +319,7 @@ static int add_video_segment(edl_dec_t * dec, int track, int stream,
                              const bg_edl_segment_t * seg)
   {
   int i;
-  video_source_t * source = (video_source_t*)0;
+  video_source_t * source = NULL;
   const bg_edl_segment_t * same_source_seg;
   
   bg_video_info_t * vi;
@@ -377,7 +379,7 @@ static int add_subtitle_overlay_segment(edl_dec_t * dec, int track, int stream,
                                         const bg_edl_segment_t * seg)
   {
   int i;
-  subtitle_source_t * source = (subtitle_source_t*)0;
+  subtitle_source_t * source = NULL;
   const bg_edl_segment_t * same_source_seg;
   
   bg_subtitle_info_t * vi;
@@ -427,7 +429,7 @@ static int add_subtitle_text_segment(edl_dec_t * dec, int track, int stream,
                                      const bg_edl_segment_t * seg)
   {
   int i;
-  subtitle_source_t * source = (subtitle_source_t*)0;
+  subtitle_source_t * source = NULL;
   const bg_edl_segment_t * same_source_seg;
   
   bg_subtitle_info_t * vi;
@@ -625,7 +627,7 @@ static int init_source_common(edl_dec_t * dec,
   {
   if(!bg_input_plugin_load(dec->plugin_reg,
                            com->url,
-                           dec->plugin_info,
+                           NULL,
                            &com->handle,
                            dec->callbacks, 0))
     return 0;
@@ -1333,7 +1335,7 @@ static void close_edl(void * priv)
   if(dec->tracks)
     {
     free(dec->tracks);
-    dec->tracks = (track_t*)0;
+    dec->tracks = NULL;
     }
   if(dec->track_info)
     {
@@ -1342,7 +1344,7 @@ static void close_edl(void * priv)
       bg_track_info_free(&dec->track_info[i]);
       }
     free(dec->track_info);
-    dec->track_info = (bg_track_info_t*)0;
+    dec->track_info = NULL;
     
     }
   
@@ -1368,9 +1370,9 @@ static const bg_input_plugin_t edl_plugin =
       BG_LOCALE,
       .name =           "i_edldec",
       .long_name =      TRS("EDL decoder"),
-      .description =    TRS("This metaplugin decodes and EDL as if it was a single file."),
+      .description =    TRS("This metaplugin decodes an EDL as if it was a single file."),
       .type =           BG_PLUGIN_INPUT,
-      .flags =          BG_PLUGIN_FILE,
+      .flags =          0,
       .priority =       1,
       .create =         NULL,
       .destroy =        destroy_edl,
@@ -1412,6 +1414,10 @@ static const bg_input_plugin_t edl_plugin =
     .close = close_edl,
   };
 
+bg_plugin_info_t * bg_edldec_get_info()
+  {
+  return bg_plugin_info_create(&edl_plugin.common);
+  }
 
 int bg_input_plugin_load_edl(bg_plugin_registry_t * reg,
                              const bg_edl_t * edl,
@@ -1435,7 +1441,10 @@ int bg_input_plugin_load_edl(bg_plugin_registry_t * reg,
     
   //  ret->plugin_reg = reg;
   ret->plugin = (bg_plugin_common_t*)(&edl_plugin);
-  pthread_mutex_init(&ret->mutex,(pthread_mutexattr_t *)0);
+
+  ret->info = info;
+  
+  pthread_mutex_init(&ret->mutex, NULL);
 
   priv = calloc(1, sizeof(*priv));
   ret->priv = priv;
@@ -1443,7 +1452,6 @@ int bg_input_plugin_load_edl(bg_plugin_registry_t * reg,
   
   priv->edl = edl;
   priv->plugin_reg = reg;
-  priv->plugin_info = info;
   priv->callbacks = callbacks;
   
   priv->track_info = calloc(edl->num_tracks, sizeof(*priv->track_info));
@@ -1459,6 +1467,8 @@ int bg_input_plugin_load_edl(bg_plugin_registry_t * reg,
     t     = &priv->tracks[i];
     
     ti->name = bg_strdup(ti->name, track->name);
+
+    gavl_metadata_copy(&ti->metadata, &track->metadata);
     
     ti->flags |= (BG_TRACK_SEEKABLE|BG_TRACK_PAUSABLE);
     
