@@ -37,13 +37,14 @@ typedef struct
 
   bg_encoder_plugin_t * plugin;
   void * priv;
-
+  bg_plugin_handle_t * h;
+  
   gavl_audio_format_t format;
 
   bg_cfg_section_t * section;
   const bg_parameter_info_t * parameters;
 
-  char language[4];
+  const gavl_metadata_t * m;
 
   const gavl_compression_info_t * ci;
   
@@ -56,7 +57,8 @@ typedef struct
 
   bg_encoder_plugin_t * plugin;
   void * priv;
-
+  bg_plugin_handle_t * h;
+  
   gavl_video_format_t format;
   
   bg_cfg_section_t * section;
@@ -65,7 +67,9 @@ typedef struct
   int pass;
   int total_passes;
   char * stats_file;
-  
+
+  const gavl_metadata_t * m;
+
   //  int64_t last_timestamp;
   const gavl_compression_info_t * ci;
   
@@ -78,14 +82,15 @@ typedef struct
 
   bg_encoder_plugin_t * plugin;
   void * priv;
+  bg_plugin_handle_t * h;
 
   int timescale;
   
   bg_cfg_section_t * section;
   const bg_parameter_info_t * parameters;
 
-  char language[4];
-
+  const gavl_metadata_t * m;
+  
   } subtitle_text_stream_t;
 
 typedef struct
@@ -95,13 +100,14 @@ typedef struct
 
   bg_encoder_plugin_t * plugin;
   void * priv;
+  bg_plugin_handle_t * h;
 
   gavl_video_format_t format;
 
   bg_cfg_section_t * section;
   const bg_parameter_info_t * parameters;
 
-  char language[4];
+  const gavl_metadata_t * m;
   
   } subtitle_overlay_stream_t;
 
@@ -158,7 +164,7 @@ struct bg_encoder_s
 
   char * filename_base;
 
-  const bg_metadata_t * metadata;
+  const gavl_metadata_t * metadata;
   const bg_chapter_list_t * chapter_list;
   
   };
@@ -338,12 +344,22 @@ void bg_encoder_destroy(bg_encoder_t * enc, int do_delete)
   
   if(enc->filename_base)
     free(enc->filename_base);
+
+  if(enc->audio_streams)
+    free(enc->audio_streams);
+  if(enc->video_streams)
+    free(enc->video_streams);
+  if(enc->subtitle_text_streams)
+    free(enc->subtitle_text_streams);
+  if(enc->subtitle_overlay_streams)
+    free(enc->subtitle_overlay_streams);
+  
   
   free(enc);
   }
 
 int bg_encoder_open(bg_encoder_t * enc, const char * filename_base,
-                    const bg_metadata_t * metadata,
+                    const gavl_metadata_t * metadata,
                     const bg_chapter_list_t * chapter_list)
   {
   enc->filename_base = bg_strdup(enc->filename_base, filename_base);
@@ -538,14 +554,24 @@ static int start_audio(bg_encoder_t * enc, int stream)
   
   s->plugin = (bg_encoder_plugin_t*)h->plugin;
   s->priv = h->priv;
-
+  s->h = h;
+  
   /* Add stream */
 
   if(s->ci)
-    s->out_index = s->plugin->add_audio_stream_compressed(s->priv, s->language, &s->format, s->ci);
+    {
+    s->out_index =
+      s->plugin->add_audio_stream_compressed(s->priv, s->m,
+                                             &s->format, s->ci);
+    if(s->out_index < 0)
+      return 0;
+    }
   else
     {
-    s->out_index = s->plugin->add_audio_stream(s->priv, s->language, &s->format);
+    s->out_index =
+      s->plugin->add_audio_stream(s->priv, s->m, &s->format);
+    if(s->out_index < 0)
+      return 0;
   
     /* Apply parameters */ 
 
@@ -561,7 +587,7 @@ static int start_audio(bg_encoder_t * enc, int stream)
                            &st);
       }
     }
-  
+
   return 1;
   }
 
@@ -581,14 +607,24 @@ static int start_video(bg_encoder_t * enc, int stream)
   
   s->plugin = (bg_encoder_plugin_t*)h->plugin;
   s->priv = h->priv;
-
+  s->h = h;
+  
   /* Add stream */
   
   if(s->ci)
-    s->out_index = s->plugin->add_video_stream_compressed(s->priv, &s->format, s->ci);
+    {
+    s->out_index =
+      s->plugin->add_video_stream_compressed(s->priv, s->m,
+                                             &s->format, s->ci);
+    if(s->out_index < 0)
+      return 0;
+    }
   else
     {
-    s->out_index = s->plugin->add_video_stream(s->priv, &s->format);
+    s->out_index = s->plugin->add_video_stream(s->priv, s->m,
+                                               &s->format);
+    if(s->out_index < 0)
+      return 0;
   
     /* Apply parameters */ 
     if(s->plugin->set_video_parameter)
@@ -637,11 +673,13 @@ static int start_subtitle_text(bg_encoder_t * enc, int stream)
   
   s->plugin = (bg_encoder_plugin_t*)h->plugin;
   s->priv = h->priv;
-
+  s->h = h;
   /* Add stream */
   
-  s->out_index = s->plugin->add_subtitle_text_stream(s->priv, s->language, &s->timescale);
-    
+  s->out_index = s->plugin->add_subtitle_text_stream(s->priv, s->m, &s->timescale);
+  if(s->out_index < 0)
+    return 0;
+
   /* Apply parameters */ 
   if(s->plugin->set_subtitle_text_parameter)
     {
@@ -674,12 +712,15 @@ static int start_subtitle_overlay(bg_encoder_t * enc, int stream)
   
   s->plugin = (bg_encoder_plugin_t*)h->plugin;
   s->priv = h->priv;
-
+  s->h = h;
+  
   /* Add stream */
   s->out_index =
     s->plugin->add_subtitle_overlay_stream(s->priv,
-                                           s->language, &s->format);
-    
+                                           s->m, &s->format);
+  if(s->out_index < 0)
+    return 0;
+  
   /* Apply parameters */ 
   if(s->plugin->set_subtitle_overlay_parameter)
     {
@@ -760,7 +801,7 @@ int bg_encoder_start(bg_encoder_t * enc)
 
 /* Add streams */
 int bg_encoder_add_audio_stream(bg_encoder_t * enc,
-                                const char * language,
+                                const gavl_metadata_t * m,
                                 const gavl_audio_format_t * format,
                                 int source_index)
   {
@@ -783,8 +824,7 @@ int bg_encoder_add_audio_stream(bg_encoder_t * enc,
   else if(enc->video_plugin.info)
     s->parameters = enc->video_plugin.info->audio_parameters;
 
-  if(language)
-    strncpy(s->language, language, 3);
+  s->m = m;
   
   ret = enc->num_audio_streams;
   enc->num_audio_streams++;
@@ -792,6 +832,7 @@ int bg_encoder_add_audio_stream(bg_encoder_t * enc,
   }
 
 int bg_encoder_add_video_stream(bg_encoder_t * enc,
+                                const gavl_metadata_t * m,
                                 const gavl_video_format_t * format,
                                 int source_index)
   {
@@ -810,13 +851,16 @@ int bg_encoder_add_video_stream(bg_encoder_t * enc,
     s->section = enc->video_stream.section;
 
   s->parameters = enc->video_plugin.info->video_parameters;
+
+  s->m = m;
   
   ret = enc->num_video_streams;
   enc->num_video_streams++;
   return ret;
   }
 
-int bg_encoder_add_audio_stream_compressed(bg_encoder_t * enc, const char * language,
+int bg_encoder_add_audio_stream_compressed(bg_encoder_t * enc,
+                                           const gavl_metadata_t * m,
                                            const gavl_audio_format_t * format,
                                            const gavl_compression_info_t * info,
                                            int source_index)
@@ -831,9 +875,7 @@ int bg_encoder_add_audio_stream_compressed(bg_encoder_t * enc, const char * lang
   s->in_index = source_index;
   
   s->ci = info;
-  
-  if(language)
-    strncpy(s->language, language, 3);
+  s->m = m;
   
   ret = enc->num_audio_streams;
   enc->num_audio_streams++;
@@ -842,6 +884,7 @@ int bg_encoder_add_audio_stream_compressed(bg_encoder_t * enc, const char * lang
   }
 
 int bg_encoder_add_video_stream_compressed(bg_encoder_t * enc,
+                                           const gavl_metadata_t * m,
                                            const gavl_video_format_t * format,
                                            const gavl_compression_info_t * info,
                                            int source_index)
@@ -856,7 +899,7 @@ int bg_encoder_add_video_stream_compressed(bg_encoder_t * enc,
   s->in_index = source_index;
   
   s->ci = info;
-  
+  s->m = m;
   ret = enc->num_video_streams;
   enc->num_video_streams++;
   return ret;
@@ -864,7 +907,7 @@ int bg_encoder_add_video_stream_compressed(bg_encoder_t * enc,
 
 
 int bg_encoder_add_subtitle_text_stream(bg_encoder_t * enc,
-                                        const char * language,
+                                        const gavl_metadata_t * m,
                                         int timescale,
                                         int source_index)
   {
@@ -876,6 +919,8 @@ int bg_encoder_add_subtitle_text_stream(bg_encoder_t * enc,
 
   s->timescale = timescale;
   s->in_index = source_index;
+
+  s->m = m;
   
   if(enc->tt)
     s->section = enc->tt->subtitle_text_streams[source_index].encoder_section_text;
@@ -887,8 +932,6 @@ int bg_encoder_add_subtitle_text_stream(bg_encoder_t * enc,
   else if(enc->video_plugin.info)
     s->parameters = enc->video_plugin.info->subtitle_text_parameters;
 
-  if(language)
-    strncpy(s->language, language, 3);
   
   ret = enc->num_subtitle_text_streams;
   enc->num_subtitle_text_streams++;
@@ -897,7 +940,7 @@ int bg_encoder_add_subtitle_text_stream(bg_encoder_t * enc,
   }
 
 int bg_encoder_add_subtitle_overlay_stream(bg_encoder_t * enc,
-                                           const char * language,
+                                           const gavl_metadata_t * m,
                                            const gavl_video_format_t * format,
                                            int source_index, bg_stream_type_t source_format)
   {
@@ -909,7 +952,7 @@ int bg_encoder_add_subtitle_overlay_stream(bg_encoder_t * enc,
 
   gavl_video_format_copy(&s->format, format);
   s->in_index = source_index;
-
+  s->m = m;
   if(enc->tt)
     {
     if(source_format == BG_STREAM_SUBTITLE_TEXT)
@@ -925,8 +968,6 @@ int bg_encoder_add_subtitle_overlay_stream(bg_encoder_t * enc,
   else if(enc->video_plugin.info)
     s->parameters = enc->video_plugin.info->subtitle_overlay_parameters;
 
-  if(language)
-    strncpy(s->language, language, 3);
   
   ret = enc->num_subtitle_overlay_streams;
   enc->num_subtitle_overlay_streams++;
@@ -980,15 +1021,18 @@ void bg_encoder_get_subtitle_text_timescale(bg_encoder_t * enc,
   *ret = s->timescale;
   }
 
-
-
 /* Write frame */
 int bg_encoder_write_audio_frame(bg_encoder_t * enc,
                                  gavl_audio_frame_t * frame,
                                  int stream)
   {
+  int ret;
   audio_stream_t * s = &enc->audio_streams[stream];
-  return s->plugin->write_audio_frame(s->priv, frame, s->out_index);
+
+  bg_plugin_lock(s->h);
+  ret = s->plugin->write_audio_frame(s->priv, frame, s->out_index);
+  bg_plugin_unlock(s->h);
+  return ret;
   }
   
 
@@ -996,6 +1040,7 @@ int bg_encoder_write_video_frame(bg_encoder_t * enc,
                                  gavl_video_frame_t * frame,
                                  int stream)
   {
+  int ret;
   video_stream_t * s = &enc->video_streams[stream];
 #if 0  
   fprintf(stderr, "Write video frame %"PRId64"\n", frame->timestamp);
@@ -1007,7 +1052,10 @@ int bg_encoder_write_video_frame(bg_encoder_t * enc,
     }
   s->last_timestamp = frame->timestamp;
 #endif
-  return s->plugin->write_video_frame(s->priv, frame, s->out_index);
+  bg_plugin_lock(s->h);
+  ret = s->plugin->write_video_frame(s->priv, frame, s->out_index);
+  bg_plugin_unlock(s->h);
+  return ret;
   }
 
 int bg_encoder_write_subtitle_text(bg_encoder_t * enc,
@@ -1015,15 +1063,26 @@ int bg_encoder_write_subtitle_text(bg_encoder_t * enc,
                                    int64_t start,
                                    int64_t duration, int stream)
   {
+  int ret;
   subtitle_text_stream_t * s = &enc->subtitle_text_streams[stream];
-  return s->plugin->write_subtitle_text(s->priv, text, start, duration, s->out_index);
+
+  bg_plugin_lock(s->h);
+  ret = s->plugin->write_subtitle_text(s->priv, text,
+                                       start, duration, s->out_index);
+  bg_plugin_unlock(s->h);
+  return ret;
   }
 
 int bg_encoder_write_subtitle_overlay(bg_encoder_t * enc,
                                       gavl_overlay_t * ovl, int stream)
   {
+  int ret;
   subtitle_overlay_stream_t * s = &enc->subtitle_overlay_streams[stream];
-  return s->plugin->write_subtitle_overlay(s->priv, ovl, s->out_index);
+
+  bg_plugin_lock(s->h);
+  ret = s->plugin->write_subtitle_overlay(s->priv, ovl, s->out_index);
+  bg_plugin_unlock(s->h);
+  return ret;
   }
 
 static bg_plugin_handle_t *
@@ -1112,14 +1171,42 @@ int bg_encoder_writes_compressed_video(bg_encoder_t * enc,
   }
 
     
-int bg_encoder_write_audio_packet(bg_encoder_t * enc, gavl_packet_t * p, int stream)
+int bg_encoder_write_audio_packet(bg_encoder_t * enc,
+                                  gavl_packet_t * p, int stream)
   {
+  int ret;
   audio_stream_t * s = &enc->audio_streams[stream];
-  return s->plugin->write_audio_packet(s->priv, p, s->out_index);
+  bg_plugin_lock(s->h);
+  ret = s->plugin->write_audio_packet(s->priv, p, s->out_index);
+  bg_plugin_unlock(s->h);
+  return ret;
   }
 
-int bg_encoder_write_video_packet(bg_encoder_t * enc, gavl_packet_t * p, int stream)
+int bg_encoder_write_video_packet(bg_encoder_t * enc,
+                                  gavl_packet_t * p, int stream)
   {
+  int ret;
   video_stream_t * s = &enc->video_streams[stream];
-  return s->plugin->write_video_packet(s->priv, p, s->out_index);
+  bg_plugin_lock(s->h);
+  ret = s->plugin->write_video_packet(s->priv, p, s->out_index);
+  bg_plugin_unlock(s->h);
+  return ret;
+  }
+
+void bg_encoder_update_metadata(bg_encoder_t * enc,
+                                const char * name,
+                                const gavl_metadata_t * m)
+  {
+  int i;
+  for(i = 0; i < enc->num_plugins; i++)
+    {
+    bg_encoder_plugin_t * encoder =
+      (bg_encoder_plugin_t *)enc->plugins[i]->plugin;
+    if(encoder->update_metadata)
+      {
+      bg_plugin_lock(enc->plugins[i]);
+      encoder->update_metadata(enc->plugins[i]->priv, name, m);
+      bg_plugin_unlock(enc->plugins[i]);
+      }
+    }
   }
