@@ -93,13 +93,9 @@ int bg_audio_filter_chain_need_restart(bg_audio_filter_chain_t * ch)
       ch->need_restart = 1;
     }
   
-  return ch->need_restart;
+  return ch->need_restart || ch->need_rebuild;
   }
 
-int bg_audio_filter_chain_need_rebuild(bg_audio_filter_chain_t * ch)
-  {
-  return ch->need_rebuild;
-  }
 
 static int audio_filter_create(audio_filter_t * f,
                                bg_audio_filter_chain_t * ch,
@@ -146,7 +142,7 @@ static void destroy_audio_chain(bg_audio_filter_chain_t * ch)
   if(ch->filters)
     {
     free(ch->filters);
-    ch->filters = (audio_filter_t*)0;
+    ch->filters = NULL;
     }
   ch->num_filters = 0;
   }
@@ -186,7 +182,7 @@ bg_audio_filter_chain_create(const bg_gavl_audio_options_t * opt,
   ret->plugin_reg = plugin_reg;
   ret->cnv_out = bg_audio_converter_create(opt->opt);
   
-  pthread_mutex_init(&ret->mutex, (pthread_mutexattr_t*)0);
+  pthread_mutex_init(&ret->mutex, NULL);
   return ret;
   }
 
@@ -226,8 +222,15 @@ bg_audio_filter_chain_set_parameter(void * data, const char * name,
   ch = (bg_audio_filter_chain_t *)data;
   
   if(!name)
+    {
+    for(i = 0; i < ch->num_filters; i++)
+      {
+      if(ch->filters[i].plugin->common.set_parameter)
+        ch->filters[i].plugin->common.set_parameter(ch->filters[i].handle->priv,
+                                             NULL, NULL);
+      }
     return;
-
+    }
 
   if(!strcmp(name, "audio_filters"))
     {
@@ -520,11 +523,6 @@ struct bg_video_filter_chain_s
   pthread_mutex_t mutex;
   };
 
-int bg_video_filter_chain_need_rebuild(bg_video_filter_chain_t * ch)
-  {
-  return ch->need_rebuild;
-  }
-
 int bg_video_filter_chain_need_restart(bg_video_filter_chain_t * ch)
   {
   gavl_video_format_t test_format;
@@ -537,7 +535,7 @@ int bg_video_filter_chain_need_restart(bg_video_filter_chain_t * ch)
       ch->need_restart = 1;
     }
   
-  return ch->need_restart;
+  return ch->need_restart || ch->need_rebuild;
   }
 
 static int
@@ -574,7 +572,7 @@ static void destroy_video_chain(bg_video_filter_chain_t * ch)
   if(ch->filters)
     {
     free(ch->filters);
-    ch->filters = (video_filter_t*)0;
+    ch->filters = NULL;
     }
   ch->num_filters = 0;
   }
@@ -614,7 +612,7 @@ bg_video_filter_chain_create(const bg_gavl_video_options_t * opt,
 
   ret->cnv_out = bg_video_converter_create(opt->opt);
 
-  pthread_mutex_init(&ret->mutex, (pthread_mutexattr_t*)0);
+  pthread_mutex_init(&ret->mutex, NULL);
   return ret;
   }
 
@@ -653,9 +651,18 @@ bg_video_filter_chain_set_parameter(void * data, const char * name,
   
   bg_video_filter_chain_t * ch;
   ch = (bg_video_filter_chain_t *)data;
-  
+    
   if(!name)
+    {
+    for(i = 0; i < ch->num_filters; i++)
+      {
+      if(ch->filters[i].plugin->common.set_parameter)
+        ch->filters[i].plugin->common.set_parameter(ch->filters[i].handle->priv,
+                                             NULL, NULL);
+      }
     return;
+    }
+
   
   if(!strcmp(name, "video_filters"))
     {
