@@ -221,8 +221,8 @@ void bg_gtk_album_window_destroy(bg_gtk_album_window_t * w, int notify)
   if(w->window && w->window->window)
     {
     gdk_window_get_geometry(w->window->window,
-                            (gint *)0, (gint *)0, &w->width, &w->height,
-                            (gint *)0);
+                            NULL, NULL, &w->width, &w->height,
+                            NULL);
 
     gdk_window_get_root_origin(w->window->window, &w->x, &w->y);
 
@@ -316,7 +316,7 @@ void bg_gtk_album_window_attach(bg_gtk_album_window_t * w, GtkWidget * notebook)
     {
     gtk_container_remove(GTK_CONTAINER(w->window), bg_gtk_album_widget_get_widget(w->widget));
     gtk_widget_destroy(w->window);
-    w->window = (GtkWidget*)0;
+    w->window = NULL;
     }
   /* Attach stuff to notebook */
 
@@ -339,10 +339,16 @@ void bg_gtk_album_window_attach(bg_gtk_album_window_t * w, GtkWidget * notebook)
   gtk_notebook_append_page(GTK_NOTEBOOK(notebook), bg_gtk_album_widget_get_widget(w->widget),
                            w->tab_widget);
   gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook), page_num);
-  
-  gtk_notebook_set_tab_label_packing(GTK_NOTEBOOK(notebook), bg_gtk_album_widget_get_widget(w->widget),
+
+#if 0  
+#if GTK_CHECK_VERSION(2,20,0) 
+  g_object_set(notebook, "tab-fill", FALSE, NULL);
+#else 
+  gtk_notebook_set_tab_label_packing(GTK_NOTEBOOK(notebook),
+                                     bg_gtk_album_widget_get_widget(w->widget),
                                      FALSE, FALSE, GTK_PACK_START);
-  
+#endif
+#endif
   gtk_notebook_set_menu_label_text(GTK_NOTEBOOK(notebook),
                                    bg_gtk_album_widget_get_widget(w->widget),
                                    bg_album_get_label(album));
@@ -364,7 +370,7 @@ void bg_gtk_album_window_detach(bg_gtk_album_window_t * w)
     {
     page_num = gtk_notebook_page_num(GTK_NOTEBOOK(w->notebook), bg_gtk_album_widget_get_widget(w->widget));
     gtk_notebook_remove_page(GTK_NOTEBOOK(w->notebook), page_num);
-    w->notebook = (GtkWidget*)0;
+    w->notebook = NULL;
     }
   
   w->window = bg_gtk_window_new(GTK_WINDOW_TOPLEVEL);
