@@ -208,26 +208,7 @@ static void reset_section(dialog_section_t * s)
                             s->widgets[i].info);
 
     s->widgets[i].funcs->get_value(&s->widgets[i]);
-    
-    if(s->cfg_section)
-      {
-      if(s->widgets[i].info->flags & BG_PARAMETER_SYNC)
-        bg_cfg_section_set_parameter(s->cfg_section,
-                                     s->widgets[i].info,
-                                      &s->widgets[i].value);
 
-      /* If we have multi parameters, we'll also reset the subsection, even if
-         BG_PARAMETER_SYNC isn't set */
-
-      if(s->widgets[i].cfg_subsection_save)
-        {
-        cfg_subsection = bg_cfg_section_find_subsection(s->cfg_section, s->widgets[i].info->name);
-        bg_cfg_section_transfer(s->widgets[i].cfg_subsection_save, cfg_subsection);
-        }
-      if(s->widgets[i].funcs->apply_sub_params)
-        s->widgets[i].funcs->apply_sub_params(&s->widgets[i]);
-      }
-    
     if(s->set_param && (s->widgets[i].info->flags & BG_PARAMETER_SYNC))
       {
       set_param = 1;
@@ -235,7 +216,7 @@ static void reset_section(dialog_section_t * s)
          (s->widgets[i].value.val_str) &&
          strchr(s->widgets[i].value.val_str, ':'))
         {
-        val.val_str = bg_strdup((char*)0, s->widgets[i].value.val_str);
+        val.val_str = bg_strdup(NULL, s->widgets[i].value.val_str);
         pos = strchr(val.val_str, ':');
         if(pos)
           *pos = '\0';
@@ -247,6 +228,26 @@ static void reset_section(dialog_section_t * s)
         s->set_param(s->callback_data, s->widgets[i].info->name,
                      &s->widgets[i].value);
       }
+    
+    if(s->cfg_section)
+      {
+      if(s->widgets[i].info->flags & BG_PARAMETER_SYNC)
+        bg_cfg_section_set_parameter(s->cfg_section,
+                                     s->widgets[i].info,
+                                      &s->widgets[i].value);
+      
+      /* If we have multi parameters, we'll also reset the subsection, even if
+         BG_PARAMETER_SYNC isn't set */
+      
+      if(s->widgets[i].cfg_subsection_save)
+        {
+        cfg_subsection = bg_cfg_section_find_subsection(s->cfg_section, s->widgets[i].info->name);
+        bg_cfg_section_transfer(s->widgets[i].cfg_subsection_save, cfg_subsection);
+        }
+      if(s->widgets[i].funcs->apply_sub_params)
+        s->widgets[i].funcs->apply_sub_params(&s->widgets[i]);
+      }
+    
     }
   
   if(set_param)
@@ -256,7 +257,8 @@ static void reset_section(dialog_section_t * s)
     reset_section(s->children[i]);
   }
 
-static void restore_section(dialog_section_t * s, bg_cfg_section_t * cfg_section)
+static void restore_section(dialog_section_t * s,
+                            bg_cfg_section_t * cfg_section)
   {
   int i;
   bg_parameter_value_t val;
@@ -284,7 +286,7 @@ static void restore_section(dialog_section_t * s, bg_cfg_section_t * cfg_section
          (s->widgets[i].value.val_str) &&
          strchr(s->widgets[i].value.val_str, ':'))
         {
-        val.val_str = bg_strdup((char*)0, s->widgets[i].value.val_str);
+        val.val_str = bg_strdup(NULL, s->widgets[i].value.val_str);
         pos = strchr(val.val_str, ':');
         if(pos)
           *pos = '\0';
@@ -304,6 +306,9 @@ static void restore_section(dialog_section_t * s, bg_cfg_section_t * cfg_section
       bg_cfg_section_t * src1, * dst1;
       dst1 = bg_cfg_section_find_subsection(s->cfg_section, s->widgets[i].info->name);
       src1 = bg_cfg_section_find_subsection(cfg_section, s->widgets[i].info->name);
+
+      if(s->widgets[i].info->type == BG_PARAMETER_MULTI_CHAIN)
+        bg_cfg_section_delete_subsections(dst1);
       bg_cfg_section_transfer_children(src1, dst1);
       }
     }
@@ -641,8 +646,9 @@ static void preset_save_callback(void * data)
       src1 = bg_cfg_section_find_subsection(s->cfg_section, s->widgets[i].info->name);
       dst1 = bg_cfg_section_find_subsection(s->preset_section, s->widgets[i].info->name);
 
+      if(s->widgets[i].info->type == BG_PARAMETER_MULTI_CHAIN)
+        bg_cfg_section_delete_subsections(dst1);
       bg_cfg_section_transfer_children(src1, dst1);
-      
       }
     }
   }
@@ -869,14 +875,14 @@ static GtkWidget * create_section(dialog_section_t * section,
     section->widgets[count].funcs->attach(section->widgets[count].priv, table,
                                  &row, &num_columns);
 
-    /* Get the value from the config data... */
-    if(section->cfg_section)
+    /* Get the value from the get_param function */
+    if(get_param &&
+       get_param(data, info[i].name, &section->widgets[count].value))
+      ;
+    /* .. or from the config data... */
+    else if(section->cfg_section)
       bg_cfg_section_get_parameter(section->cfg_section, &info[i],
                                    &section->widgets[count].value);
-    /* ... or from the get_param function */
-    else if(get_param &&
-            get_param(data, info[i].name, &section->widgets[count].value))
-      ;
     /* ... or from the parameter default */
     else
       bg_parameter_value_copy(&section->widgets[count].value,
@@ -993,7 +999,7 @@ bg_dialog_t * bg_dialog_create(bg_cfg_section_t * section,
   
   GtkTreeIter root_iter;
   GtkTreeModel * model;
-  const char * translation_domain = (const char *)0;
+  const char * translation_domain = NULL;
   bg_dialog_t * ret = create_dialog(title);
 
   //  fprintf(stderr, "bg_dialog_create\n");
@@ -1027,7 +1033,8 @@ bg_dialog_t * bg_dialog_create(bg_cfg_section_t * section,
     
     for(i = 0; i < ret->root_section.num_children; i++)
       {
-      ret->root_section.children[i] = calloc(1, sizeof(*ret->root_section.children[i]));
+      ret->root_section.children[i] =
+        calloc(1, sizeof(*ret->root_section.children[i]));
       
       if(info[index].gettext_domain)
         translation_domain = info[i].gettext_domain;
@@ -1043,7 +1050,8 @@ bg_dialog_t * bg_dialog_create(bg_cfg_section_t * section,
                          TR_DOM(info[index].long_name), -1);
 
       if(ret->preset_section)
-        preset_subsection = bg_cfg_section_find_subsection(ret->preset_section, info[index].name);
+        preset_subsection =
+          bg_cfg_section_find_subsection(ret->preset_section, info[index].name);
       else
         preset_subsection = NULL;
 
@@ -1057,7 +1065,7 @@ bg_dialog_t * bg_dialog_create(bg_cfg_section_t * section,
 
       ret->root_section.children[i]->parent = &ret->root_section;
 
-      while(info[index].type == BG_PARAMETER_SECTION)
+      //      while(info[index].type == BG_PARAMETER_SECTION)
         index++;
 
       
@@ -1077,7 +1085,7 @@ bg_dialog_t * bg_dialog_create(bg_cfg_section_t * section,
     ret->root_section.children[0] = calloc(1, sizeof(*ret->root_section.children[0]));
     table =
       create_section(*ret->root_section.children, info, section, set_param, get_param,
-                     callback_data, (const char *)0, ret->plugin_reg, NULL);
+                     callback_data, NULL, ret->plugin_reg, NULL);
     gtk_notebook_append_page(GTK_NOTEBOOK(ret->notebook), table, label);
     gtk_notebook_set_current_page(GTK_NOTEBOOK(ret->notebook), 1);
     gtk_widget_hide(ret->scrolledwindow);
@@ -1106,7 +1114,7 @@ void bg_dialog_add_child(bg_dialog_t *d, void * _parent,
   GtkWidget * tab_label;
   int i, item_index, section_index;
   GtkTreeModel *model;
-  const char * translation_domain = (const char *)0;
+  const char * translation_domain = NULL;
   dialog_section_t * parent = (dialog_section_t*)_parent;
 
   //  fprintf(stderr, "bg_dialog_add_child %s %p\n", info->name, section);
@@ -1136,7 +1144,7 @@ void bg_dialog_add_child(bg_dialog_t *d, void * _parent,
     
     table = create_section(parent->children[parent->num_children],
                            info, section, set_param, get_param, callback_data,
-                           (const char*)0, d->plugin_reg, NULL);
+                           NULL, d->plugin_reg, NULL);
     tab_label = gtk_label_new(name);
     gtk_widget_show(tab_label);
 
