@@ -82,7 +82,7 @@ static void translate_labels(bg_gtk_widget_t * w)
   while(w->info->multi_labels[i])
     {
     priv->multi_labels[i] =
-      bg_strdup((char*)0,
+      bg_strdup(NULL,
                 TRD(w->info->multi_labels[i], priv->translation_domain));
     i++;
     }
@@ -103,10 +103,12 @@ static void set_sub_param(void * priv, const char * name,
     return;
   
   if(!name)
-    tmp_string = (char*)0;
+    tmp_string = NULL;
   else if(list->is_chain)
     tmp_string = bg_sprintf("%s.%d.%s", w->info->name, list->selected,
                             name);
+  else if(list->param_selected < 0)
+    return;
   else
     {
     tmp_string = bg_sprintf("%s.%s.%s", w->info->name,
@@ -133,7 +135,7 @@ static int get_sub_param(void * priv, const char * name,
     return 0;
   
   if(!name)
-    tmp_string = (char*)0;
+    tmp_string = NULL;
   else if(list->is_chain)
     tmp_string = bg_sprintf("%s.%d.%s", w->info->name, list->selected,
                             name);
@@ -198,18 +200,10 @@ static void apply_sub_params(bg_gtk_widget_t * w)
     bg_strbreak_free(names);
   }
 
-#if 0
-static void do_apply_sub_params(bg_gtk_widget_t * w)
-  {
-  apply_sub_params(w);
-  set_sub_param(w, NULL, NULL);
-  }
-#endif
-
 /* Return the string corresponding to the current list */
 static char * get_list_string(bg_gtk_widget_t * w)
   {
-  char * ret = (char*)0;
+  char * ret = NULL;
   GtkTreeModel * model;
   GtkTreeIter iter;
   char * name;
@@ -219,7 +213,7 @@ static char * get_list_string(bg_gtk_widget_t * w)
   model = gtk_tree_view_get_model(GTK_TREE_VIEW(priv->treeview));
   if(!gtk_tree_model_get_iter_first(model, &iter))
     {
-    return (char*)0;
+    return NULL;
     }
 
   while(1)
@@ -246,7 +240,7 @@ static int get_selected_index(bg_gtk_widget_t * w)
 
   model = gtk_tree_view_get_model(GTK_TREE_VIEW(priv->treeview));
   if(!gtk_tree_model_iter_nth_child(model, &iter,
-                                    (GtkTreeIter *)0,
+                                    NULL,
                                     priv->selected))
     {
     return 0;
@@ -406,8 +400,8 @@ static void get_value(bg_gtk_widget_t * w)
   if(!init)
     bg_strbreak_free(names);
   
-  if(w->info->flags & BG_PARAMETER_SYNC)
-    bg_gtk_change_callback((GtkWidget*)0, w);
+  //  if(w->info->flags & BG_PARAMETER_SYNC)
+  //    bg_gtk_change_callback(NULL, w);
   }
 
 static void add_func(void * priv, const char * name,
@@ -420,62 +414,67 @@ static void add_func(void * priv, const char * name,
   GtkTreeIter iter;
   bg_cfg_section_t * subsection;
   bg_cfg_section_t * subsubsection;
-  bg_cfg_section_t * subsection_default;
-  w = (bg_gtk_widget_t*)priv;
-  list = (list_priv_t*)(w->priv);
-
+  //  bg_cfg_section_t * subsection_default;
+  w = priv;
+  list = w->priv;
+  
   if(!name)
     return;
+  if(strcmp(name, w->info->name))
+    return;
   
   model = gtk_tree_view_get_model(GTK_TREE_VIEW(list->treeview));
   
-  if(!strcmp(name, w->info->name))
-    {
-    index = 0;
-    while(strcmp(w->info->multi_names[index], val->val_str))
-      index++;
+  index = 0;
+  while(strcmp(w->info->multi_names[index], val->val_str))
+    index++;
     
-    gtk_list_store_append(GTK_LIST_STORE(model), &iter);
+  gtk_list_store_append(GTK_LIST_STORE(model), &iter);
 
-    if(!list->multi_labels && w->info->multi_labels)
-      translate_labels(w);
+  if(!list->multi_labels && w->info->multi_labels)
+    translate_labels(w);
     
-    if(list->multi_labels)
-      gtk_list_store_set(GTK_LIST_STORE(model), &iter,
-                         COLUMN_LABEL,
-                         list->multi_labels[index],
-                         -1);
-    else
-      gtk_list_store_set(GTK_LIST_STORE(model), &iter,
-                         COLUMN_LABEL,
-                         w->info->multi_names[index],
-                         -1);
-
+  if(list->multi_labels)
     gtk_list_store_set(GTK_LIST_STORE(model), &iter,
-                       COLUMN_NAME,
+                       COLUMN_LABEL,
+                       list->multi_labels[index],
+                       -1);
+  else
+    gtk_list_store_set(GTK_LIST_STORE(model), &iter,
+                       COLUMN_LABEL,
                        w->info->multi_names[index],
                        -1);
+
+  gtk_list_store_set(GTK_LIST_STORE(model), &iter,
+                     COLUMN_NAME,
+                     w->info->multi_names[index],
+                     -1);
     
-    subsection =
-      bg_cfg_section_find_subsection(w->cfg_section, w->info->name);
+  subsection =
+    bg_cfg_section_find_subsection(w->cfg_section, w->info->name);
+
+#if 0 
+  subsection_default =
+    bg_cfg_section_find_subsection(subsection, val->val_str);
+  
+  if(w->info->multi_parameters[index])
+    bg_cfg_section_create_items(subsection_default, 
+                                w->info->multi_parameters[index]);
+#endif
+  
+  subsubsection =
+    bg_cfg_section_create_subsection_at_pos(subsection, list->num);
+  if(w->info->multi_parameters[index])
+    bg_cfg_section_create_items(subsubsection, 
+                                w->info->multi_parameters[index]);
+  
+  //  bg_cfg_section_transfer(subsection_default, subsubsection);
     
-    subsection_default =
-      bg_cfg_section_find_subsection(subsection, val->val_str);
+  list->num++;
     
-    if(w->info->multi_parameters[index])
-      bg_cfg_section_create_items(subsection_default, 
-                                  w->info->multi_parameters[index]);
-    
-    subsubsection =
-      bg_cfg_section_create_subsection_at_pos(subsection, list->num);
-    bg_cfg_section_transfer(subsection_default, subsubsection);
-    
-    list->num++;
-    
-    if(w->info->flags & BG_PARAMETER_SYNC)
-      {
-      bg_gtk_change_callback((GtkWidget*)0, w);
-      }
+  if(w->info->flags & BG_PARAMETER_SYNC)
+    {
+    bg_gtk_change_callback(NULL, w);
     }
   }
 
@@ -693,7 +692,7 @@ static void move_selected(bg_gtk_widget_t * w, int new_pos)
     {
     gtk_list_store_move_after(GTK_LIST_STORE(model),
                               &iter,
-                              (GtkTreeIter*)0);
+                              NULL);
 
     }
   else
@@ -715,7 +714,7 @@ static void move_selected(bg_gtk_widget_t * w, int new_pos)
   path = gtk_tree_model_get_path(model, &iter);
   gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(priv->treeview),
                                path,
-                               (GtkTreeViewColumn *)0,
+                               NULL,
                                0, 0.0, 0.0);
   gtk_tree_path_free(path);
 
@@ -734,7 +733,7 @@ static void move_selected(bg_gtk_widget_t * w, int new_pos)
   /* Apply parameter and subsections. It's easier to do it here. */
 
   if(w->info->flags & BG_PARAMETER_SYNC)
-    bg_gtk_change_callback((GtkWidget*)0, w);
+    bg_gtk_change_callback(NULL, w);
   
   priv->selected = new_pos;
   
@@ -781,9 +780,9 @@ static void button_callback(GtkWidget * wid, gpointer data)
   bg_cfg_section_t * subsection;
   bg_cfg_section_t * subsubsection;
 
-  w = (bg_gtk_widget_t *)data;
-  priv = (list_priv_t *)(w->priv);
-
+  w = data;
+  priv = w->priv;
+  
   if(wid == priv->config_button)
     {
     if(w->cfg_section)
@@ -804,10 +803,11 @@ static void button_callback(GtkWidget * wid, gpointer data)
 
     
     if(w->info->multi_labels && w->info->multi_labels[priv->param_selected])
-      label = TRD(w->info->multi_labels[priv->param_selected], priv->translation_domain);
+      label = TRD(w->info->multi_labels[priv->param_selected],
+                  priv->translation_domain);
     else
       label = w->info->multi_names[priv->param_selected];
-
+    
     dialog = bg_dialog_create(subsection, set_sub_param, get_sub_param, w,
                               w->info->multi_parameters[priv->param_selected],
                               label);
@@ -858,7 +858,7 @@ static void button_callback(GtkWidget * wid, gpointer data)
     params[0].multi_labels       = w->info->multi_labels;
     params[0].multi_descriptions = w->info->multi_descriptions;
     params[0].help_string        = w->info->help_string;
-    params[0].multi_parameters   = w->info->multi_parameters;
+    //    params[0].multi_parameters   = w->info->multi_parameters;
     
     tmp_string = bg_sprintf(TR("Add %s"),
                             TRD(w->info->long_name, priv->translation_domain));
@@ -866,10 +866,10 @@ static void button_callback(GtkWidget * wid, gpointer data)
     dialog = bg_dialog_create(w->cfg_section, add_func, NULL,
                               w, params, tmp_string);
     
-    free(params[0].gettext_domain);
     
     free(tmp_string);
     bg_dialog_show(dialog, priv->treeview);
+    free(params[0].gettext_domain);
     
     }
   else if(wid == priv->remove_button)
@@ -891,7 +891,7 @@ static void button_callback(GtkWidget * wid, gpointer data)
     priv->num--;
     if(w->info->flags & BG_PARAMETER_SYNC)
       {
-      bg_gtk_change_callback((GtkWidget*)0, w);
+      bg_gtk_change_callback(NULL, w);
       }
     }
   
