@@ -46,6 +46,7 @@ struct bg_gtk_drivesel_s
   bg_gtk_plugin_menu_t * plugin_menu;
   
   void (*add_files)(char ** files, const char * plugin,
+                    int prefer_edl,
                     void * data);
 
   void (*close_notify)(bg_gtk_drivesel_t * f, void * data);
@@ -67,7 +68,7 @@ static void plugin_change_callback(bg_gtk_plugin_menu_t * m, void * data)
   ds = (bg_gtk_drivesel_t*)data;
   
   for(i = 0; i < ds->num_drives; i++)
-    gtk_combo_box_remove_text(GTK_COMBO_BOX(ds->drive_menu), 0);
+    bg_gtk_combo_box_remove_text(ds->drive_menu, 0);
 
   
   
@@ -80,11 +81,11 @@ static void plugin_change_callback(bg_gtk_plugin_menu_t * m, void * data)
   while(devices[ds->num_drives].device)
     {
     if(devices[ds->num_drives].name)
-      gtk_combo_box_append_text(GTK_COMBO_BOX(ds->drive_menu),
-                                devices[ds->num_drives].name);
+      bg_gtk_combo_box_append_text(ds->drive_menu,
+                                   devices[ds->num_drives].name);
     else
-      gtk_combo_box_append_text(GTK_COMBO_BOX(ds->drive_menu),
-                                devices[ds->num_drives].device);
+      bg_gtk_combo_box_append_text(ds->drive_menu,
+                                   devices[ds->num_drives].device);
     ds->num_drives++;
     }
   /* Select first entry */
@@ -94,7 +95,7 @@ static void plugin_change_callback(bg_gtk_plugin_menu_t * m, void * data)
 static void button_callback(GtkWidget * w, gpointer data)
   {
   bg_gtk_drivesel_t * f;
-  const char * plugin = (const char*)0;
+  const char * plugin = NULL;
 
   char * drives[2];
   
@@ -109,7 +110,7 @@ static void button_callback(GtkWidget * w, gpointer data)
 
     plugin = f->plugin_info->name;
     
-    f->add_files(drives, plugin, f->callback_data);
+    f->add_files(drives, plugin, 0, f->callback_data);
     }
   
   else if((w == f->window) || (w == f->close_button))
@@ -142,7 +143,7 @@ static gboolean destroy_callback(GtkWidget * w, GdkEvent * event,
 bg_gtk_drivesel_t *
 bg_gtk_drivesel_create(const char * title,
                        void (*add_files)(char ** files, const char * plugin,
-                                         void * data),
+                                         int prefer_edl, void * data),
                        void (*close_notify)(bg_gtk_drivesel_t *,
                                             void * data),
                        void * user_data,
@@ -176,7 +177,7 @@ bg_gtk_drivesel_create(const char * title,
 
   /* Create device menu */
 
-  ret->drive_menu = gtk_combo_box_new_text();
+  ret->drive_menu = bg_gtk_combo_box_new_text();
   gtk_widget_show(ret->drive_menu);
   
   /* Create plugin menu */
