@@ -58,24 +58,23 @@ enum
 #define PATH_INPUT_PLUGIN     1
 #define PATH_LOCATION         2
 #define PATH_TRACK            3
-#define PATH_FORMAT           4
-#define PATH_METADATA         5
-#define PATH_AUDIO            6
-#define PATH_AUDIO_DESC       7
-#define PATH_AUDIO_FORMAT_I   8
-#define PATH_AUDIO_FORMAT_O   9
+#define PATH_METADATA         4
+#define PATH_AUDIO            5
+#define PATH_AUDIO_DESC       6
+#define PATH_AUDIO_FORMAT_I   7
+#define PATH_AUDIO_FORMAT_O   8
 
-#define PATH_VIDEO           10
-#define PATH_VIDEO_DESC      11
-#define PATH_VIDEO_FORMAT_I  12
-#define PATH_VIDEO_FORMAT_O  13
+#define PATH_VIDEO            9
+#define PATH_VIDEO_DESC      10
+#define PATH_VIDEO_FORMAT_I  11
+#define PATH_VIDEO_FORMAT_O  12
 
-#define PATH_SUBTITLE          14
-#define PATH_SUBTITLE_DESC     15
-#define PATH_SUBTITLE_FORMAT_I 16
-#define PATH_SUBTITLE_FORMAT_O 17
+#define PATH_SUBTITLE          13
+#define PATH_SUBTITLE_DESC     14
+#define PATH_SUBTITLE_FORMAT_I 15
+#define PATH_SUBTITLE_FORMAT_O 16
 
-#define PATH_NUM             18
+#define PATH_NUM             17
 
 /* Delay between update calls in Milliseconds */
 
@@ -87,9 +86,6 @@ struct bg_gtk_info_window_s
 
   /* We store everything interesting locally */
   
-  gavl_video_format_t subtitle_format;
-  
-
   int num_audio_streams;
   int num_video_streams;
   int num_subtitle_streams;
@@ -482,7 +478,7 @@ static gboolean idle_callback(gpointer data)
   
   gavl_audio_format_t arg_af;
   gavl_video_format_t arg_vf;
-  bg_metadata_t     arg_m;
+  gavl_metadata_t     arg_m;
   
   bg_gtk_info_window_t * w;
   bg_msg_t * msg;
@@ -556,38 +552,38 @@ static gboolean idle_callback(gpointer data)
         break;
       case BG_PLAYER_MSG_TRACK_DURATION:
         break;
-      case BG_PLAYER_MSG_STREAM_DESCRIPTION:
-        
-        arg_str = bg_msg_get_arg_string(msg, 0);
-        
-        if(arg_str)
+      case BG_PLAYER_MSG_AUDIO_STREAM_INFO:
+        gavl_metadata_init(&arg_m);
+        bg_msg_get_arg_metadata(msg, 1, &arg_m);
+        tmp_string = bg_metadata_to_string(&arg_m, 1);
+        if(tmp_string)
           {
-          tmp_string = bg_sprintf(TR("Format:\t%s"), arg_str);
-          set_line_index(w, PATH_FORMAT, tmp_string, 1);
+          set_line_multi(w, PATH_AUDIO_DESC, tmp_string);
           free(tmp_string);
-          free(arg_str);
           }
-        
+        gavl_metadata_free(&arg_m);
         break;
-      case BG_PLAYER_MSG_AUDIO_DESCRIPTION:
-        arg_str = bg_msg_get_arg_string(msg, 0);
-        if(arg_str)
+      case BG_PLAYER_MSG_SUBTITLE_STREAM_INFO:
+        gavl_metadata_init(&arg_m);
+        bg_msg_get_arg_metadata(msg, 1, &arg_m);
+        tmp_string = bg_metadata_to_string(&arg_m, 1);
+        if(tmp_string)
           {
-          tmp_string = bg_sprintf(TR("Stream type:\t%s"), arg_str);
-          set_line_index(w, PATH_AUDIO_DESC, tmp_string, 1);
+          set_line_multi(w, PATH_SUBTITLE_DESC, tmp_string);
           free(tmp_string);
-          free(arg_str);
           }
+        gavl_metadata_free(&arg_m);
         break;
-      case BG_PLAYER_MSG_VIDEO_DESCRIPTION:
-        arg_str = bg_msg_get_arg_string(msg, 0);
-        if(arg_str)
+      case BG_PLAYER_MSG_VIDEO_STREAM_INFO:
+        gavl_metadata_init(&arg_m);
+        bg_msg_get_arg_metadata(msg, 1, &arg_m);
+        tmp_string = bg_metadata_to_string(&arg_m, 1);
+        if(tmp_string)
           {
-          tmp_string = bg_sprintf(TR("Stream type:\t%s"), arg_str);
-          set_line_index(w, PATH_VIDEO_DESC, tmp_string, 1);
+          set_line_multi(w, PATH_VIDEO_DESC, tmp_string);
           free(tmp_string);
-          free(arg_str);
           }
+        gavl_metadata_free(&arg_m);
         break;
       case BG_PLAYER_MSG_AUDIO_STREAM:
         arg_i = bg_msg_get_arg_int(msg, 0);
@@ -634,9 +630,9 @@ static gboolean idle_callback(gpointer data)
         
         break;
       case BG_PLAYER_MSG_METADATA:
-        memset(&arg_m, 0, sizeof(arg_m));
+        gavl_metadata_init(&arg_m);
         bg_msg_get_arg_metadata(msg, 0, &arg_m);
-        
+                
         tmp_string = bg_metadata_to_string(&arg_m, 1);
         
         if(tmp_string)
@@ -644,6 +640,7 @@ static gboolean idle_callback(gpointer data)
           set_line_multi(w, PATH_METADATA, tmp_string);
           free(tmp_string);
           }
+        gavl_metadata_free(&arg_m);
         break;
       }
     bg_msg_queue_unlock_read(w->queue);
@@ -678,7 +675,7 @@ static gboolean configure_callback(GtkWidget * w, GdkEventConfigure *event,
 
 
 
-#define FREE(str) if(str) free(str);str=(char*)0;
+#define FREE(str) if(str) free(str);str=NULL;
 
 
 static void reset_tree(bg_gtk_info_window_t * w)
@@ -690,10 +687,6 @@ static void reset_tree(bg_gtk_info_window_t * w)
 
   model = gtk_tree_view_get_model(GTK_TREE_VIEW(w->treeview));
   
-  /* Format */
-  gtk_tree_model_get_iter(model, &iter, w->paths[PATH_FORMAT]);
-  set_line(w, &iter, TR("Format"), 0);
-  
   /* Metadata */
   gtk_tree_model_get_iter(model, &iter, w->paths[PATH_METADATA]);
   set_line(w, &iter, TR("Metadata"), 0);
@@ -705,7 +698,8 @@ static void reset_tree(bg_gtk_info_window_t * w)
 
   /* Audio -> desc */
   gtk_tree_model_get_iter(model, &iter, w->paths[PATH_AUDIO_DESC]);
-  set_line(w, &iter, TR("Stream type"), 0);
+  set_line(w, &iter, TR("Metadata"), 0);
+  remove_children(w, &iter);
   
   /* Audio -> format_i */
   gtk_tree_model_get_iter(model, &iter, w->paths[PATH_AUDIO_FORMAT_I]);
@@ -723,7 +717,8 @@ static void reset_tree(bg_gtk_info_window_t * w)
 
   /* Video -> desc */
   gtk_tree_model_get_iter(model, &iter, w->paths[PATH_VIDEO_DESC]);
-  set_line(w, &iter, TR("Stream type"), 0);
+  set_line(w, &iter, TR("Metadata"), 0);
+  remove_children(w, &iter);
 
   /* Video -> format_i */
   gtk_tree_model_get_iter(model, &iter, w->paths[PATH_VIDEO_FORMAT_I]);
@@ -741,7 +736,8 @@ static void reset_tree(bg_gtk_info_window_t * w)
 
   /* Subtitle -> desc */
   gtk_tree_model_get_iter(model, &iter, w->paths[PATH_SUBTITLE_DESC]);
-  set_line(w, &iter, TR("Stream type"), 0);
+  set_line(w, &iter, TR("Metadata"), 0);
+  remove_children(w, &iter);
   
   /* Subtitle -> format_i */
   gtk_tree_model_get_iter(model, &iter, w->paths[PATH_SUBTITLE_FORMAT_I]);
@@ -766,35 +762,31 @@ static void init_tree(bg_gtk_info_window_t * w)
   model = gtk_tree_view_get_model(GTK_TREE_VIEW(w->treeview));
 
   /* Name */
-  gtk_tree_store_append(GTK_TREE_STORE(model), &iter, (GtkTreeIter*)0);
+  gtk_tree_store_append(GTK_TREE_STORE(model), &iter, NULL);
   w->paths[PATH_NAME] = gtk_tree_model_get_path(model, &iter);
   set_line(w, &iter, TR("Name"), 0);
 
   /* Plugin */
-  gtk_tree_store_append(GTK_TREE_STORE(model), &iter, (GtkTreeIter*)0);
+  gtk_tree_store_append(GTK_TREE_STORE(model), &iter, NULL);
   w->paths[PATH_INPUT_PLUGIN] = gtk_tree_model_get_path(model, &iter);
   set_line(w, &iter, TR("Input plugin"), 0);
     
   /* Location */
-  gtk_tree_store_append(GTK_TREE_STORE(model), &iter, (GtkTreeIter*)0);
+  gtk_tree_store_append(GTK_TREE_STORE(model), &iter, NULL);
   w->paths[PATH_LOCATION] = gtk_tree_model_get_path(model, &iter);
   set_line(w, &iter, TR("Location"), 0);
   
   /* Track */
-  gtk_tree_store_append(GTK_TREE_STORE(model), &iter, (GtkTreeIter*)0);
+  gtk_tree_store_append(GTK_TREE_STORE(model), &iter, NULL);
   w->paths[PATH_TRACK] = gtk_tree_model_get_path(model, &iter);
   set_line(w, &iter, TR("Track"), 0);
-  
-  /* Format */
-  gtk_tree_store_append(GTK_TREE_STORE(model), &iter, (GtkTreeIter*)0);
-  w->paths[PATH_FORMAT] = gtk_tree_model_get_path(model, &iter);
-  
+    
   /* Metadata */
-  gtk_tree_store_append(GTK_TREE_STORE(model), &iter, (GtkTreeIter*)0);
+  gtk_tree_store_append(GTK_TREE_STORE(model), &iter, NULL);
   w->paths[PATH_METADATA] = gtk_tree_model_get_path(model, &iter);
   
   /* Audio */
-  gtk_tree_store_append(GTK_TREE_STORE(model), &iter, (GtkTreeIter*)0);
+  gtk_tree_store_append(GTK_TREE_STORE(model), &iter, NULL);
   w->paths[PATH_AUDIO] = gtk_tree_model_get_path(model, &iter);
 
   /* Audio -> desc */
@@ -810,7 +802,7 @@ static void init_tree(bg_gtk_info_window_t * w)
   w->paths[PATH_AUDIO_FORMAT_O] = gtk_tree_model_get_path(model, &child);
     
   /* Video */
-  gtk_tree_store_append(GTK_TREE_STORE(model), &iter, (GtkTreeIter*)0);
+  gtk_tree_store_append(GTK_TREE_STORE(model), &iter, NULL);
   w->paths[PATH_VIDEO] = gtk_tree_model_get_path(model, &iter);
 
   /* Video -> desc */
@@ -827,7 +819,7 @@ static void init_tree(bg_gtk_info_window_t * w)
   
   
   /* Subtitle */
-  gtk_tree_store_append(GTK_TREE_STORE(model), &iter, (GtkTreeIter*)0);
+  gtk_tree_store_append(GTK_TREE_STORE(model), &iter, NULL);
   w->paths[PATH_SUBTITLE] = gtk_tree_model_get_path(model, &iter);
 
   /* Subtitle -> desc */
@@ -923,7 +915,7 @@ static void clipboard_clear_func(GtkClipboard *clipboard,
     {
     free(w->clipboard);
     w->clipboard_len = 0;
-    w->clipboard = (char*)0;
+    w->clipboard = NULL;
     }
   }
 
@@ -953,10 +945,10 @@ static void copy_selected(bg_gtk_info_window_t * w)
     free(w->clipboard);
 
   gtk_tree_selection_get_selected(selection,
-                                  (GtkTreeModel**)0,
+                                  NULL,
                                   &iter);
   
-  w->clipboard = iter_to_string(w, (char*)0, 0, &iter, 1);
+  w->clipboard = iter_to_string(w, NULL, 0, &iter, 1);
 
   if(w->clipboard)
     {
@@ -985,7 +977,7 @@ static void copy_all(bg_gtk_info_window_t * w)
   
   if(w->clipboard)
     free(w->clipboard);
-  w->clipboard = iter_to_string(w, (char*)0, 0, (GtkTreeIter*)0, 1);
+  w->clipboard = iter_to_string(w, NULL, 0, NULL, 1);
 
   if(w->clipboard)
     {
@@ -1059,10 +1051,10 @@ static gboolean button_press_callback(GtkWidget * wid, GdkEventButton * evt,
   if(evt->button == 3)
     {
     gtk_menu_popup(GTK_MENU(w->menu.menu),
-                   (GtkWidget *)0,
-                   (GtkWidget *)0,
-                   (GtkMenuPositionFunc)0,
-                   (gpointer)0,
+                   NULL,
+                   NULL,
+                   NULL,
+                   NULL,
                    3, evt->time);
     return  FALSE;
     }
@@ -1160,7 +1152,7 @@ bg_gtk_info_window_create(bg_player_t * player,
 
   /* pack objects */
   
-  scrolledwin = gtk_scrolled_window_new((GtkAdjustment*)0, (GtkAdjustment*)0);
+  scrolledwin = gtk_scrolled_window_new(NULL, NULL);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolledwin),
                                  GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
   
