@@ -237,7 +237,7 @@ static void change_callback(GtkWidget * w, gpointer data)
   if(widget->handle)
     {
     bg_plugin_unref(widget->handle);
-    widget->handle = (bg_plugin_handle_t*)0;
+    widget->handle = NULL;
     }
   update_sensitive(widget);
 
@@ -266,7 +266,7 @@ static void change_callback(GtkWidget * w, gpointer data)
       widget->audio_section =
         bg_cfg_section_find_subsection(widget->section, "$audio");
     else
-      widget->audio_section = (bg_cfg_section_t*)0;
+      widget->audio_section = NULL;
 
     if(widget->video_section_priv)
       {
@@ -278,7 +278,7 @@ static void change_callback(GtkWidget * w, gpointer data)
       widget->video_section =
         bg_cfg_section_find_subsection(widget->section, "$video");
     else
-      widget->video_section = (bg_cfg_section_t*)0;
+      widget->video_section = NULL;
 
     if(widget->subtitle_text_section_priv)
       {
@@ -290,7 +290,7 @@ static void change_callback(GtkWidget * w, gpointer data)
       widget->subtitle_text_section =
         bg_cfg_section_find_subsection(widget->section, "$subtitle_text");
     else
-      widget->subtitle_text_section = (bg_cfg_section_t*)0;
+      widget->subtitle_text_section = NULL;
 
     if(widget->subtitle_overlay_section_priv)
       {
@@ -302,7 +302,7 @@ static void change_callback(GtkWidget * w, gpointer data)
       widget->subtitle_overlay_section =
         bg_cfg_section_find_subsection(widget->section, "$subtitle_overlay");
     else
-      widget->subtitle_overlay_section = (bg_cfg_section_t*)0;
+      widget->subtitle_overlay_section = NULL;
 
     }
   
@@ -398,14 +398,14 @@ bg_gtk_plugin_widget_single_create(char * label,
   
   /* Make combo */
   default_index = -1;
-  ret->combo = gtk_combo_box_new_text();
+  ret->combo = bg_gtk_combo_box_new_text();
   g_signal_connect(G_OBJECT(ret->combo),
                    "changed", G_CALLBACK(change_callback),
                    (gpointer)ret);
   for(i = 0; i < num_plugins; i++)
     {
     info = bg_plugin_find_by_index(reg, i, type_mask, flag_mask);
-    gtk_combo_box_append_text(GTK_COMBO_BOX(ret->combo), info->long_name);
+    bg_gtk_combo_box_append_text(ret->combo, info->long_name);
 
     if(info == default_info)
       default_index = i;
