@@ -28,6 +28,9 @@
 #include <gmerlin/lcdproc.h>
 #include <gmerlin/bgsocket.h>
 
+#include <gavl/metatags.h>
+
+
 #include <string.h>
 #include <sys/types.h> /* pid_t */
 #include <unistd.h>
@@ -147,8 +150,8 @@ bg_lcdproc_t * bg_lcdproc_create(bg_player_t * player)
   ret = calloc(1, sizeof(*ret));
   ret->fd = -1;
   ret->queue = bg_msg_queue_create();
-  pthread_mutex_init(&ret->config_mutex, (pthread_mutexattr_t *)0);
-  pthread_mutex_init(&ret->state_mutex, (pthread_mutexattr_t *)0);
+  pthread_mutex_init(&ret->config_mutex, NULL);
+  pthread_mutex_init(&ret->state_mutex, NULL);
   ret->player = player;
   return ret;
   }
@@ -202,7 +205,7 @@ static int do_connect(bg_lcdproc_t* l)
   {
   int i;
   char ** answer_args;
-  char * cmd = (char*)0;
+  char * cmd = NULL;
   
   bg_host_address_t * addr = bg_host_address_create();
 
@@ -541,10 +544,32 @@ static int destroy_formats(bg_lcdproc_t * l)
   return 0;
   }
 
-static int set_audio_description(bg_lcdproc_t * l, const char * desc)
+static int set_audio_description(bg_lcdproc_t * l, gavl_metadata_t * m)
   {
+  char * desc;
   char * command;
 
+  const char * format_str = NULL;
+  int bitrate = 0;
+
+  if(m)
+    {
+    format_str = gavl_metadata_get(m, GAVL_META_FORMAT);
+
+    if(!gavl_metadata_get_int(m, GAVL_META_BITRATE, &bitrate))
+      bitrate = 0;
+    }
+  
+  if(!format_str)
+    desc = NULL;
+  else
+    {
+    if(bitrate)
+      desc = bg_sprintf("%s %d kbps", format_str, bitrate);
+    else
+      desc = bg_sprintf("%s", format_str);
+    }
+  
   if(!desc)
     {
     command = bg_sprintf("widget_set %s %s 1 1 16 2 m 1 {A: Off}",
@@ -559,6 +584,7 @@ static int set_audio_description(bg_lcdproc_t * l, const char * desc)
     else
       command = bg_sprintf("widget_set %s %s 1 1 16 2 m 1 {A: %s}",
                            descriptions_name, audio_description_name, desc);
+    free(desc);
     }
   if(!send_command(l, command))
     goto fail;
@@ -570,9 +596,23 @@ static int set_audio_description(bg_lcdproc_t * l, const char * desc)
 
   }
 
-static int set_video_description(bg_lcdproc_t * l, const char * desc)
+static int set_video_description(bg_lcdproc_t * l, gavl_metadata_t * m)
   {
+  char * desc;
+  const char * format_str = NULL;
   char * command;
+
+  if(m)
+    format_str = gavl_metadata_get(m, GAVL_META_FORMAT);
+    
+  
+  if(!format_str)
+    desc = NULL;
+  else
+    {
+    desc = bg_sprintf("%s", format_str);
+    }
+  
   if(!desc)
     {
     command = bg_sprintf("widget_set %s %s 1 2 16 3 m 1 {V: Off}",
@@ -586,6 +626,7 @@ static int set_video_description(bg_lcdproc_t * l, const char * desc)
     else
       command = bg_sprintf("widget_set %s %s 1 2 16 3 m 1 {V: %s}",
                            descriptions_name, video_description_name, desc);
+    free(desc);
     }
   if(!send_command(l, command))
     goto fail;
@@ -748,20 +789,24 @@ static void * thread_func(void * data)
             free(arg_str_1);
             }
           break;
-        case BG_PLAYER_MSG_AUDIO_DESCRIPTION:
+        case BG_PLAYER_MSG_AUDIO_STREAM_INFO:
           if(l->have_descriptions)
             {
-            arg_str_1 = bg_msg_get_arg_string(msg, 0);
-            result = set_audio_description(l, arg_str_1);
-            free(arg_str_1);
+            gavl_metadata_t m;
+            gavl_metadata_init(&m);
+            bg_msg_get_arg_metadata(msg, 1, &m);
+            result = set_audio_description(l, &m);
+            gavl_metadata_free(&m);
             }
           break;
-        case BG_PLAYER_MSG_VIDEO_DESCRIPTION:
+        case BG_PLAYER_MSG_VIDEO_STREAM_INFO:
           if(l->have_descriptions)
             {
-            arg_str_1 = bg_msg_get_arg_string(msg, 0);
-            result = set_video_description(l, arg_str_1);
-            free(arg_str_1);
+            gavl_metadata_t m;
+            gavl_metadata_init(&m);
+            bg_msg_get_arg_metadata(msg, 1, &m);
+            result = set_audio_description(l, &m);
+            gavl_metadata_free(&m);
             }
           break;
         case BG_PLAYER_MSG_AUDIO_STREAM:
@@ -805,7 +850,7 @@ static void start_thread(bg_lcdproc_t * l)
   {
   pthread_mutex_lock(&l->state_mutex);
 
-  pthread_create(&l->thread, (pthread_attr_t*)0,
+  pthread_create(&l->thread, NULL,
                  thread_func, l);
 
   l->is_running = 1;
@@ -825,7 +870,7 @@ static void stop_thread(bg_lcdproc_t * l)
 
   pthread_mutex_unlock(&l->state_mutex);
 
-  pthread_join(l->thread, (void**)0);
+  pthread_join(l->thread, NULL);
 
   pthread_mutex_lock(&l->state_mutex);
   l->do_stop = 0;
