@@ -127,7 +127,7 @@ void bg_msg_set_arg_time(bg_msg_t * msg, int arg, gavl_time_t value)
 void * bg_msg_set_arg_ptr(bg_msg_t * msg, int arg, int len)
   {
   if(!check_arg(arg))
-    return (char*)0;
+    return NULL;
   
   msg->args[arg].value.val_ptr = calloc(1, len);
   msg->args[arg].size = len;
@@ -269,10 +269,10 @@ void * bg_msg_get_arg_ptr(bg_msg_t * msg, int arg, int * length)
   void * ret;
   
   if(!check_arg(arg))
-    return (void*)0;
+    return NULL;
 
   ret = msg->args[arg].value.val_ptr;
-  msg->args[arg].value.val_ptr = (void*)0;
+  msg->args[arg].value.val_ptr = NULL;
   if(length)
     *length = msg->args[arg].size;
   return ret;
@@ -289,9 +289,9 @@ char * bg_msg_get_arg_string(bg_msg_t * msg, int arg)
   {
   char * ret;
   if(!check_arg(arg))
-    return (char *)0;
+    return NULL;
   ret = msg->args[arg].value.val_ptr;
-  msg->args[arg].value.val_ptr = (char*)0;
+  msg->args[arg].value.val_ptr = NULL;
   return ret;
   }
 
@@ -474,57 +474,55 @@ void bg_msg_get_arg_video_format(bg_msg_t * msg, int arg,
 
 
 void bg_msg_set_arg_metadata(bg_msg_t * msg, int arg,
-                             const bg_metadata_t * m)
+                             const gavl_metadata_t * m)
   {
+  int i;
+  
   uint8_t * ptr;
   uint8_t * pos;
 
   int len = 4;
-  len += str_len(m->artist);
-  len += str_len(m->title);
-  len += str_len(m->album);
-  len += str_len(m->date);
-  len += str_len(m->genre);
-  len += str_len(m->comment);
-  len += str_len(m->author);
-  len += str_len(m->copyright);
+
+  for(i = 0; i < m->num_tags; i++)
+    {
+    len += str_len(m->tags[i].key);
+    len += str_len(m->tags[i].val);
+    }
   
   ptr = bg_msg_set_arg_ptr(msg, arg, len);
   pos = ptr;
 
-  pos = set_str(pos, m->artist);
-  pos = set_str(pos, m->title);
-  pos = set_str(pos, m->album);
-  pos = set_str(pos, m->date);
-  pos = set_str(pos, m->genre);
-  pos = set_str(pos, m->comment);
-  pos = set_str(pos, m->author);
-  pos = set_str(pos, m->copyright);
-  pos = set_32(pos, m->track);
+  pos = set_32(pos, m->num_tags);
+  for(i = 0; i < m->num_tags; i++)
+    {
+    pos = set_str(pos, m->tags[i].key);
+    pos = set_str(pos, m->tags[i].val);
+    }
   }
 
 void bg_msg_get_arg_metadata(bg_msg_t * msg, int arg,
-                             bg_metadata_t * m)
+                             gavl_metadata_t * m)
   {
-  uint32_t tmp;
+  int i;
+  uint32_t num;
   uint8_t * ptr;
   uint8_t * pos;
-
+  char * key;
+  char * val;
+  
   ptr = bg_msg_get_arg_ptr(msg, arg, NULL);
   
   pos = ptr;
 
-  pos = get_str(pos, &m->artist);
-  pos = get_str(pos, &m->title);
-  pos = get_str(pos, &m->album);
-  pos = get_str(pos, &m->date);
-  pos = get_str(pos, &m->genre);
-  pos = get_str(pos, &m->comment);
-  pos = get_str(pos, &m->author);
-  pos = get_str(pos, &m->copyright);
-  pos = get_32(pos,  &tmp);
-  m->track = tmp;
-  
+  pos = get_32(pos, &num);
+
+  for(i = 0; i < num; i++)
+    {
+    pos = get_str(pos, &key);
+    pos = get_str(pos, &val);
+    gavl_metadata_set_nocpy(m, key, val);
+    free(key);
+    }
   free(ptr);
   }
 
@@ -547,7 +545,7 @@ void bg_msg_free(bg_msg_t * m)
        (m->args[i].value.val_ptr))
       {
       free(m->args[i].value.val_ptr);
-      m->args[i].value.val_ptr = (void*)0;
+      m->args[i].value.val_ptr = NULL;
       }
     }
   }
@@ -752,8 +750,8 @@ bg_msg_queue_t * bg_msg_queue_create()
   
   /* Initialize chain mutex */
 
-  pthread_mutex_init(&ret->chain_mutex,(pthread_mutexattr_t *)0);
-  pthread_mutex_init(&ret->write_mutex,(pthread_mutexattr_t *)0);
+  pthread_mutex_init(&ret->chain_mutex, NULL);
+  pthread_mutex_init(&ret->write_mutex, NULL);
   
   return ret;
   }
@@ -777,7 +775,7 @@ bg_msg_t * bg_msg_queue_lock_read(bg_msg_queue_t * m)
   while(sem_wait(&m->msg_output->produced) == -1)
     {
     if(errno != EINTR)
-      return (void*)0;
+      return NULL;
     }
   return m->msg_output;
   
@@ -789,7 +787,7 @@ bg_msg_t * bg_msg_queue_try_lock_read(bg_msg_queue_t * m)
   if(!sem_trywait(&m->msg_output->produced))
     return m->msg_output;
   else
-    return (bg_msg_t*)0;
+    return NULL;
   }
 
 int bg_msg_queue_peek(bg_msg_queue_t * m, uint32_t * id)
@@ -819,7 +817,7 @@ void bg_msg_queue_unlock_read(bg_msg_queue_t * m)
   m->msg_output = m->msg_output->next;
   m->msg_last->next = old_out_message;
   m->msg_last = m->msg_last->next;
-  m->msg_last->next = (bg_msg_t*)0;
+  m->msg_last->next = NULL;
 
   pthread_mutex_unlock(&m->chain_mutex);
   }
@@ -868,7 +866,7 @@ struct bg_msg_queue_list_s
 bg_msg_queue_list_t * bg_msg_queue_list_create()
   {
   bg_msg_queue_list_t * ret = calloc(1, sizeof(*ret));
-  pthread_mutex_init(&ret->mutex,(pthread_mutexattr_t *)0);
+  pthread_mutex_init(&ret->mutex, NULL);
   return ret;
   }
 
