@@ -34,7 +34,7 @@
 
 static void msg_metadata(bg_msg_t * msg, const void * data)
   {
-  bg_metadata_t * m = (bg_metadata_t *)data;
+  gavl_metadata_t * m = (gavl_metadata_t *)data;
   bg_msg_set_id(msg, BG_PLAYER_MSG_METADATA);
   bg_msg_set_arg_metadata(msg, 0, m);
   }
@@ -143,8 +143,7 @@ static void msg_audio_stream_info(bg_msg_t * msg, const void * data)
   bg_msg_set_id(msg, BG_PLAYER_MSG_AUDIO_STREAM_INFO);
 
   bg_msg_set_arg_int(msg,    0, si->index);
-  bg_msg_set_arg_string(msg, 1, si->track->audio_streams[si->index].info);
-  bg_msg_set_arg_string(msg, 2, si->track->audio_streams[si->index].language);
+  bg_msg_set_arg_metadata(msg, 1, &si->track->audio_streams[si->index].m);
   }
 
 static void msg_video_stream_info(bg_msg_t * msg, const void * data)
@@ -154,8 +153,7 @@ static void msg_video_stream_info(bg_msg_t * msg, const void * data)
   bg_msg_set_id(msg, BG_PLAYER_MSG_VIDEO_STREAM_INFO);
 
   bg_msg_set_arg_int(msg,    0, si->index);
-  bg_msg_set_arg_string(msg, 1, si->track->video_streams[si->index].info);
-  bg_msg_set_arg_string(msg, 2, si->track->video_streams[si->index].language);
+  bg_msg_set_arg_metadata(msg, 1, &si->track->video_streams[si->index].m);
   }
 
 static void msg_subtitle_stream_info(bg_msg_t * msg, const void * data)
@@ -165,30 +163,9 @@ static void msg_subtitle_stream_info(bg_msg_t * msg, const void * data)
   bg_msg_set_id(msg, BG_PLAYER_MSG_SUBTITLE_STREAM_INFO);
 
   bg_msg_set_arg_int(msg,    0, si->index);
-  bg_msg_set_arg_string(msg, 1, si->track->subtitle_streams[si->index].info);
-  bg_msg_set_arg_string(msg, 2, si->track->subtitle_streams[si->index].language);
+  bg_msg_set_arg_metadata(msg, 1, &si->track->subtitle_streams[si->index].m);
   }
 
-static void msg_video_description(bg_msg_t * msg, const void * data)
-  {
-  bg_msg_set_id(msg, BG_PLAYER_MSG_VIDEO_DESCRIPTION);
-  bg_msg_set_arg_string(msg, 0, (char*)data);
-  }
-
-
-static void msg_audio_description(bg_msg_t * msg, const void * data)
-  {
-  bg_msg_set_id(msg, BG_PLAYER_MSG_AUDIO_DESCRIPTION);
-  bg_msg_set_arg_string(msg, 0, (char*)data);
-  }
-
-static void msg_stream_description(bg_msg_t * msg, const void * data)
-  {
-  bg_msg_set_id(msg, BG_PLAYER_MSG_STREAM_DESCRIPTION);
-  bg_msg_set_arg_string(msg, 0, (char*)data);
-  }
-
-
 static void msg_mute(bg_msg_t * msg, const void * data)
   {
   bg_msg_set_id(msg, BG_PLAYER_MSG_MUTE);
@@ -452,7 +429,7 @@ static void init_playback(bg_player_t * p, gavl_time_t time,
         bg_visualizer_close(p->visualizer);
       /* Initialize visualizer */
       bg_visualizer_open_plugin(p->visualizer, &p->audio_stream.fifo_format,
-                                p->video_stream.plugin_handle);
+                                bg_ov_get_plugin(p->video_stream.ov));
       }
     else
       {
@@ -463,13 +440,7 @@ static void init_playback(bg_player_t * p, gavl_time_t time,
   
   /* Send input messages */
   bg_player_input_send_messages(p);
-
   
-  if(p->track_info->description)
-    bg_msg_queue_list_send(p->message_queues,
-                           msg_stream_description,
-                           p->track_info->description);
-
   /* Send metadata */
 
   bg_msg_queue_list_send(p->message_queues,
@@ -533,21 +504,12 @@ static void init_playback(bg_player_t * p, gavl_time_t time,
   /* Send messages about formats */
   if(DO_AUDIO(p->flags))
     {
-    if(p->track_info->audio_streams[p->current_audio_stream].description)
-      bg_msg_queue_list_send(p->message_queues,
-                             msg_audio_description,
-                             p->track_info->audio_streams[p->current_audio_stream].description);
     bg_msg_queue_list_send(p->message_queues,
                            msg_audio_stream,
                            p);
     }
   if(DO_VIDEO(p->flags))
     {
-    if(!DO_SUBTITLE_ONLY(p->flags) &&
-       p->track_info->video_streams[p->current_video_stream].description)
-      bg_msg_queue_list_send(p->message_queues,
-                             msg_video_description,
-                             p->track_info->video_streams[p->current_video_stream].description);
     bg_msg_queue_list_send(p->message_queues,
                            msg_video_stream,
                            p);
@@ -605,9 +567,6 @@ static void init_playback(bg_player_t * p, gavl_time_t time,
   if(flags & BG_PLAY_FLAG_INIT_THEN_PAUSE)
     {
     bg_player_set_state(p, BG_PLAYER_STATE_PAUSED, NULL, NULL);
-
-    
-
     if(DO_VIDEO(p->flags))
       {
       bg_player_ov_reset(p);
@@ -1290,9 +1249,7 @@ static void * player_thread(void * data)
       break;
     
     if(player->flags & PLAYER_FREEZE_FRAME)
-      {
       bg_player_ov_handle_events(&player->video_stream);
-      }
     if(player->flags & PLAYER_FREEZE_VIS)
       bg_visualizer_update(player->visualizer, NULL);    
 
@@ -1325,7 +1282,7 @@ static void * player_thread(void * data)
       }
     gavl_time_delay(&player->wait_time);
     }
-  return (void*)0;
+  return NULL;
   }
 
 void bg_player_broadcast_time(bg_player_t * player, gavl_time_t time)
@@ -1339,7 +1296,7 @@ void bg_player_broadcast_time(bg_player_t * player, gavl_time_t time)
 void bg_player_run(bg_player_t * player)
   {
   pthread_create(&player->player_thread,
-                 (pthread_attr_t*)0,
+                 NULL,
                  player_thread, player);
 
   }
@@ -1352,5 +1309,5 @@ void bg_player_quit(bg_player_t *player)
   bg_msg_queue_unlock_write(player->command_queue);
   
   //  pthread_cancel(player->player_thread);
-  pthread_join(player->player_thread, (void**)0);
+  pthread_join(player->player_thread, NULL);
   }
