@@ -96,10 +96,11 @@ handle_messages(bg_player_video_stream_t * ctx, gavl_time_t time)
       {
       case BG_PLAYER_MSG_VOLUME_CHANGED:
         arg_f = bg_msg_get_arg_float(msg, 0);
-        bg_osd_set_volume_changed(ctx->osd,
-                                  (arg_f - BG_PLAYER_VOLUME_MIN)/
-                                  (-BG_PLAYER_VOLUME_MIN),
-                                  time);
+        if(ctx->osd_ovl)
+          bg_osd_set_volume_changed(ctx->osd,
+                                    (arg_f - BG_PLAYER_VOLUME_MIN)/
+                                    (-BG_PLAYER_VOLUME_MIN),
+                                    time);
         break;
       default:
         break;
@@ -109,91 +110,6 @@ handle_messages(bg_player_video_stream_t * ctx, gavl_time_t time)
     }
   }
 
-/* Create frame */
-
-static gavl_video_frame_t * create_frame(bg_player_video_stream_t * s)
-  {
-  gavl_video_frame_t * ret;
-
-  if(s->plugin->create_frame)
-    {
-    bg_plugin_lock(s->plugin_handle);
-    ret = s->plugin->create_frame(s->priv);
-    bg_plugin_unlock(s->plugin_handle);
-    }
-  else
-    ret = gavl_video_frame_create(&s->output_format);
-
-  gavl_video_frame_clear(ret, &s->output_format);
-  
-  return (void*)ret;
-  }
-
-static void destroy_frame(bg_player_video_stream_t * s,
-                          gavl_video_frame_t * frame)
-  {
-  if(s->plugin->destroy_frame)
-    {
-    bg_plugin_lock(s->plugin_handle);
-    s->plugin->destroy_frame(s->priv, frame);
-    bg_plugin_unlock(s->plugin_handle);
-    }
-  else
-    gavl_video_frame_destroy(frame);
-  }
-
-static gavl_overlay_t * create_overlay(bg_player_video_stream_t * vs,
-                                       int id)
-  {
-  gavl_overlay_t * ret;
-  
-  if(vs->plugin->create_overlay)
-    {
-    bg_plugin_lock(vs->plugin_handle);
-    ret = vs->plugin->create_overlay(vs->priv, id);
-    bg_plugin_unlock(vs->plugin_handle);
-    }
-  else
-    {
-    ret = calloc(1, sizeof(*ret));
-
-    if(id == vs->subtitle_id)
-      ret->frame =
-        gavl_video_frame_create(&vs->ss->output_format);
-    else
-      ret->frame =
-        gavl_video_frame_create(&vs->osd_format);
-    }
-
-  if(id == vs->subtitle_id)
-    gavl_video_frame_clear(ret->frame,
-                           &vs->ss->output_format);
-  else
-    gavl_video_frame_clear(ret->frame,
-                           &vs->osd_format);
-    
-  
-  return ret;
-  }
-
-static void destroy_overlay(bg_player_video_stream_t * vs,
-                            int id, gavl_overlay_t * ovl)
-  {
-  if(vs->plugin->destroy_overlay)
-    {
-    bg_plugin_lock(vs->plugin_handle);
-    vs->plugin->destroy_overlay(vs->priv, id, ovl);
-    bg_plugin_unlock(vs->plugin_handle);
-    }
-  else
-    {
-    gavl_video_frame_destroy(ovl->frame);
-    free(ovl);
-    }
-  }
-
-
-
 void bg_player_ov_create(bg_player_t * player)
   {
   bg_player_video_stream_t * s = &player->video_stream;
@@ -210,27 +126,18 @@ void bg_player_ov_create(bg_player_t * player)
   
   }
 
-void bg_player_add_accelerators(bg_player_t * player, const bg_accelerator_t * list)
+void bg_player_add_accelerators(bg_player_t * player,
+                                const bg_accelerator_t * list)
   {
-  if(player->video_stream.plugin_handle)
-    bg_plugin_lock(player->video_stream.plugin_handle);
-
   bg_accelerator_map_append_array(player->video_stream.accel_map, list);
-  
-  if(player->video_stream.plugin_handle)
-    bg_plugin_unlock(player->video_stream.plugin_handle);
   }
 
 
 void bg_player_ov_standby(bg_player_video_stream_t * ctx)
   {
-  if(!ctx->plugin_handle)
+  if(!ctx->ov)
     return;
-
-  bg_plugin_lock(ctx->plugin_handle);
-  if(ctx->plugin->show_window)
-    ctx->plugin->show_window(ctx->priv, 0);
-  bg_plugin_unlock(ctx->plugin_handle);
+  bg_ov_show_window(ctx->ov, 0);
   }
 
 
@@ -240,21 +147,19 @@ void bg_player_ov_set_plugin(bg_player_t * player, bg_plugin_handle_t * handle)
 
   ctx = &player->video_stream;
 
-  if(ctx->plugin_handle)
-    bg_plugin_unref(ctx->plugin_handle);
-  
-
-  ctx->plugin_handle = handle;
+  if(ctx->ov)
+    {
+    bg_ov_destroy(ctx->ov);
+    ctx->ov = NULL;
+    }
 
   if(handle)
     {
-    ctx->plugin = (bg_ov_plugin_t*)(ctx->plugin_handle->plugin);
-    ctx->priv = ctx->plugin_handle->priv;
-    
-    bg_plugin_lock(ctx->plugin_handle);
-    if(ctx->plugin->set_callbacks)
-      ctx->plugin->set_callbacks(ctx->priv, &ctx->callbacks);
-    bg_plugin_unlock(ctx->plugin_handle);
+    ctx->ov = bg_ov_create(handle);
+    bg_ov_set_callbacks(ctx->ov, &ctx->callbacks);
+
+    /* ov holds a private reference */
+    bg_plugin_unref(handle);
     }
   }
 
@@ -262,22 +167,21 @@ void bg_player_ov_destroy(bg_player_t * player)
   {
   bg_player_video_stream_t * ctx = &player->video_stream;
   
-  if(ctx->plugin_handle)
-    bg_plugin_unref(ctx->plugin_handle);
+  if(ctx->ov)
+    bg_ov_destroy(ctx->ov);
   }
 
 int bg_player_ov_init(bg_player_video_stream_t * vs)
   {
   int result;
   
-  bg_plugin_lock(vs->plugin_handle);
-  result = vs->plugin->open(vs->priv,
-                             &vs->output_format, 1);
+  result = bg_ov_open(vs->ov, &vs->output_format, 1);
   
-  vs->plugin->set_window_title(vs->priv, "Video output");
+  bg_ov_set_window_title(vs->ov, "Video output");
+  
+  if(result)
+    bg_ov_show_window(vs->ov, 1);
   
-  if(result && vs->plugin->show_window)
-    vs->plugin->show_window(vs->priv, 1);
   else if(!result)
     return result;
   
@@ -287,29 +191,37 @@ int bg_player_ov_init(bg_player_video_stream_t * vs)
               &vs->osd_format);
   /* Fixme: Lets just hope, that the OSD format doesn't get changed
      by this call. Otherwise, we would need a gavl_video_converter */
-  vs->osd_id = vs->plugin->add_overlay_stream(vs->priv,
-                                              &vs->osd_format);
+
+  vs->osd_id = bg_ov_add_overlay_stream(vs->ov,  &vs->osd_format);
   
   /* create_overlay needs the lock again */
-  bg_plugin_unlock(vs->plugin_handle);
 
   /* Create frame */
-  vs->frame = create_frame(vs);
   
-  vs->osd_ovl = create_overlay(vs, vs->osd_id);
-  bg_osd_set_overlay(vs->osd, vs->osd_ovl);
+  if(vs->osd_id >= 0)
+    {
+    vs->osd_ovl = bg_ov_create_overlay(vs->ov, vs->osd_id);
+    bg_osd_set_overlay(vs->osd, vs->osd_ovl);
+    }
   vs->frames_written = 0;
   return result;
   }
 
-static int overlay_is_current(gavl_overlay_t * ovl,
+static int overlay_is_expired(gavl_overlay_t * ovl,
                               gavl_time_t frame_time)
   {
-  if(ovl->frame->timestamp == GAVL_TIME_UNDEFINED)
-    return 0;
-  if((ovl->frame->timestamp <= frame_time) &&
-     ((ovl->frame->duration < 0) ||
-      (frame_time < ovl->frame->timestamp + ovl->frame->duration)))
+  if((ovl->frame->duration > 0) &&
+     (ovl->frame->timestamp + ovl->frame->duration < frame_time))
+    {
+    return 1;
+    }
+  return 0;
+  }
+
+static int overlay_is_early(gavl_overlay_t * ovl,
+                            gavl_time_t frame_time)
+  {
+  if(ovl->frame->timestamp > frame_time)
     return 1;
   return 0;
   }
@@ -321,12 +233,9 @@ static void handle_subtitle(bg_player_t * p)
   
   /* Check if subtitle expired */
   if(s->subtitle_active &&
-     !overlay_is_current(s->ss->current_subtitle, s->frame_time))
+     overlay_is_expired(s->ss->current_subtitle, s->frame_time))
     {
-    bg_plugin_lock(s->plugin_handle);
-    s->plugin->set_overlay(s->priv, s->subtitle_id,
-                           NULL);
-    bg_plugin_unlock(s->plugin_handle);
+    bg_ov_set_overlay(s->ov, s->subtitle_id, NULL);
     
     /* Make invalid */
     s->ss->current_subtitle->frame->timestamp = GAVL_TIME_UNDEFINED;
@@ -336,7 +245,6 @@ static void handle_subtitle(bg_player_t * p)
     swp = s->ss->current_subtitle;
     s->ss->current_subtitle = s->ss->next_subtitle;
     s->ss->next_subtitle = swp;
-    
     }
   
   /* Try to read as many subtitles as possible */
@@ -357,17 +265,14 @@ static void handle_subtitle(bg_player_t * p)
   /* Check if the current subtitle became valid */
   if(!s->subtitle_active &&
      (s->ss->current_subtitle->frame->timestamp != GAVL_TIME_UNDEFINED) &&
-     overlay_is_current(s->ss->current_subtitle, s->frame_time))
+     !overlay_is_early(s->ss->current_subtitle, s->frame_time))
     {
-    bg_plugin_lock(s->plugin_handle);
-    s->plugin->set_overlay(s->priv, s->subtitle_id,
-                           s->ss->current_subtitle);
-    bg_plugin_unlock(s->plugin_handle);
+    bg_ov_set_overlay(s->ov, s->subtitle_id, s->ss->current_subtitle);
     s->subtitle_active = 1;
     }
   /* Check if the next subtitle became valid */
   else if((s->ss->next_subtitle->frame->timestamp != GAVL_TIME_UNDEFINED) &&
-          overlay_is_current(s->ss->next_subtitle, s->frame_time))
+          !overlay_is_early(s->ss->next_subtitle, s->frame_time))
     {
     if(s->subtitle_active)
       {
@@ -380,10 +285,7 @@ static void handle_subtitle(bg_player_t * p)
     s->ss->current_subtitle = s->ss->next_subtitle;
     s->ss->next_subtitle = swp;
 
-    bg_plugin_lock(s->plugin_handle);
-    s->plugin->set_overlay(s->priv, s->subtitle_id,
-                           s->ss->current_subtitle);
-    bg_plugin_unlock(s->plugin_handle);
+    bg_ov_set_overlay(s->ov, s->subtitle_id, s->ss->current_subtitle);
     s->subtitle_active = 1;
     }
   }
@@ -391,54 +293,49 @@ static void handle_subtitle(bg_player_t * p)
 
 void bg_player_ov_update_still(bg_player_t * p)
   {
+  gavl_video_frame_t * frame;
   bg_player_video_stream_t * s = &p->video_stream;
   
-  if(s->frame->timestamp == GAVL_TIME_UNDEFINED)
-    {
-    if(!bg_player_read_video(p, s->frame))
-      return;
-    s->frame_time =
-      gavl_time_unscale(s->output_format.timescale,
-                        s->frame->timestamp);
-    }
+  frame = bg_ov_get_frame(s->ov);
+  if(!bg_player_read_video(p, frame))
+    return;
+  s->frame_time =
+    gavl_time_unscale(s->output_format.timescale,
+                      frame->timestamp);
   
   if(DO_SUBTITLE(p->flags))
     handle_subtitle(p);
   
   handle_messages(s, s->frame_time);
   
-  bg_plugin_lock(s->plugin_handle);
-  s->plugin->put_still(s->priv, s->frame);
-  s->plugin->handle_events(s->priv);
-  bg_plugin_unlock(s->plugin_handle);
+  bg_ov_put_still(s->ov, frame);
+  bg_ov_handle_events(s->ov);
   }
 
 void bg_player_ov_cleanup(bg_player_video_stream_t * s)
   {
   if(s->osd_ovl)
     {
-    destroy_overlay(s, s->osd_id, s->osd_ovl);
-    s->osd_ovl = (gavl_overlay_t*)0;
+    bg_ov_destroy_overlay(s->ov, s->osd_id, s->osd_ovl);
+    s->osd_ovl = NULL;
     }
 
-  destroy_frame(s, s->frame);
-  s->frame = NULL;
+  //  destroy_frame(s, s->frame);
+  //  s->frame = NULL;
 
   if(s->ss->subtitles[0])
     {
-    destroy_overlay(s, s->subtitle_id, s->ss->subtitles[0]);
+    bg_ov_destroy_overlay(s->ov, s->subtitle_id, s->ss->subtitles[0]);
     s->ss->subtitles[0] = NULL;
     }
   if(s->ss->subtitles[1])
     {
-    destroy_overlay(s, s->subtitle_id, s->ss->subtitles[1]);
+    bg_ov_destroy_overlay(s->ov, s->subtitle_id, s->ss->subtitles[1]);
     s->ss->subtitles[1] = NULL;
     }
   
-  bg_plugin_lock(s->plugin_handle);
-  s->plugin->close(s->priv);
-  bg_plugin_unlock(s->plugin_handle);
-
+  bg_ov_close(s->ov);
+  
   }
 
 void bg_player_ov_reset(bg_player_t * p)
@@ -448,27 +345,17 @@ void bg_player_ov_reset(bg_player_t * p)
   if(DO_SUBTITLE(p->flags))
     {
     if(s->subtitle_active)
-      {
-      bg_plugin_lock(s->plugin_handle);
-      s->plugin->set_overlay(s->priv, s->subtitle_id,
-                             NULL);
-      bg_plugin_unlock(s->plugin_handle);
-      }
+      bg_ov_set_overlay(s->ov, s->subtitle_id, NULL);
     s->subtitle_active = 0;
     s->ss->current_subtitle->frame->timestamp = GAVL_TIME_UNDEFINED;
     s->ss->next_subtitle->frame->timestamp = GAVL_TIME_UNDEFINED;
     }
-  s->frame->timestamp = GAVL_TIME_UNDEFINED;
-  
   }
 
 void bg_player_ov_update_aspect(bg_player_video_stream_t * ctx,
                                 int pixel_width, int pixel_height)
   {
-  bg_plugin_lock(ctx->plugin_handle);
-  if(ctx->plugin && ctx->plugin->update_aspect)
-    ctx->plugin->update_aspect(ctx->priv, pixel_width, pixel_height);
-  bg_plugin_unlock(ctx->plugin_handle);
+  bg_ov_update_aspect(ctx->ov, pixel_width, pixel_height);
   }
 
 /* Set this extra because we must initialize subtitles after the video output */
@@ -480,13 +367,13 @@ void bg_player_ov_set_subtitle_format(bg_player_video_stream_t * s)
   /* Add subtitle stream for plugin */
   
   s->subtitle_id =
-    s->plugin->add_overlay_stream(s->priv,
+    bg_ov_add_overlay_stream(s->ov,
                                     &s->ss->output_format);
   
   /* Allocate overlay frames */
   
-  s->ss->subtitles[0] = create_overlay(s, s->subtitle_id);
-  s->ss->subtitles[1] = create_overlay(s, s->subtitle_id);
+  s->ss->subtitles[0] = bg_ov_create_overlay(s->ov, s->subtitle_id);
+  s->ss->subtitles[1] = bg_ov_create_overlay(s->ov, s->subtitle_id);
 
   s->ss->subtitles[0]->frame->timestamp = GAVL_TIME_UNDEFINED;  
   s->ss->subtitles[1]->frame->timestamp = GAVL_TIME_UNDEFINED;  
@@ -497,9 +384,7 @@ void bg_player_ov_set_subtitle_format(bg_player_video_stream_t * s)
 
 void bg_player_ov_handle_events(bg_player_video_stream_t * s)
   {
-  bg_plugin_lock(s->plugin_handle);
-  s->plugin->handle_events(s->priv);
-  bg_plugin_unlock(s->plugin_handle);
+  bg_ov_handle_events(s->ov);
   handle_messages(s, s->frame_time);
   }
 
@@ -537,12 +422,14 @@ void * bg_player_ov_thread(void * data)
   gavl_time_t current_time;
   
   bg_player_t * p = data;
+  gavl_video_frame_t * frame;
   
   s = &p->video_stream;
 
   bg_player_add_message_queue(p, s->msg_queue);
 
   bg_player_thread_wait_for_start(s->th);
+
   
   while(1)
     {
@@ -550,7 +437,10 @@ void * bg_player_ov_thread(void * data)
       {
       break;
       }
-    if(!bg_player_read_video(p, s->frame))
+    
+    frame = bg_ov_get_frame(s->ov);
+    
+    if(!bg_player_read_video(p, frame))
       {
       bg_player_video_set_eof(p);
       if(!bg_player_thread_wait_for_start(s->th))
@@ -564,7 +454,7 @@ void * bg_player_ov_thread(void * data)
 
     s->frame_time =
       gavl_time_unscale(s->output_format.timescale,
-                        s->frame->timestamp);
+                        frame->timestamp);
 
     pthread_mutex_lock(&p->config_mutex);
     s->frame_time += p->sync_offset;
@@ -580,10 +470,13 @@ void * bg_player_ov_thread(void * data)
     
     /* Display OSD */
 
-    if(bg_osd_overlay_valid(s->osd, s->frame_time))
-      s->plugin->set_overlay(s->priv, s->osd_id, s->osd_ovl);
-    else
-      s->plugin->set_overlay(s->priv, s->osd_id, (gavl_overlay_t*)0);
+    if(s->osd_id >= 0)
+      {
+      if(bg_osd_overlay_valid(s->osd, s->frame_time))
+        bg_ov_set_overlay(s->ov, s->osd_id, s->osd_ovl);
+      else
+        bg_ov_set_overlay(s->ov, s->osd_id, NULL);
+      }
     
     /* Check Timing */
     bg_player_time_get(p, 1, &current_time);
@@ -603,10 +496,8 @@ void * bg_player_ov_thread(void * data)
       bg_player_broadcast_time(p, s->frame_time);
       }
     
-    bg_plugin_lock(s->plugin_handle);
-    s->plugin->put_video(s->priv, s->frame);
-    s->plugin->handle_events(s->priv);
-    bg_plugin_unlock(s->plugin_handle);
+    bg_ov_put_video(s->ov, frame);
+    bg_ov_handle_events(s->ov);
     s->frames_written++;
     }
   
