@@ -23,6 +23,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
+#include <ctype.h>
 
 
 #include <gmerlin/utils.h> 
@@ -30,12 +31,37 @@
 
 #include <gmerlin/recorder.h>
 #include <recorder_private.h>
+#include <gmerlin/subprocess.h>
+#include <gmerlin/log.h>
+
+#define LOG_DOMAIN "recorder"
 
 const uint32_t bg_recorder_stream_mask =
 BG_STREAM_AUDIO | BG_STREAM_VIDEO;                                   
 
 const uint32_t bg_recorder_plugin_mask = BG_PLUGIN_FILE | BG_PLUGIN_BROADCAST;
 
+static void
+metadata_changed_callback(void * priv, const char * name,
+                          const gavl_metadata_t * m)
+  {
+  bg_recorder_t * rec = priv;
+  if(rec->metadata_mode != BG_RECORDER_METADATA_INPUT)
+    return;
+
+  bg_log(BG_LOG_INFO, LOG_DOMAIN, "New track: %s", name);
+  
+  if(rec->enc && rec->encoding_finalized)
+    {
+    bg_encoder_update_metadata(rec->enc, name, m);
+    }
+  else
+    {
+    gavl_metadata_copy(&rec->updated_metadata, m);
+    rec->updated_name = bg_strdup(rec->updated_name, name);
+    }
+  }
+
 bg_recorder_t * bg_recorder_create(bg_plugin_registry_t * plugin_reg)
   {
   bg_recorder_t * ret = calloc(1, sizeof(*ret));
@@ -58,9 +84,11 @@ bg_recorder_t * bg_recorder_create(bg_plugin_registry_t * plugin_reg)
   ret->th[1] = ret->vs.th;
 
   ret->msg_queues = bg_msg_queue_list_create();
-  pthread_mutex_init(&ret->enc_mutex, NULL);
   pthread_mutex_init(&ret->time_mutex, NULL);
   pthread_mutex_init(&ret->snapshot_mutex, NULL);
+
+  ret->recorder_cb.metadata_changed = metadata_changed_callback;
+  ret->recorder_cb.data = ret;
   
   return ret;
   }
@@ -87,8 +115,11 @@ void bg_recorder_destroy(bg_recorder_t * rec)
   if(rec->snapshot_directory)     free(rec->snapshot_directory);
   if(rec->snapshot_filename_mask) free(rec->snapshot_filename_mask);
 
-  bg_metadata_free(&rec->m);
-  pthread_mutex_destroy(&rec->enc_mutex);
+  gavl_metadata_free(&rec->m);
+  gavl_metadata_free(&rec->updated_metadata);
+  if(rec->updated_name)
+    free(rec->updated_name);
+  
   pthread_mutex_destroy(&rec->time_mutex);
   pthread_mutex_destroy(&rec->snapshot_mutex);
   
@@ -113,6 +144,7 @@ static void init_encoding(bg_recorder_t * rec)
   time_t t;
   char time_string[512];
   char * filename_base;
+  const gavl_metadata_t * m;
   
   time(&t);
   localtime_r(&t, &brokentime);
@@ -128,8 +160,13 @@ static void init_encoding(bg_recorder_t * rec)
                                rec->encoder_section,
                                NULL,
                                bg_recorder_stream_mask, bg_recorder_plugin_mask);
+
+  if(rec->metadata_mode != BG_RECORDER_METADATA_STATIC)
+    m = &rec->updated_metadata;
+  else
+    m = &rec->m;
   
-  bg_encoder_open(rec->enc, filename_base, NULL, NULL);
+  bg_encoder_open(rec->enc, filename_base, m, NULL);
   free(filename_base);
   }
 
@@ -143,6 +180,8 @@ static int finalize_encoding(bg_recorder_t * rec)
   if(rec->vs.flags & STREAM_ACTIVE)
     bg_recorder_video_finalize_encode(rec);
   
+  bg_encoder_update_metadata(rec->enc, rec->updated_name, &rec->updated_metadata);
+  rec->encoding_finalized = 1;
   return 1;
   }
 
@@ -150,6 +189,8 @@ int bg_recorder_run(bg_recorder_t * rec)
   {
   int do_audio = 0;
   int do_video = 0;
+
+  rec->encoding_finalized = 0;
   
   if(rec->flags & FLAG_DO_RECORD)
     {
@@ -170,6 +211,8 @@ int bg_recorder_run(bg_recorder_t * rec)
     else
       do_audio = 1;
     }
+
+  bg_recorder_audio_set_eof(&rec->as, !do_audio);
   
   if(rec->vs.flags & STREAM_ACTIVE)
     {
@@ -178,6 +221,8 @@ int bg_recorder_run(bg_recorder_t * rec)
     else
       do_video = 1;
     }
+
+  bg_recorder_video_set_eof(&rec->vs, !do_video);
   
   if(rec->flags & FLAG_DO_RECORD)
     {
@@ -500,18 +545,52 @@ bg_recorder_set_output_parameter(void * data,
   if(!strcmp(name, "output_directory"))
     rec->output_directory = bg_strdup(rec->output_directory, val->val_str);
   else if(!strcmp(name, "output_filename_mask"))
-    rec->output_filename_mask = bg_strdup(rec->output_filename_mask, val->val_str);
+    rec->output_filename_mask =
+      bg_strdup(rec->output_filename_mask, val->val_str);
   else if(!strcmp(name, "snapshot_directory"))
-    rec->snapshot_directory = bg_strdup(rec->snapshot_directory, val->val_str);
+    rec->snapshot_directory =
+      bg_strdup(rec->snapshot_directory, val->val_str);
   else if(!strcmp(name, "snapshot_filename_mask"))
-    rec->snapshot_filename_mask = bg_strdup(rec->snapshot_filename_mask, val->val_str);
+    rec->snapshot_filename_mask =
+      bg_strdup(rec->snapshot_filename_mask, val->val_str);
   }
 
+static const bg_parameter_info_t common_metadata_parameters[] =
+  {
+    {
+      .name      = "metadata_mode",
+      .long_name = TRS("Metadata mode"),
+      .type      = BG_PARAMETER_STRINGLIST,
+      .val_default = { .val_str = "static" },
+      .multi_names =  (char const *[]){ "static",
+                                        "input",
+                                        "player", NULL },
+      .multi_labels = (char const *[]){ TRS("Static"),
+                                        TRS("From input"),
+                                        TRS("From player"), NULL  },
+    },
+    { /* End of parameters */ },
+  };
+
 const bg_parameter_info_t *
 bg_recorder_get_metadata_parameters(bg_recorder_t * rec)
   {
   if(!rec->metadata_parameters)
-    rec->metadata_parameters = bg_metadata_get_parameters(&rec->m);
+    {
+    bg_parameter_info_t * p;
+    const bg_parameter_info_t * params[3];
+
+    p = bg_metadata_get_parameters(&rec->m);
+
+    params[0] = common_metadata_parameters;
+    params[1] = p;
+    params[2] = NULL;
+    
+    rec->metadata_parameters = bg_parameter_info_concat_arrays(params);
+    
+    bg_parameter_info_destroy_array(p);
+    
+    }
   return rec->metadata_parameters;
   }
 
@@ -521,6 +600,21 @@ bg_recorder_set_metadata_parameter(void * data,
                                    const bg_parameter_value_t * val)
   {
   bg_recorder_t * rec = data;
+
+  if(name)
+    {
+    if(!strcmp(name, "metadata_mode"))
+      {
+      if(!strcmp(val->val_str, "static"))
+        rec->metadata_mode = BG_RECORDER_METADATA_STATIC;
+      else if(!strcmp(val->val_str, "input"))
+        rec->metadata_mode = BG_RECORDER_METADATA_INPUT;
+      else if(!strcmp(val->val_str, "player"))
+        rec->metadata_mode = BG_RECORDER_METADATA_PLAYER;
+      return;
+      }
+    }
+  
   bg_metadata_set_parameter(&rec->m, name, val);
   }
 
@@ -564,5 +658,95 @@ void bg_recorder_snapshot(bg_recorder_t * rec)
   pthread_mutex_lock(&rec->snapshot_mutex);
   rec->snapshot = 1;
   pthread_mutex_unlock(&rec->snapshot_mutex);
-  fprintf(stderr, "Snapshot\n");
+  //  fprintf(stderr, "Snapshot\n");
+  }
+
+static const char * remote_command =
+  "gmerlin_remote -get-name -get-metadata 2>> /dev/null";
+
+#define CHECK_STRING(key, val) \
+  len = strlen(key); \
+  if(!strncmp(key, line, len)) \
+    val = bg_strdup(val, line + len)
+
+
+static void update_metadata(bg_recorder_t * rec)
+  {
+  bg_subprocess_t * sp;
+  char * line = NULL;
+  int line_alloc = 0;
+
+  char * key;
+  char * val;
+  char * pos;
+  
+  gavl_metadata_t m;
+  char * name = NULL;
+
+  gavl_metadata_init(&m);
+  
+  sp = bg_subprocess_create(remote_command, 0, 1, 0);
+  
+  //  fprintf(stderr, "Update metadata\n");
+
+  while(1)
+    {
+    if(!bg_subprocess_read_line(sp->stdout_fd,
+                                &line, &line_alloc, -1))
+      break;
+    //    fprintf(stderr, "Got remote line: %s\n", line);
+
+    pos = strchr(line, ':');
+    if(!pos)
+      continue;
+
+    key = bg_strndup(NULL, line, pos);
+    pos++;
+    while(isspace(*pos))
+      pos++;
+    val = pos;
+
+    gavl_metadata_set(&m, key, val);
+    free(key);
+    }
+  bg_subprocess_close(sp);
+
+  if(!gavl_metadata_equal(&m, &rec->updated_metadata) ||
+     (!rec->updated_name && name) ||
+     (name && rec->updated_name && strcmp(name, rec->updated_name)))
+    {
+    /* Metadata changed */
+
+    if(rec->enc)
+      bg_encoder_update_metadata(rec->enc, name, &m);
+    
+    if(rec->updated_name)
+      free(rec->updated_name);
+    rec->updated_name = name;
+    
+    gavl_metadata_free(&rec->updated_metadata);
+    memcpy(&rec->updated_metadata, &m, sizeof(m));
+
+    if(name)
+      bg_log(BG_LOG_INFO, LOG_DOMAIN, "New track %s", name);
+    }
+  else
+    {
+    free(name);
+    gavl_metadata_free(&m);
+    }
+  }
+
+int bg_recorder_ping(bg_recorder_t * rec)
+  {
+  //  fprintf(stderr, "bg_recorder_ping\n");
+  if(rec->metadata_mode == BG_RECORDER_METADATA_PLAYER)
+    {
+    update_metadata(rec);
+    }
+
+  if(bg_recorder_video_get_eof(&rec->vs) &&
+     bg_recorder_audio_get_eof(&rec->as))
+    return 0;
+  return 1;
   }
