@@ -31,6 +31,8 @@
 #include <gmerlin/log.h>
 #define LOG_DOMAIN "recorder.audio"
 
+#include <gavl/metatags.h>
+
 void bg_recorder_create_audio(bg_recorder_t * rec)
   {
   bg_recorder_audio_stream_t * as = &rec->as;
@@ -44,9 +46,27 @@ void bg_recorder_create_audio(bg_recorder_t * rec)
   as->th = bg_player_thread_create(rec->tc);
 
   as->pd = gavl_peak_detector_create();
-  
+
+  pthread_mutex_init(&as->eof_mutex, NULL);
   }
 
+void bg_recorder_audio_set_eof(bg_recorder_audio_stream_t * s, int eof)
+  {
+  pthread_mutex_lock(&s->eof_mutex);
+  s->eof = eof;
+  pthread_mutex_unlock(&s->eof_mutex);
+  }
+
+int  bg_recorder_audio_get_eof(bg_recorder_audio_stream_t * s)
+  {
+  int ret;
+  pthread_mutex_lock(&s->eof_mutex);
+  ret = s->eof;
+  pthread_mutex_unlock(&s->eof_mutex);
+  return ret;
+  }
+
+
 void bg_recorder_destroy_audio(bg_recorder_t * rec)
   {
   bg_recorder_audio_stream_t * as = &rec->as;
@@ -56,7 +76,8 @@ void bg_recorder_destroy_audio(bg_recorder_t * rec)
   bg_player_thread_destroy(as->th);
 
   gavl_peak_detector_destroy(as->pd);
-  
+  pthread_mutex_destroy(&as->eof_mutex);
+  gavl_metadata_free(&as->m);
   }
 
 static const bg_parameter_info_t parameters[] =
@@ -126,9 +147,7 @@ bg_recorder_set_audio_parameter(void * data,
       as->flags &= ~STREAM_ACTIVE;
     }
   else if(!strcmp(name, "language"))
-    {
-    strncpy(as->language, val->val_str, 3);
-    }
+    gavl_metadata_set(&as->m, GAVL_META_LANGUAGE, val->val_str);
   else if(!strcmp(name, "plugin"))
     {
     const bg_plugin_info_t * info;
@@ -146,7 +165,10 @@ bg_recorder_set_audio_parameter(void * data,
     info = bg_plugin_find_by_name(rec->plugin_reg, val->val_str);
     as->input_handle = bg_plugin_load(rec->plugin_reg, info);
     as->input_plugin = (bg_recorder_plugin_t*)(as->input_handle->plugin);
+    if(as->input_plugin->set_callbacks)
+      as->input_plugin->set_callbacks(as->input_handle->priv, &rec->recorder_cb);
     }
+  
   else if(as->input_handle && as->input_plugin->common.set_parameter)
     {
     as->input_plugin->common.set_parameter(as->input_handle->priv, name, val);
@@ -180,8 +202,7 @@ bg_recorder_set_audio_filter_parameter(void * data,
   bg_audio_filter_chain_lock(as->fc);
   bg_audio_filter_chain_set_parameter(as->fc, name, val);
   
-  if(bg_audio_filter_chain_need_rebuild(as->fc) ||
-     bg_audio_filter_chain_need_restart(as->fc))
+  if(bg_audio_filter_chain_need_restart(as->fc))
     need_restart = 1;
   else
     need_restart = 0;
@@ -192,7 +213,7 @@ bg_recorder_set_audio_filter_parameter(void * data,
 void * bg_recorder_audio_thread(void * data)
   {
   double peaks[2]; /* Doesn't work for > 2 channels!! */
-  
+  gavl_time_t idle_time = GAVL_TIME_SCALE / 100; // 10 ms
   bg_recorder_t * rec = data;
   bg_recorder_audio_stream_t * as = &rec->as;
 
@@ -202,11 +223,20 @@ void * bg_recorder_audio_thread(void * data)
     {
     if(!bg_player_thread_check(as->th))
       break;
+
+    if(bg_recorder_audio_get_eof(as))
+      {
+      gavl_time_delay(&idle_time);
+      continue;
+      }
     
     if(!as->in_func(as->in_data, as->pipe_frame, as->in_stream,
                     as->pipe_format.samples_per_frame))
-      break; /* Should never happen */
-    
+      {
+      bg_log(BG_LOG_ERROR, LOG_DOMAIN, "Read failed (device unplugged?)");
+      bg_recorder_audio_set_eof(as, 1);
+      continue; // Need to go to bg_player_thread_check to stop the thread cleanly
+      }
     /* Peak detection */    
     gavl_peak_detector_update(as->pd, as->pipe_frame);
     gavl_peak_detector_get_peaks(as->pd, NULL, NULL, peaks);
@@ -226,16 +256,10 @@ void * bg_recorder_audio_thread(void * data)
       if(as->do_convert_enc)
         {
         gavl_audio_convert(as->enc_cnv, as->pipe_frame, as->enc_frame);
-        pthread_mutex_lock(&rec->enc_mutex);
         bg_encoder_write_audio_frame(rec->enc, as->enc_frame, as->enc_index);
-        pthread_mutex_unlock(&rec->enc_mutex);
         }
       else
-        {
-        pthread_mutex_lock(&rec->enc_mutex);
         bg_encoder_write_audio_frame(rec->enc, as->pipe_frame, as->enc_index);
-        pthread_mutex_unlock(&rec->enc_mutex);
-        }
       }
     
     }
@@ -284,7 +308,7 @@ int bg_recorder_audio_init(bg_recorder_t * rec)
 
   if(as->flags & STREAM_ENCODE)
     {
-    as->enc_index = bg_encoder_add_audio_stream(rec->enc, as->language,
+    as->enc_index = bg_encoder_add_audio_stream(rec->enc, &as->m,
                                                 &as->pipe_format, 0);
     }
   
