@@ -45,7 +45,7 @@ char * bg_search_file_read(const char * directory, const char * file)
   FILE * testfile;
 
   if(!file)
-    return (char*)0;
+    return NULL;
   
   testpath = malloc(FILENAME_MAX * sizeof(char));
   
@@ -72,7 +72,7 @@ char * bg_search_file_read(const char * directory, const char * file)
     return testpath;
     }
   free(testpath);
-  return (char*)0;
+  return NULL;
   }
 
 char * bg_search_file_write(const char * directory, const char * file)
@@ -84,7 +84,7 @@ char * bg_search_file_write(const char * directory, const char * file)
   FILE * testfile;
 
   if(!file)
-    return (char*)0;
+    return NULL;
   
   home_dir = getenv("HOME");
 
@@ -111,28 +111,40 @@ char * bg_search_file_write(const char * directory, const char * file)
     {
     free(testpath);
     free(testdir);
-    return (char*)0;
+    return NULL;
     }
   }
 
 int bg_ensure_directory(const char * dir)
   {
   char ** directories;
-  char * subpath = (char*)0;
+  char * subpath = NULL;
   int i, ret;
+  int absolute;
   
   /* Return early */
   if(!access(dir, R_OK|W_OK|X_OK))
     return 1;
+
+  if(dir[0] == '/')
+    absolute = 1;
+  else
+    absolute = 0;
   
   /* We omit the first slash */
-  directories = bg_strbreak(dir+1, '/');
-
+  
+  if(absolute)
+    directories = bg_strbreak(dir+1, '/');
+  else
+    directories = bg_strbreak(dir, '/');
+  
   i = 0;
   ret = 1;
   while(directories[i])
     {
-    subpath = bg_strcat(subpath, "/");
+    if(i || absolute)
+      subpath = bg_strcat(subpath, "/");
+
     subpath = bg_strcat(subpath, directories[i]);
 
     if(access(subpath, R_OK) && (errno == ENOENT))
@@ -215,18 +227,18 @@ webbrowsers[] =
 char * bg_find_url_launcher()
   {
   int i;
-  char * ret = (char*)0;
+  char * ret = NULL;
   int ret_alloc = 0;
   bg_subprocess_t * proc;
   /* Try to get the default url handler from gnome */
   
-  if(bg_search_file_exec("gconftool-2", (char**)0))
+  if(bg_search_file_exec("gconftool-2", NULL))
     {
     proc =
       bg_subprocess_create("gconftool-2 -g /desktop/gnome/url-handlers/http/command",
                            0, 1, 0);
     
-    if(bg_subprocess_read_line(proc->stdout_fd, &ret, &ret_alloc, 0))
+    if(bg_subprocess_read_line(proc->stdout_fd, &ret, &ret_alloc, -1))
       {
       bg_subprocess_close(proc);
       return ret;
@@ -237,12 +249,12 @@ char * bg_find_url_launcher()
     }
   for(i = 0; i < sizeof(webbrowsers)/sizeof(webbrowsers[0]); i++)
     {
-    if(bg_search_file_exec(webbrowsers[i].command, (char**)0))
+    if(bg_search_file_exec(webbrowsers[i].command, NULL))
       {
-      return bg_strdup((char*)0, webbrowsers[i].template);
+      return bg_strdup(NULL, webbrowsers[i].template);
       }
     }
-  return (char*)0;
+  return NULL;
   }
 
 void bg_display_html_help(const char * path)
@@ -257,7 +269,7 @@ void bg_display_html_help(const char * path)
   complete_path = bg_sprintf("file://%s/%s", DOC_DIR, path);
   command = bg_sprintf(url_launcher, complete_path);
   command = bg_strcat(command, " &");
-  system(command);
+  bg_system(command);
   free(command);
   free(url_launcher);
   free(complete_path);
