@@ -32,15 +32,16 @@
 #include <config.h>
 #include <gmerlin/translation.h>
 
-
 #include <gmerlin/cfg_registry.h>
 #include <gmerlin/pluginregistry.h>
 #include <gmerlin/pluginfuncs.h>
-#include <config.h>
+
 #include <gmerlin/utils.h>
 #include <gmerlin/singlepic.h>
 #include <gmerlin/log.h>
 
+#include <gavl/metatags.h>
+
 #define LOG_DOMAIN_ENC "singlepicture-encoder"
 #define LOG_DOMAIN_DEC "singlepicture-decoder"
 
@@ -48,12 +49,12 @@ static char * get_extensions(bg_plugin_registry_t * reg,
                              uint32_t type_mask, uint32_t flag_mask)
   {
   int num, i;
-  char * ret = (char*)0;
+  char * ret = NULL;
   const bg_plugin_info_t * info;
   
   num = bg_plugin_registry_get_num_plugins(reg, type_mask, flag_mask);
   if(!num)
-    return (char*)0;
+    return NULL;
 
   for(i = 0; i < num; i++)
     {
@@ -173,8 +174,10 @@ static int open_input(void * priv, const char * filename)
   const char * pos;
   const char * pos_start;
   const char * pos_end;
+  const gavl_metadata_t * m;
   
   input_t * inp = priv;
+
   
   /* Check if the first file exists */
   
@@ -244,15 +247,12 @@ static int open_input(void * priv, const char * filename)
       break;
     inp->frame_end++;
     }
-
+  
   /* Create stream */
-    
+  
   inp->track_info.num_video_streams = 1;
   inp->track_info.video_streams =
     calloc(1, sizeof(*inp->track_info.video_streams));
-
-  inp->track_info.video_streams[0].description =
-    bg_strdup(NULL, "Single images");
   
   inp->track_info.duration = gavl_frames_to_time(inp->timescale,
                                                  inp->frame_duration,
@@ -269,6 +269,8 @@ static int open_input(void * priv, const char * filename)
 
   sprintf(inp->filename_buffer, inp->template, inp->current_frame);
 
+  /* Load image header */
+  
   if(!inp->image_reader->read_header(inp->handle->priv,
                                      inp->filename_buffer,
                                      &inp->track_info.video_streams[0].format))
@@ -280,13 +282,28 @@ static int open_input(void * priv, const char * filename)
   inp->track_info.video_streams[0].format.framerate_mode =
     GAVL_FRAMERATE_CONSTANT;
   inp->header_read = 1;
+
+  /* Metadata */
+
+  if(inp->image_reader->get_metadata &&
+     (m = inp->image_reader->get_metadata(inp->handle->priv)))
+    {
+    gavl_metadata_copy(&inp->track_info.metadata, m);
+    }
+  
+  gavl_metadata_set(&inp->track_info.video_streams[0].m,
+                    GAVL_META_FORMAT, "Single images");
+
   
   return 1;
   }
 
 static int open_stills_input(void * priv, const char * filename)
   {
+  const char * tag;
   const bg_plugin_info_t * info;
+  const gavl_metadata_t * m;
+  
   input_t * inp = priv;
   
   /* Check if the first file exists */
@@ -303,6 +320,15 @@ static int open_stills_input(void * priv, const char * filename)
     return 0;
   
   inp->handle = bg_plugin_load(inp->plugin_reg, info);
+
+  if(!inp->handle)
+    {
+    bg_log(BG_LOG_ERROR, LOG_DOMAIN_DEC,
+           "Plugin %s could not be loaded",
+           info->name);
+    return 0;
+    }
+  
   inp->image_reader = (bg_image_reader_plugin_t*)inp->handle->plugin;
   
   /* Create stream */
@@ -311,8 +337,6 @@ static int open_stills_input(void * priv, const char * filename)
   inp->track_info.video_streams =
     calloc(1, sizeof(*inp->track_info.video_streams));
 
-  inp->track_info.video_streams[0].description =
-    bg_strdup(NULL, "Still Image");
   
   inp->track_info.video_streams[0].format.framerate_mode =
     GAVL_FRAMERATE_STILL;
@@ -332,6 +356,28 @@ static int open_stills_input(void * priv, const char * filename)
   inp->track_info.video_streams[0].format.timescale = GAVL_TIME_SCALE;
   inp->track_info.video_streams[0].format.frame_duration = 0;
   inp->track_info.video_streams[0].format.framerate_mode = GAVL_FRAMERATE_STILL;
+
+  /* Metadata */
+
+  if(inp->image_reader->get_metadata &&
+     (m = inp->image_reader->get_metadata(inp->handle->priv)))
+    {
+    gavl_metadata_copy(&inp->track_info.metadata, m);
+    }
+
+  tag = gavl_metadata_get(&inp->track_info.metadata,
+                          GAVL_META_FORMAT);
+  if(tag)
+    gavl_metadata_set(&inp->track_info.video_streams[0].m,
+                      GAVL_META_FORMAT, tag);
+  else
+    gavl_metadata_set(&inp->track_info.video_streams[0].m,
+                      GAVL_META_FORMAT, "Image");
+  
+  gavl_metadata_set(&inp->track_info.metadata,
+                    GAVL_META_FORMAT, "Still image");
+
+
   inp->header_read = 1;
 
   return 1;
@@ -486,7 +532,7 @@ static int set_track_input_stills(void * priv, int track)
   if(inp->header_read)
     {
     inp->image_reader->read_image(inp->handle->priv,
-                                  (gavl_video_frame_t*)0);
+                                  NULL);
     inp->header_read = 0;
     }
   return 1;
@@ -517,12 +563,12 @@ static void close_input(void * priv)
   if(inp->template)
     {
     free(inp->template);
-    inp->template = (char*)0;
+    inp->template = NULL;
     }
   if(inp->filename_buffer)
     {
     free(inp->filename_buffer);
-    inp->filename_buffer = (char*)0;
+    inp->filename_buffer = NULL;
     }
   bg_track_info_free(&inp->track_info);
   
@@ -652,25 +698,12 @@ static bg_plugin_info_t * get_input_info(bg_plugin_registry_t * reg,
   
   if(!bg_plugin_registry_get_num_plugins(reg, BG_PLUGIN_IMAGE_READER,
                                          BG_PLUGIN_FILE))
-    return (bg_plugin_info_t *)0;
-  
-  ret = calloc(1, sizeof(*ret));
+    return NULL;
 
-  ret->gettext_domain      = bg_strdup(ret->gettext_domain, plugin->common.gettext_domain);
-  
-  ret->gettext_directory   = bg_strdup(ret->gettext_directory,
-                                       plugin->common.gettext_directory);
-  
-  
-  ret->name      = bg_strdup(ret->name, plugin->common.name);
-  ret->long_name = bg_strdup(ret->long_name, plugin->common.long_name);
-  ret->description = bg_strdup(ret->description, plugin->common.description);
+  ret = bg_plugin_info_create(&plugin->common);
   
   ret->extensions = get_extensions(reg, BG_PLUGIN_IMAGE_READER,
                                    BG_PLUGIN_FILE);
-  ret->priority  =  plugin->common.priority;
-  ret->type  =  plugin->common.type;
-  ret->flags =  plugin->common.flags;
   return ret;
   }
 
@@ -747,7 +780,7 @@ typedef struct
   bg_plugin_handle_t * plugin_handle;
   bg_image_writer_plugin_t * image_writer;
   
-  bg_metadata_t metadata;
+  gavl_metadata_t metadata;
   
   bg_parameter_info_t * parameters;
 
@@ -817,7 +850,7 @@ static void set_parameter_encoder(void * priv, const char * name,
       if(e->plugin_handle)
         {
         bg_plugin_unref(e->plugin_handle);
-        e->plugin_handle = (bg_plugin_handle_t*)0;
+        e->plugin_handle = NULL;
         }
       info = bg_plugin_find_by_name(e->plugin_reg, val->val_str);
       e->plugin_handle = bg_plugin_load(e->plugin_reg, info);
@@ -865,7 +898,7 @@ static void create_mask(encoder_t * e, const char * ext)
   }
 
 static int open_encoder(void * data, const char * filename,
-                        const bg_metadata_t * metadata,
+                        const gavl_metadata_t * metadata,
                         const bg_chapter_list_t * chapter_list)
   {
   encoder_t * e;
@@ -876,7 +909,7 @@ static int open_encoder(void * data, const char * filename,
   e->filename_base = bg_strdup(e->filename_base, filename);
   
   if(metadata)
-    bg_metadata_copy(&e->metadata, metadata);
+    gavl_metadata_copy(&e->metadata, metadata);
   
   return 1;
   }
@@ -923,7 +956,9 @@ static int writes_compressed_video(void * priv,
 
 
 
-static int add_video_stream_encoder(void * data, const gavl_video_format_t * format)
+static int add_video_stream_encoder(void * data,
+                                    const gavl_metadata_t * m,
+                                    const gavl_video_format_t * format)
   {
   char ** extensions;
   encoder_t * e = data;
@@ -941,7 +976,9 @@ static int add_video_stream_encoder(void * data, const gavl_video_format_t * for
   }
 
 static int
-add_video_stream_compressed_encoder(void * data, const gavl_video_format_t * format,
+add_video_stream_compressed_encoder(void * data,
+                                    const gavl_metadata_t * m,
+                                    const gavl_video_format_t * format,
                                     const gavl_compression_info_t * info)
   {
   encoder_t * e;
@@ -1006,7 +1043,7 @@ static int write_video_packet_encoder(void * data, gavl_packet_t * packet,
   return 1;
   }
 
-#define STR_FREE(s) if(s){free(s);s=(char*)0;}
+#define STR_FREE(s) if(s){free(s);s=NULL;}
 
 static int close_encoder(void * data, int do_delete)
   {
@@ -1027,12 +1064,12 @@ static int close_encoder(void * data, int do_delete)
   STR_FREE(e->filename_buffer);
   STR_FREE(e->filename_base);
   
-  bg_metadata_free(&e->metadata);
+  gavl_metadata_free(&e->metadata);
   
   if(e->plugin_handle)
     {
     bg_plugin_unref(e->plugin_handle);
-    e->plugin_handle = (bg_plugin_handle_t*)0;
+    e->plugin_handle = NULL;
     }
   return 1;
   }
@@ -1110,25 +1147,9 @@ bg_plugin_info_t * bg_singlepic_encoder_info(bg_plugin_registry_t * reg)
   
   if(!bg_plugin_registry_get_num_plugins(reg, BG_PLUGIN_IMAGE_WRITER,
                                          BG_PLUGIN_FILE))
-    return (bg_plugin_info_t *)0;
-  
-  ret = calloc(1, sizeof(*ret));
-
-  ret->gettext_domain      = bg_strdup(ret->gettext_domain, encoder_plugin.common.gettext_domain);
-  ret->gettext_directory   = bg_strdup(ret->gettext_directory,
-                                       encoder_plugin.common.gettext_directory);
-  
-  
-  ret->name      = bg_strdup(ret->name, encoder_plugin.common.name);
-  ret->long_name = bg_strdup(ret->long_name, encoder_plugin.common.long_name);
-  ret->description = bg_strdup(ret->description,
-                               encoder_plugin.common.description);
-  
-  ret->type     = encoder_plugin.common.type;
-  ret->flags    = encoder_plugin.common.flags;
-  ret->priority = encoder_plugin.common.priority;
+    return NULL;
+  ret = bg_plugin_info_create(&encoder_plugin.common);
   ret->parameters = create_encoder_parameters(reg);
-  
   return ret;
   }
 
