@@ -47,6 +47,8 @@
 
 #include <gmerlin/translation.h>
 
+#include <gavl/metatags.h>
+
 
 #include <md5.h>
 
@@ -64,7 +66,7 @@ char * bg_fix_path(char * path)
   if(!len)
     {
     free(path);
-    return (char*)0;
+    return NULL;
     }
   if(path[len-1] != '/')
     {
@@ -88,7 +90,7 @@ char * bg_strdup(char * old_string, const char * new_string)
     {
     if(old_string)
       free(old_string);
-    return (char*)0;
+    return NULL;
     }
 
   if(old_string)
@@ -114,7 +116,7 @@ char * bg_strndup(char * old_string,
     {
     if(old_string)
       free(old_string);
-    return (char*)0;
+    return NULL;
     }
 
   if(old_string)
@@ -141,7 +143,7 @@ char * bg_sprintf(const char * format,...)
   va_start( argp, format);
 
 #ifndef HAVE_VASPRINTF
-  len = vsnprintf((char*)0, 0, format, argp);
+  len = vsnprintf(NULL, 0, format, argp);
   ret = malloc(len+1);
   vsnprintf(ret, len+1, format, argp);
 #else
@@ -183,7 +185,7 @@ char * bg_create_unique_filename(char * template)
       if(err)
         {
         free(filename);
-        return (char*)0;
+        return NULL;
         }
       else
         return filename;
@@ -196,7 +198,7 @@ char * bg_create_unique_filename(char * template)
 char * bg_strcat(char * old_string, const char * tail)
   {
   if(!old_string)
-    return bg_strdup((char*)0, tail);
+    return bg_strdup(NULL, tail);
 
   old_string = realloc(old_string, strlen(old_string) + strlen(tail) + 1);
   strcat(old_string, tail);
@@ -208,7 +210,7 @@ char * bg_strncat(char * old_string, const char * start, const char * end)
   int old_len;
   
   if(!old_string)
-    return bg_strndup((char*)0, start, end);
+    return bg_strndup(NULL, start, end);
 
   old_len = strlen(old_string);
   
@@ -226,7 +228,7 @@ char ** bg_strbreak(const char * str, char delim)
   char ** ret;
   int i;
   if(!str || (*str == '\0'))
-    return (char**)0;
+    return NULL;
     
   pos_c = str;
   
@@ -238,7 +240,7 @@ char ** bg_strbreak(const char * str, char delim)
     }
   ret = calloc(num_entries+1, sizeof(char*));
 
-  ret[0] = bg_strdup((char*)0, str);
+  ret[0] = bg_strdup(NULL, str);
   pos = ret[0];
   for(i = 0; i < num_entries; i++)
     {
@@ -307,7 +309,7 @@ int bg_url_split(const char * url,
   /* Protocol */
     
   if(protocol)
-    *protocol = bg_strndup((char*)0, pos1, pos2);
+    *protocol = bg_strndup(NULL, pos1, pos2);
 
   pos2 += 3;
   pos1 = pos2;
@@ -323,10 +325,10 @@ int bg_url_split(const char * url,
      (at_pos < slash_pos))
     {
     if(user)
-      *user = bg_strndup((char*)0, pos1, colon_pos);
+      *user = bg_strndup(NULL, pos1, colon_pos);
     pos1 = colon_pos + 1;
     if(password)
-      *password = bg_strndup((char*)0, pos1, at_pos);
+      *password = bg_strndup(NULL, pos1, at_pos);
     pos1 = at_pos + 1;
     pos2 = pos1;
     }
@@ -337,7 +339,7 @@ int bg_url_split(const char * url,
     pos2++;
 
   if(hostname)
-    *hostname = bg_strndup((char*)0, pos1, pos2);
+    *hostname = bg_strndup(NULL, pos1, pos2);
 
   switch(*pos2)
     {
@@ -365,9 +367,9 @@ int bg_url_split(const char * url,
     pos1 = pos2;
     pos2 = pos1 + strlen(pos1);
     if(pos1 != pos2)
-      *path = bg_strndup((char*)0, pos1, pos2);
+      *path = bg_strndup(NULL, pos1, pos2);
     else
-      *path = (char*)0;
+      *path = NULL;
     }
   return 1;
   }
@@ -403,7 +405,7 @@ char * bg_descramble_string(const char *str)
   int error;
   
   if (*str != '$')
-    return (bg_strdup ((char*)0, str));
+    return (bg_strdup (NULL, str));
   
   strpos = str + 1;
   newstr = malloc (strlen (strpos) / 2 + 1);
@@ -428,7 +430,7 @@ char * bg_descramble_string(const char *str)
   if(error)
     {
     free (newstr);
-    return (bg_strdup((char*)0, str));
+    return (bg_strdup(NULL, str));
     }
   
   *newpos = '\0';
@@ -446,7 +448,7 @@ const char * bg_get_language_name(const char * iso)
       return bg_language_labels[i];
     i++;
     }
-  return (char*)0;
+  return NULL;
   }
 
 int bg_string_match(const char * key,
@@ -518,7 +520,7 @@ char * bg_toupper(const char * str)
     }
   *pos_2 = 0;
 
-  ret = bg_convert_string(cnv2, tmp_string_2, len, (int*)0);
+  ret = bg_convert_string(cnv2, tmp_string_2, len, NULL);
 
   free(tmp_string_1);
   free(tmp_string_2);
@@ -576,14 +578,20 @@ char * bg_filename_ensure_extension(const char * filename,
     return bg_sprintf("%s.%s", filename, ext);
   }
 
-char * bg_get_stream_label(int index, const char * info, const char * language)
+char * bg_get_stream_label(int index, const gavl_metadata_t * m)
   {
   char * label;
-  if(info && language && *language)
+  const char * info;
+  const char * language;
+  
+  info = gavl_metadata_get(m, GAVL_META_LABEL);
+  language = gavl_metadata_get(m, GAVL_META_LANGUAGE);
+  
+  if(info && language)
     label = bg_sprintf("%s [%s]", info, bg_get_language_name(language));
   else if(info)
     label = bg_sprintf("%s", info);
-  else if(language && *language)
+  else if(language)
     label = bg_sprintf(TR("Stream %d [%s]"), index+1, bg_get_language_name(language));
   else
     label = bg_sprintf(TR("Stream %d"), index+1);
@@ -600,3 +608,94 @@ char * bg_canonical_filename(const char * name)
   return ret;
 #endif
   }
+
+void * bg_read_file(const char * filename, int * len_ret)
+  {
+  uint8_t * ret;
+  FILE * file;
+  size_t len;
+  
+  file = fopen(filename, "r");
+  if(!file)
+    return NULL;
+
+  fseek(file, 0, SEEK_END);
+  len = ftell(file);
+  fseek(file, 0, SEEK_SET);
+
+  ret = malloc(len + 1);
+
+  if(fread(ret, 1, len, file) < len)
+    {
+    fclose(file);
+    free(ret);
+    return NULL;
+    }
+  ret[len] = '\0';
+  fclose(file);
+
+  if(len_ret)
+    *len_ret = len;
+  
+  return ret;
+  }
+
+int bg_write_file(const char * filename, void * data, int len)
+  {
+  FILE * file;
+  
+  file = fopen(filename, "w");
+  if(!file)
+    return 0;
+  
+  if(fwrite(data, 1, len, file) < len)
+    {
+    fclose(file);
+    return 0;
+    }
+  fclose(file);
+  return 1;
+  }
+
+
+static const struct
+  {
+  const char * bcode;
+  const char * tcode;
+  }
+iso639tab[] =
+  {
+    { "alb", "sqi" },
+    { "arm", "hye" },
+    { "baq", "eus" },
+    { "bur", "mya" },
+    { "chi", "zho" },
+    { "cze", "ces" },
+    { "dut", "nld" },
+    { "fre", "fra" },
+    { "geo", "kat" },
+    { "ger", "deu" },
+    { "gre", "ell" },
+    { "ice", "isl" },
+    { "mac", "mkd" },
+    { "mao", "mri" },
+    { "may", "msa" },
+    { "per", "fas" },
+    { "rum", "ron" },
+    { "slo", "slk" },
+    { "tib", "bod" },
+    { "wel", "cym" },
+    { /* End */    }
+  };
+
+const char * bg_iso639_b_to_t(const char * code)
+  {
+  int i = 0;
+  while(iso639tab[i].bcode)
+    {
+    if(!strcmp(code, iso639tab[i].bcode))
+      return iso639tab[i].tcode;
+    i++;
+    }
+  return code;
+  }
