@@ -45,7 +45,13 @@
 #include <gmerlin/filters.h>
 #include <gmerlin/encoder.h>
 
+#include <gmerlin/subprocess.h>
+
+#include <gavl/metatags.h>
+
+
 // #define DUMP_VIDEO_TIMESTAMPS
+// #define DUMP_AUDIO_TIMESTAMPS
 
 #define LOG_DOMAIN "transcoder"
 
@@ -84,11 +90,17 @@ static void copy_language(char * dst, const char * src)
     *dst = '\0';
   }
 
-static char * get_language(char * in_lang, char * lang, int force)
+static void get_language(char * in_lang, char * lang, int force,
+                         gavl_metadata_t * m)
   {
+  char * ret;
+  
   if(in_lang)
-    return force ? lang : in_lang;
-  return lang;
+    ret = force ? lang : in_lang;
+  else
+    ret = lang;
+
+  gavl_metadata_set(m, GAVL_META_LANGUAGE, ret);
   }
 
 typedef struct subtitle_stream_s subtitle_stream_t;
@@ -114,6 +126,8 @@ typedef struct
   
   gavl_compression_info_t ci;
   gavl_packet_t packet;
+
+  gavl_metadata_t m;
   
   } stream_t;
 
@@ -305,6 +319,9 @@ struct subtitle_stream_s
   char in_language[4];
   char out_language[4];
   int force_language;
+
+  int64_t time_offset;
+  int64_t time_offset_scaled;
   };
 
 typedef struct
@@ -332,24 +349,28 @@ static void set_subtitle_parameter_general(void * data,
 
   if(!strcmp(name, "video_stream"))
     stream->video_stream = val->val_i-1;
-  if(!strcmp(name, "in_language"))
+  else if(!strcmp(name, "in_language"))
     {
     copy_language(stream->in_language, val->val_str);
     return;
     }
-  if(!strcmp(name, "language"))
+  else if(!strcmp(name, "language"))
     {
     copy_language(stream->out_language, val->val_str);
     return;
     }
-  if(!strcmp(name, "force_language"))
+  else if(!strcmp(name, "force_language"))
     {
     stream->force_language = val->val_i;
     return;
     }
-
-  if(set_stream_parameters_general(&stream->com,
-                                   name, val))
+  else if(!strcmp(name, "time_offset"))
+    {
+    stream->time_offset = (int64_t)(val->val_f * GAVL_TIME_SCALE + 0.5);
+    return;
+    }
+  else if(set_stream_parameters_general(&stream->com,
+                                        name, val))
     return;
   }
 
@@ -398,8 +419,8 @@ struct bg_transcoder_s
   gavl_time_t end_time;
   int set_start_time;
   int set_end_time;
-  
-  bg_metadata_t metadata;
+  int prefer_edl;
+  gavl_metadata_t metadata;
   
   /* General configuration stuff */
 
@@ -729,17 +750,17 @@ static void set_message_error(bg_msg_t * msg, const void * data)
 
 void bg_transcoder_send_msg_error(bg_msg_queue_list_t * l)
   {
-  bg_msg_queue_list_send(l, set_message_error, (void*)0);
+  bg_msg_queue_list_send(l, set_message_error, NULL);
   }
 
 
 static void set_message_metadata(bg_msg_t * msg, const void * data)
   {
   bg_msg_set_id(msg, BG_TRANSCODER_MSG_METADATA);
-  bg_msg_set_arg_metadata(msg, 0, (const bg_metadata_t*)data);
+  bg_msg_set_arg_metadata(msg, 0, (const gavl_metadata_t*)data);
   }
 
-void bg_transcoder_send_msg_metadata(bg_msg_queue_list_t * l, bg_metadata_t * m)
+void bg_transcoder_send_msg_metadata(bg_msg_queue_list_t * l, gavl_metadata_t * m)
   {
   bg_msg_queue_list_send(l,
                          set_message_metadata, m);
@@ -764,7 +785,7 @@ static int decode_video_frame(void * priv, gavl_video_frame_t * f, int stream)
     return 0;
 
 #ifdef DUMP_VIDEO_TIMESTAMPS
-  bg_debug("Input timestamp: %"PRId64" Offset: %"PRId64"\n",
+  bg_debug("Input timestamp (video): %"PRId64" Offset: %"PRId64"\n",
            f->timestamp, s->start_time_scaled);
 #endif
   
@@ -785,7 +806,6 @@ static int decode_video_frame(void * priv, gavl_video_frame_t * f, int stream)
   return 1;
   }
 
-
 static void init_audio_stream(audio_stream_t * ret,
                               bg_transcoder_track_audio_t * s,
                               int in_index, bg_plugin_registry_t * plugin_reg)
@@ -997,15 +1017,15 @@ static void set_input_formats(bg_transcoder_t * ret)
 static void add_audio_stream(audio_stream_t * ret,
                              bg_transcoder_t * t)
   {
-  char * language;
   
   ret->in_func = ret->com.in_plugin->read_audio;
   ret->in_data = ret->com.in_handle->priv;
   ret->in_stream = ret->com.in_index;
   
   /* We set the frame size so we have roughly half second long audio chunks */
-  ret->in_format.samples_per_frame = gavl_time_to_samples(ret->in_format.samplerate,
-                                                          GAVL_TIME_SCALE/2);
+  ret->in_format.samples_per_frame =
+    gavl_time_to_samples(ret->in_format.samplerate,
+                         GAVL_TIME_SCALE/2);
   
   bg_audio_filter_chain_connect_input(ret->fc,
                                       ret->in_func,
@@ -1014,8 +1034,9 @@ static void add_audio_stream(audio_stream_t * ret,
   
   bg_audio_filter_chain_init(ret->fc, &ret->in_format, &ret->pipe_format);
 
-  ret->pipe_format.samples_per_frame = gavl_time_to_samples(ret->pipe_format.samplerate,
-                                                            GAVL_TIME_SCALE/2);
+  ret->pipe_format.samples_per_frame =
+    gavl_time_to_samples(ret->pipe_format.samplerate,
+                         GAVL_TIME_SCALE/2);
   
   ret->in_func = bg_audio_filter_chain_read;
   ret->in_data = ret->fc;
@@ -1025,15 +1046,16 @@ static void add_audio_stream(audio_stream_t * ret,
                          &ret->pipe_format);
   
   /* Decide language */
-  language = get_language(ret->in_language,
-                          ret->out_language,
-                          ret->force_language);
+  get_language(ret->in_language,
+               ret->out_language,
+               ret->force_language,
+               &ret->com.m);
   
   /* Add the audio stream */
 
   ret->com.out_index =
     bg_encoder_add_audio_stream(t->enc,
-                                language,
+                                &ret->com.m,
                                 &ret->out_format,
                                 ret->com.in_index);
   }
@@ -1041,17 +1063,17 @@ static void add_audio_stream(audio_stream_t * ret,
 static void add_audio_stream_compressed(audio_stream_t * ret,
                                         bg_transcoder_t * t)
   {
-  char * language;
   /* Decide language */
-  language = get_language(ret->in_language,
-                          ret->out_language,
-                          ret->force_language);
+  get_language(ret->in_language,
+               ret->out_language,
+               ret->force_language,
+               &ret->com.m);
   
   /* Add the audio stream */
   
   ret->com.out_index =
     bg_encoder_add_audio_stream_compressed(t->enc,
-                                           language,
+                                           &ret->com.m,
                                            &ret->in_format,
                                            &ret->com.ci,
                                            ret->com.in_index);
@@ -1063,13 +1085,13 @@ static void add_subtitle_text_stream(subtitle_text_stream_t * ret,
                                      bg_transcoder_track_subtitle_text_t * s,
                                      bg_transcoder_t * t)
   {
-  char * language;
   if(ret->com.com.action == STREAM_ACTION_TRANSCODE)
     {
     /* Decide language */
-    language = get_language(ret->com.in_language,
-                            ret->com.out_language,
-                            ret->com.force_language);
+    get_language(ret->com.in_language,
+                 ret->com.out_language,
+                 ret->com.force_language,
+                 &ret->com.com.m);
 
     gavl_video_format_copy(&ret->com.out_format,
                            &ret->com.in_format);
@@ -1078,7 +1100,8 @@ static void add_subtitle_text_stream(subtitle_text_stream_t * ret,
     /* TODO: timescale might get changed by the encoder!!! */
     ret->com.com.out_index =
       bg_encoder_add_subtitle_text_stream(t->enc,
-                                          language, ret->com.out_format.timescale,
+                                          &ret->com.com.m,
+                                          ret->com.out_format.timescale,
                                           ret->com.com.in_index);
     
     }
@@ -1102,35 +1125,37 @@ static void add_subtitle_text_stream(subtitle_text_stream_t * ret,
       }
 
     /* Decide language */
-    language = get_language(ret->com.in_language,
-                            ret->com.out_language,
-                            ret->com.force_language);
+    get_language(ret->com.in_language,
+                 ret->com.out_language,
+                 ret->com.force_language,
+                 &ret->com.com.m);
     
     ret->com.com.out_index =
       bg_encoder_add_subtitle_overlay_stream(t->enc,
-                                             language,
-                                             &ret->com.out_format, ret->com.com.in_index,
+                                             &ret->com.com.m,
+                                             &ret->com.out_format,
+                                             ret->com.com.in_index,
                                              BG_STREAM_SUBTITLE_TEXT);
     }
   }
 
-static void add_subtitle_overlay_stream(subtitle_stream_t * ret,
-                                        bg_transcoder_track_subtitle_overlay_t * s,
-                                        bg_transcoder_t * t)
+static void
+add_subtitle_overlay_stream(subtitle_stream_t * ret,
+                            bg_transcoder_track_subtitle_overlay_t * s,
+                            bg_transcoder_t * t)
   {
-  char * language;
-  
   gavl_video_format_copy(&ret->out_format, &ret->in_format);
 
   /* Decide language */
 
-  language = get_language(ret->in_language,
-                          ret->out_language,
-                          ret->force_language);
+  get_language(ret->in_language,
+               ret->out_language,
+               ret->force_language,
+               &ret->com.m);
   
   ret->com.out_index =
     bg_encoder_add_subtitle_overlay_stream(t->enc,
-                                           language,
+                                           &ret->com.m,
                                            &ret->out_format, ret->com.in_index,
                                            BG_STREAM_SUBTITLE_OVERLAY);
   }
@@ -1155,6 +1180,7 @@ static void add_video_stream(video_stream_t * ret,
 
   ret->com.out_index =
     bg_encoder_add_video_stream(t->enc,
+                                &ret->com.m,
                                 &ret->out_format,
                                 ret->com.in_index);
   }
@@ -1166,6 +1192,7 @@ static void add_video_stream_compressed(video_stream_t * ret,
 
   ret->com.out_index =
     bg_encoder_add_video_stream_compressed(t->enc,
+                                           &ret->com.m,
                                            &ret->in_format,
                                            &ret->com.ci,
                                            ret->com.in_index);
@@ -1271,7 +1298,7 @@ static int audio_iteration(audio_stream_t*s, bg_transcoder_t * t)
         gavl_volume_control_apply(s->volume_control, frame);
         }
       else if((t->pass > 1) && (t->pass < t->total_passes))
-        frame = (gavl_audio_frame_t*)0;
+        frame = NULL;
       }
   
     /* Output conversion */
@@ -1292,14 +1319,19 @@ static int audio_iteration(audio_stream_t*s, bg_transcoder_t * t)
       if(t->pass == 1)
         {
         gavl_peak_detector_update(s->peak_detector, frame);
-        frame = (gavl_audio_frame_t*)0;
+        frame = NULL;
         }
       }
     if(frame)
+      {
+#ifdef DUMP_AUDIO_TIMESTAMPS
+      bg_debug("Output timestamp (audio): %"PRId64"\n",
+               frame->timestamp);
+#endif
       ret = bg_encoder_write_audio_frame(t->enc,
                                          frame,
                                          s->com.out_index);
-    
+      }
 
     s->com.time = gavl_samples_to_time(s->out_format.samplerate,
                                        s->samples_read);
@@ -1322,8 +1354,11 @@ static void correct_subtitle_timestamp(subtitle_stream_t * s,
                                        int64_t * duration,
                                        bg_transcoder_t * t)
   {
+  /* Add offset */
+  *start += gavl_time_scale(s->in_format.timescale, s->time_offset);
+  
   /* Correct timestamps */
-
+  
   if(t->start_time != GAVL_TIME_UNDEFINED)
     {
     *start -= gavl_time_scale(s->in_format.timescale, t->start_time);
@@ -1363,7 +1398,7 @@ static int decode_subtitle_overlay(subtitle_stream_t * s, bg_transcoder_t * t,
     
 
     if(!result || ((t->end_time != GAVL_TIME_UNDEFINED) &&
-                   (st->subtitle_start >= t->end_time)))
+                   (gavl_time_unscale(s->in_format.timescale, st->subtitle_start) >= t->end_time)))
       {
       s->eof = 1;
       return 0;
@@ -1382,8 +1417,9 @@ static int decode_subtitle_overlay(subtitle_stream_t * s, bg_transcoder_t * t,
     result = s->com.in_plugin->read_subtitle_overlay(s->com.in_handle->priv,
                                                      ovl, s->com.in_index);
     
-    if(!result || ((t->end_time != GAVL_TIME_UNDEFINED) &&
-                   (ovl->frame->timestamp >= t->end_time)))
+    if(!result ||
+       ((t->end_time != GAVL_TIME_UNDEFINED) &&
+        (gavl_time_unscale(s->in_format.timescale, ovl->frame->timestamp) >= t->end_time)))
       {
       s->eof = 1;
       return 0;
@@ -1410,7 +1446,7 @@ static int decode_subtitle_text(subtitle_text_stream_t * s, bg_transcoder_t * t)
                                                     s->com.com.in_index);
   
   if(!result || ((t->end_time != GAVL_TIME_UNDEFINED) &&
-                 (s->subtitle_start >= t->end_time)))
+                 (gavl_time_unscale(s->com.in_format.timescale, s->subtitle_start) >= t->end_time)))
     {
     s->com.eof = 1;
     return 0;
@@ -1617,7 +1653,7 @@ static int video_iteration(video_stream_t * s, bg_transcoder_t * t)
       }
 
 #ifdef DUMP_VIDEO_TIMESTAMPS
-    bg_debug("Output timestamp: %"PRId64"\n", s->frame->timestamp);
+    bg_debug("Output timestamp (video): %"PRId64"\n", s->frame->timestamp);
 #endif
   
     ret = bg_encoder_write_video_frame(t->enc,
@@ -1661,7 +1697,6 @@ static int subtitle_iteration(bg_transcoder_t * t)
       continue;
       }
     
-    
     /* Check for decoding */
     if(!st->com.has_current)
       {
@@ -1695,6 +1730,9 @@ static int subtitle_iteration(bg_transcoder_t * t)
                                            st->text, st->subtitle_start,
                                            st->subtitle_duration,
                                            st->com.com.out_index);
+
+          st->com.com.time = gavl_time_unscale(st->com.out_format.timescale,
+                                               st->subtitle_start);
           
           if(st->subtitle_start > t->time)
             t->time = st->subtitle_start;
@@ -1705,8 +1743,11 @@ static int subtitle_iteration(bg_transcoder_t * t)
             bg_encoder_write_subtitle_overlay(t->enc,
                                               &st->com.ovl1,
                                               st->com.com.out_index);
-          if(st->com.ovl1.frame->timestamp > t->time)
-            t->time = st->com.ovl1.frame->timestamp;
+          st->com.com.time = gavl_time_unscale(st->com.out_format.timescale,
+                                               st->com.ovl1.frame->timestamp);
+          
+          if(st->com.com.time > t->time)
+            t->time = st->com.com.time;
           }
         st->com.has_current = 0;
         }
@@ -1754,8 +1795,11 @@ static int subtitle_iteration(bg_transcoder_t * t)
         ret = bg_encoder_write_subtitle_overlay(t->enc,
                                                 &ss->ovl1,
                                                 ss->com.out_index);
-        if(ss->ovl1.frame->timestamp > t->time)
-          t->time = ss->ovl1.frame->timestamp;
+        ss->com.time = gavl_time_unscale(ss->out_format.timescale,
+                                         ss->ovl1.frame->timestamp);
+          
+        if(ss->com.time > t->time)
+          t->time = ss->com.time;
         ss->has_current = 0;
         }
       }
@@ -1848,8 +1892,8 @@ set_parameter_general(void * data, const char * name,
   SP_STR(subdir);
   
   SP_INT(track);
-  
-  
+  SP_INT(prefer_edl);
+    
   SP_INT(set_start_time);
   SP_INT(set_end_time);
   SP_TIME(start_time);
@@ -1875,7 +1919,7 @@ bg_transcoder_t * bg_transcoder_create()
   ret = calloc(1, sizeof(*ret));
   ret->timer = gavl_timer_create();
   ret->message_queues = bg_msg_queue_list_create();
-  pthread_mutex_init(&ret->stop_mutex,  (pthread_mutexattr_t *)0);
+  pthread_mutex_init(&ret->stop_mutex,  NULL);
   return ret;
   }
 
@@ -1995,12 +2039,12 @@ static void send_init_messages(bg_transcoder_t * t)
         switch(t->subtitle_overlay_streams[i].com.action)
           {
           case STREAM_ACTION_BLEND:
-            bg_log(BG_LOG_INFO, LOG_DOMAIN, "Text subtitle stream %d: Blending onto video stream %d",
+            bg_log(BG_LOG_INFO, LOG_DOMAIN, "Overlay subtitle stream %d: Blending onto video stream %d",
                    i+1, t->subtitle_overlay_streams[i].video_stream);
             break;
           case STREAM_ACTION_TRANSCODE:
           case STREAM_ACTION_TRANSCODE_OVERLAY:
-            bg_log(BG_LOG_INFO, LOG_DOMAIN, "Text subtitle stream %d: Exporting to file", i+1);
+            bg_log(BG_LOG_INFO, LOG_DOMAIN, "Overlay subtitle stream %d: Exporting to file", i+1);
             break;
           }
         }
@@ -2019,7 +2063,7 @@ static void send_file(const char * name)
   command = bg_sprintf("gmerlin_remote -add \"%s\"\n", name);
 
 
-  system(command);
+  bg_system(command);
   free(command);
   }
 
@@ -2040,6 +2084,7 @@ static void send_file_messages(bg_transcoder_t * t)
 
 static int open_input(bg_transcoder_t * ret)
   {
+  bg_cfg_section_t * s;
   const bg_plugin_info_t * plugin_info;
   
   plugin_info = bg_plugin_find_by_name(ret->plugin_reg, ret->plugin);
@@ -2049,39 +2094,30 @@ static int open_input(bg_transcoder_t * ret)
     goto fail;
     }
 
-  ret->in_handle = bg_plugin_load(ret->plugin_reg, plugin_info);
-  if(!ret->in_handle)
+  s = bg_plugin_registry_get_section(ret->plugin_reg,
+                                     plugin_info->name);
+
+  if(s && ret->transcoder_track->input_section)
     {
-    bg_log(BG_LOG_ERROR, LOG_DOMAIN, "Cannot open plugin %s", ret->plugin);
-    goto fail;
+    bg_cfg_section_transfer(ret->transcoder_track->input_section, s);
     }
 
-  ret->in_plugin = (bg_input_plugin_t*)(ret->in_handle->plugin);
-
-  if(ret->in_plugin->common.set_parameter &&
-     ret->in_plugin->common.get_parameters &&
-     ret->transcoder_track->input_section)
-    {
-    bg_cfg_section_apply(ret->transcoder_track->input_section,
-                         ret->in_plugin->common.get_parameters(ret->in_handle->priv),
-                         ret->in_plugin->common.set_parameter, ret->in_handle->priv);
-    }
+  //  fprintf(stderr, "open input %d\n", ret->prefer_edl);
   
-  if(!ret->in_plugin->open(ret->in_handle->priv, ret->location))
-    {
-    bg_log(BG_LOG_ERROR, LOG_DOMAIN, "Cannot open %s with plugin %s",
-                                  ret->location, ret->plugin);
+  if(!bg_input_plugin_load(ret->plugin_reg,
+                           ret->location,
+                           plugin_info,
+                           &ret->in_handle,
+                           NULL, ret->prefer_edl))
     goto fail;
-    }
 
+  ret->in_plugin = (bg_input_plugin_t*)ret->in_handle->plugin;
+  
   if(bg_string_is_url(ret->location))
     ret->is_url = 1;
   
-
-  
   /* Select track and get track info */
-
-    
+  
   if(ret->in_plugin->get_num_tracks &&
      (ret->track >= ret->in_plugin->get_num_tracks(ret->in_handle->priv)))
     {
@@ -2204,29 +2240,32 @@ static void create_streams(bg_transcoder_t * ret,
   ret->num_audio_streams = track->num_audio_streams;
   if(ret->num_audio_streams)
     ret->audio_streams = calloc(ret->num_audio_streams,
-                                sizeof(*(ret->audio_streams)));
+                                sizeof(*ret->audio_streams));
   
   ret->num_video_streams = track->num_video_streams;
 
   if(ret->num_video_streams)
     ret->video_streams = calloc(ret->num_video_streams,
-                                sizeof(*(ret->video_streams)));
+                                sizeof(*ret->video_streams));
 
   ret->num_subtitle_text_streams = track->num_subtitle_text_streams;
 
   if(ret->num_subtitle_text_streams)
     ret->subtitle_text_streams = calloc(ret->num_subtitle_text_streams,
-                                sizeof(*(ret->subtitle_text_streams)));
+                                sizeof(*ret->subtitle_text_streams));
 
   ret->num_subtitle_overlay_streams = track->num_subtitle_overlay_streams;
 
   if(ret->num_subtitle_overlay_streams)
     ret->subtitle_overlay_streams = calloc(ret->num_subtitle_overlay_streams,
-                                sizeof(*(ret->subtitle_overlay_streams)));
+                                           sizeof(*ret->subtitle_overlay_streams));
   
   /* Prepare streams */
     
   ret->num_audio_streams_real = 0;
+  ret->num_video_streams_real = 0;
+  ret->num_subtitle_text_streams_real = 0;
+  ret->num_subtitle_overlay_streams_real = 0;
     
   for(i = 0; i < ret->num_audio_streams; i++)
     {
@@ -2238,7 +2277,6 @@ static void create_streams(bg_transcoder_t * ret,
       ret->num_audio_streams_real++;
     }
 
-  ret->num_video_streams_real = 0;
   
   for(i = 0; i < ret->num_video_streams; i++)
     {
@@ -2249,8 +2287,6 @@ static void create_streams(bg_transcoder_t * ret,
       ret->num_video_streams_real++;
     }
 
-  ret->num_subtitle_text_streams_real = 0;
-  ret->num_subtitle_overlay_streams_real = 0;
   
   for(i = 0; i < ret->num_subtitle_text_streams; i++)
     {
@@ -2610,6 +2646,7 @@ static int init_encoder(bg_transcoder_t * ret)
   bg_encoder_open(ret->enc, tmp_string,
                   &ret->metadata,
                   ret->transcoder_track->chapter_list);
+  free(tmp_string);
   
   for(i = 0; i < ret->num_audio_streams; i++)
     {
@@ -2700,7 +2737,10 @@ static int init_video_converter(video_stream_t * ret, bg_transcoder_t * t)
   
   /* Create frames */
   if(!ret->frame)
+    {
     ret->frame = gavl_video_frame_create(&ret->out_format);
+    // fprintf(stderr, "Created video frame %p %p\n", ret->frame, ret->frame->planes[0]);
+    }
   gavl_video_frame_clear(ret->frame, &ret->out_format);
   
   return 1;
@@ -2783,6 +2823,12 @@ static int init_converters(bg_transcoder_t * ret)
   int i;
   for(i = 0; i < ret->num_audio_streams; i++)
     {
+    if(ret->audio_streams[i].com.do_copy)
+      {
+      gavl_audio_format_copy(&ret->audio_streams[i].out_format,
+                             &ret->audio_streams[i].in_format);
+      continue;
+      }
     if(!ret->audio_streams[i].com.do_decode)
       continue;
     if(!init_audio_converter(&ret->audio_streams[i], ret))
@@ -2790,6 +2836,13 @@ static int init_converters(bg_transcoder_t * ret)
     }
   for(i = 0; i < ret->num_video_streams; i++)
     {
+    if(ret->video_streams[i].com.do_copy)
+      {
+      gavl_video_format_copy(&ret->video_streams[i].out_format,
+                             &ret->video_streams[i].in_format);
+      continue;
+      }
+    
     if(!ret->video_streams[i].com.do_decode)
       continue;
 
@@ -2799,7 +2852,7 @@ static int init_converters(bg_transcoder_t * ret)
     if(ret->video_streams[i].subtitle_streams)
       {
       free(ret->video_streams[i].subtitle_streams);
-      ret->video_streams[i].subtitle_streams = (subtitle_stream_t**)0;
+      ret->video_streams[i].subtitle_streams = NULL;
       ret->video_streams[i].num_subtitle_streams = 0;
       }
     }
@@ -2864,7 +2917,7 @@ static void init_normalize(bg_transcoder_t * ret)
                                      &ret->audio_streams[i].pipe_format);
       /* Set the volume */
       gavl_peak_detector_get_peak(ret->audio_streams[i].peak_detector,
-                                  (double*)0, (double*)0, &absolute);
+                                  NULL, NULL, &absolute);
       if(absolute == 0.0)
         {
         gavl_volume_control_set_volume(ret->audio_streams[i].volume_control, volume_dB);
@@ -2991,6 +3044,7 @@ static void cleanup_stream(stream_t * s)
   {
   gavl_compression_info_free(&s->ci);
   gavl_packet_free(&s->packet);
+  gavl_metadata_free(&s->m);
   }
 
 static void cleanup_audio_stream(audio_stream_t * s)
@@ -3022,7 +3076,10 @@ static void cleanup_video_stream(video_stream_t * s)
   /* Free all resources */
 
   if(s->frame)
+    {
+    // fprintf(stderr, "gavl_video_frame_destroy %p %p\n", s->frame, s->frame->planes[0]);
     gavl_video_frame_destroy(s->frame);
+    }
   if(s->fc)
     bg_video_filter_chain_destroy(s->fc);
   
@@ -3080,7 +3137,7 @@ static void close_input(bg_transcoder_t * t)
 
   t->in_plugin->close(t->in_handle->priv);
   bg_plugin_unref(t->in_handle);
-  t->in_handle = (bg_plugin_handle_t*)0;
+  t->in_handle = NULL;
   }
 
 /* Switch to next pass */
@@ -3141,7 +3198,7 @@ int bg_transcoder_iteration(bg_transcoder_t * t)
   {
   int i;
   gavl_time_t time;
-  stream_t * stream = (stream_t*)0;
+  stream_t * stream = NULL;
 
   gavl_time_t real_time;
   double real_seconds;
@@ -3188,17 +3245,22 @@ int bg_transcoder_iteration(bg_transcoder_t * t)
       }
     }
 
-  for(i = 0; i < t->num_subtitle_text_streams; i++)
+  /* Detecting EOF for subtitles doesn't work when we transcode until
+     a specified time */
+  if(t->end_time == GAVL_TIME_UNDEFINED)
     {
-    if(t->subtitle_text_streams[i].com.com.status != STREAM_STATE_ON)
-      continue;
-    done = 0;
-    }
-  for(i = 0; i < t->num_subtitle_overlay_streams; i++)
-    {
-    if(t->subtitle_overlay_streams[i].com.status != STREAM_STATE_ON)
-      continue;
-    done = 0;
+    for(i = 0; i < t->num_subtitle_text_streams; i++)
+      {
+      if(t->subtitle_text_streams[i].com.com.status != STREAM_STATE_ON)
+        continue;
+      done = 0;
+      }
+    for(i = 0; i < t->num_subtitle_overlay_streams; i++)
+      {
+      if(t->subtitle_overlay_streams[i].com.status != STREAM_STATE_ON)
+        continue;
+      done = 0;
+      }
     }
   
   if(done)
@@ -3365,7 +3427,7 @@ void bg_transcoder_destroy(bg_transcoder_t * t)
   
   /* Free metadata */
 
-  bg_metadata_free(&t->metadata);
+  gavl_metadata_free(&t->metadata);
   
   /* Close and destroy the input plugin */
 
@@ -3410,7 +3472,7 @@ static void * thread_func(void * data)
 
 void bg_transcoder_run(bg_transcoder_t * t)
   {
-  pthread_create(&t->thread, (pthread_attr_t*)0, thread_func, t);
+  pthread_create(&t->thread, NULL, thread_func, t);
   }
 
 void bg_transcoder_stop(bg_transcoder_t * t)
