@@ -42,6 +42,9 @@
 #include <gmerlin/log.h>
 #define LOG_DOMAIN "transcoder_track"
 
+#include <gavl/metatags.h>
+
+
 static void create_sections(bg_transcoder_track_t * t,
                             bg_cfg_section_t * track_defaults_section,
                             bg_cfg_section_t * input_section,
@@ -49,34 +52,31 @@ static void create_sections(bg_transcoder_track_t * t,
                             bg_track_info_t * track_info)
   {
   int i, in_index;
-
+  const char * tag;
   bg_cfg_section_t * general_section;
   bg_cfg_section_t * filter_section;
   bg_cfg_section_t * textrenderer_section;
 
-#if 0
-  t->general_section =
-    bg_cfg_section_create_from_parameters("General", t->general_parameters);
-#else
   t->input_section = bg_cfg_section_copy(input_section);
   
-  general_section = bg_cfg_section_find_subsection(track_defaults_section, "general");
+  general_section =
+    bg_cfg_section_find_subsection(track_defaults_section, "general");
   t->general_section = bg_cfg_section_copy(general_section);
   
-  /* The parameters which were initially hidden are not present in the general section.
+  /* The parameters which were initially hidden are not
+     present in the general section.
      Therefore, we will create the missing items now */
 
   i = 0;
   while(t->general_parameters[i].name)
     {
-    bg_cfg_section_get_parameter(t->general_section,
+    bg_cfg_section_set_parameter(t->general_section,
                                  &t->general_parameters[i],
-                                 (bg_parameter_value_t*)0);
+                                 &t->general_parameters[i].val_default);
+    
     i++;
     }
-  
-#endif
-  
+    
   /* Stop here for redirectors */
 
   if(t->url)
@@ -96,10 +96,13 @@ static void create_sections(bg_transcoder_track_t * t,
       {
       t->audio_streams[i].general_section = bg_cfg_section_copy(general_section);
       t->audio_streams[i].filter_section = bg_cfg_section_copy(filter_section);
-      if(track_info->audio_streams[i].language[0] != '\0')
+
+      tag = gavl_metadata_get(&track_info->audio_streams[i].m,
+                              GAVL_META_LANGUAGE);
+      
+      if(tag)
         bg_cfg_section_set_parameter_string(t->audio_streams[i].general_section,
-                                            "in_language",
-                                            track_info->audio_streams[i].language);
+                                            "in_language", tag);
       }
     }
 
@@ -130,10 +133,13 @@ static void create_sections(bg_transcoder_track_t * t,
 
       in_index = t->subtitle_text_streams[i].in_index;
 
-      if(track_info->subtitle_streams[in_index].language[0] != '\0')
+      tag = gavl_metadata_get(&track_info->subtitle_streams[i].m,
+                              GAVL_META_LANGUAGE);
+            
+      if(tag)
         bg_cfg_section_set_parameter_string(t->subtitle_text_streams[i].general_section,
                                             "in_language",
-                                            track_info->subtitle_streams[in_index].language);
+                                            tag);
       }
     }
 
@@ -145,10 +151,13 @@ static void create_sections(bg_transcoder_track_t * t,
       {
       t->subtitle_overlay_streams[i].general_section = bg_cfg_section_copy(general_section);
       in_index = t->subtitle_overlay_streams[i].in_index;
-      if(track_info->subtitle_streams[in_index].language[0] != '\0')
+
+      tag = gavl_metadata_get(&track_info->subtitle_streams[in_index].m,
+                              GAVL_META_LANGUAGE);
+      
+      if(tag)
         bg_cfg_section_set_parameter_string(t->subtitle_overlay_streams[i].general_section,
-                                            "in_language",
-                                            track_info->subtitle_streams[in_index].language);
+                                            "in_language", tag);
       }
     }
   
@@ -178,7 +187,7 @@ static const bg_parameter_info_t parameters_general[] =
       .name =      "prefer_edl",
       .long_name = TRS("Prefer EDL"),
       .type =      BG_PARAMETER_CHECKBUTTON,
-      .help_string = TRS("For files, which contain edit decision lists and raw streams, this option selects which one to decode."),
+      .flags =     BG_PARAMETER_HIDE_DIALOG,
     },
     {
       .name =      "track",
@@ -281,12 +290,12 @@ static const bg_parameter_info_t general_parameters_subtitle_text[] =
                                         "transcode",
                                         "transcode_overlay",
                                         "blend",
-                                        (char*)0 },
+                                        NULL },
       .multi_labels = (char const *[]){ TRS("Forget"),
                                         TRS("Transcode as text"),
                                         TRS("Transcode as overlay"),
                                         TRS("Blend onto video"),
-                                        (char*)0 },
+                                        NULL },
       .help_string = TRS("Select action for this subtitle stream.")
     },
     {
@@ -310,6 +319,15 @@ static const bg_parameter_info_t general_parameters_subtitle_text[] =
       .val_default = { .val_i = 1 },
       .help_string = TRS("Force the given language even if the input has the language set differently.")
     },
+    {
+      .name      = "time_offset",
+      .long_name = TRS("Time offset"),
+      .flags     = BG_PARAMETER_SYNC,
+      .type      = BG_PARAMETER_FLOAT,
+      .val_min   = { .val_f = -600.0 },
+      .val_max   = { .val_f =  600.0 },
+      .num_digits = 3,
+    },
     {
       .name =        "video_stream",
       .long_name =   TRS("Video stream"),
@@ -335,11 +353,11 @@ static const bg_parameter_info_t general_parameters_subtitle_overlay[] =
       .multi_names =  (char const *[]){ "forget",
                                         "transcode",
                                         "blend",
-                                        (char*)0 },
+                                        NULL },
       .multi_labels = (char const *[]){ TRS("Forget"),
                                         TRS("Transcode"),
                                         TRS("Blend onto video"),
-                                        (char*)0 },
+                                        NULL },
       .val_default = { .val_str = "forget" },
     },
     {
@@ -510,37 +528,40 @@ void bg_transcoder_track_create_parameters(bg_transcoder_track_t * track,
          !strcmp(track->general_parameters[i].name, "set_end_time") ||
          !strcmp(track->general_parameters[i].name, "end_time"))
         track->general_parameters[i].flags &= ~BG_PARAMETER_HIDE_DIALOG;
-    
-      if(!strcmp(track->general_parameters[i].name, "prefer_edl"))
-        track->general_parameters[i].flags |= BG_PARAMETER_HIDE_DIALOG;
-    
       i++;
       }
     }
 
   if(!track->metadata_parameters)
-    track->metadata_parameters = bg_metadata_get_parameters((bg_metadata_t*)0);
+    track->metadata_parameters = bg_metadata_get_parameters(NULL);
   
   create_subtitle_parameters(track);
 
   create_filter_parameters(track, plugin_reg);
   }
 
-static char * create_stream_label(const char * info, const char * language)
+static char * create_stream_label(const gavl_metadata_t * m)
   {
-  if(language && *language && info)
+  const char * info;
+  const char * language;
+
+  info = gavl_metadata_get(m, GAVL_META_LABEL);
+  language = gavl_metadata_get(m, GAVL_META_LANGUAGE);
+  
+  if(language && info)
     return bg_sprintf("%s [%s]", info, bg_get_language_name(language));
-  else if(language && *language)
-    return bg_strdup((char*)0, bg_get_language_name(language));
+  else if(language)
+    return bg_strdup(NULL, bg_get_language_name(language));
   else if(info)
-    return bg_strdup((char*)0, info);
+    return bg_strdup(NULL, info);
   else
-    return (char*)0;
+    return NULL;
   }
 
 static void set_track(bg_transcoder_track_t * track,
                       bg_track_info_t * track_info,
                       bg_plugin_handle_t * input_plugin,
+                      const bg_plugin_info_t * input_info,
                       const char * location,
                       int track_index,
                       int total_tracks,
@@ -549,12 +570,12 @@ static void set_track(bg_transcoder_track_t * track,
   int i;
   int subtitle_text_index, subtitle_overlay_index;
   const bg_input_plugin_t * input;
-  input = (bg_input_plugin_t *)(input_plugin->plugin);
+  input = (bg_input_plugin_t *)input_plugin->plugin;
   
   /* General parameters */
-
   
-  track->general_parameters = bg_parameter_info_copy_array(parameters_general);
+  track->general_parameters =
+    bg_parameter_info_copy_array(parameters_general);
 
   i = 0;
   while(track->general_parameters[i].name)
@@ -562,47 +583,13 @@ static void set_track(bg_transcoder_track_t * track,
     if(!strcmp(track->general_parameters[i].name, "name"))
       {
       if(track_info->name)
-        track->general_parameters[i].val_default.val_str = bg_strdup((char*)0,
-                                                                     track_info->name);
+        track->general_parameters[i].val_default.val_str =
+          bg_strdup(NULL, track_info->name);
       else
         track->general_parameters[i].val_default.val_str =
           bg_get_track_name_default(location, track_index, total_tracks);
       track->general_parameters[i].flags &= ~BG_PARAMETER_HIDE_DIALOG;
       }
-#if 0
-    else if(!strcmp(track->general_parameters[i].name, "audio_encoder"))
-      {
-      if(encoder_info->audio_info)
-        track->general_parameters[i].val_default.val_str =
-          bg_strdup((char*)0, encoder_info->audio_info->name);
-      else
-        track->general_parameters[i].val_default.val_str =
-          bg_strdup((char*)0, encoder_info->video_info->name);
-      }
-    else if(!strcmp(track->general_parameters[i].name, "subtitle_text_encoder"))
-      {
-      if(encoder_info->subtitle_text_info)
-        track->general_parameters[i].val_default.val_str =
-          bg_strdup((char*)0, encoder_info->subtitle_text_info->name);
-      else
-        track->general_parameters[i].val_default.val_str =
-          bg_strdup((char*)0, encoder_info->video_info->name);
-      }
-    else if(!strcmp(track->general_parameters[i].name, "subtitle_overlay_encoder"))
-      {
-      if(encoder_info->subtitle_overlay_info)
-        track->general_parameters[i].val_default.val_str =
-          bg_strdup((char*)0, encoder_info->subtitle_overlay_info->name);
-      else
-        track->general_parameters[i].val_default.val_str =
-          bg_strdup((char*)0, encoder_info->video_info->name);
-      }
-
-    
-    else if(!strcmp(track->general_parameters[i].name, "video_encoder"))
-      track->general_parameters[i].val_default.val_str =
-        bg_strdup((char*)0, encoder_info->video_info->name);
-#endif
     
     else if(!strcmp(track->general_parameters[i].name, "duration"))
       track->general_parameters[i].val_default.val_time = track_info->duration;
@@ -614,15 +601,21 @@ static void set_track(bg_transcoder_track_t * track,
                     input->get_disc_name(input_plugin->priv));
       }
     else if(!strcmp(track->general_parameters[i].name, "flags"))
-      {
       track->general_parameters[i].val_default.val_i = track_info->flags;
-      }
     else if(!strcmp(track->general_parameters[i].name, "location"))
-      track->general_parameters[i].val_default.val_str = bg_strdup((char*)0, location);
+      track->general_parameters[i].val_default.val_str = bg_strdup(NULL, location);
 
     else if(!strcmp(track->general_parameters[i].name, "plugin"))
-      track->general_parameters[i].val_default.val_str = bg_strdup((char*)0, input_plugin->info->name);
-
+      track->general_parameters[i].val_default.val_str =
+        bg_strdup(NULL, input_info->name);
+    else if(!strcmp(track->general_parameters[i].name, "prefer_edl"))
+      {
+      if(input_plugin->edl)
+        track->general_parameters[i].val_default.val_i = 1;
+      else
+        track->general_parameters[i].val_default.val_i = 0;
+        
+      }
     else if(!strcmp(track->general_parameters[i].name, "track"))
       track->general_parameters[i].val_default.val_i = track_index;
 
@@ -680,9 +673,7 @@ static void set_track(bg_transcoder_track_t * track,
     for(i = 0; i < track_info->num_audio_streams; i++)
       {
       track->audio_streams[i].label =
-        create_stream_label(track_info->audio_streams[i].info,
-                            track_info->audio_streams[i].language);
-      
+        create_stream_label(&track_info->audio_streams[i].m);
       }
     
     }
@@ -698,8 +689,7 @@ static void set_track(bg_transcoder_track_t * track,
     for(i = 0; i < track_info->num_video_streams; i++)
       {
       track->video_streams[i].label =
-        create_stream_label(track_info->video_streams[i].info,
-                            track_info->video_streams[i].language);
+        create_stream_label(&track_info->video_streams[i].m);
       }
     }
 
@@ -716,12 +706,14 @@ static void set_track(bg_transcoder_track_t * track,
       }
 
     if(track->num_subtitle_text_streams)
-      track->subtitle_text_streams = calloc(track->num_subtitle_text_streams,
-                                            sizeof(*(track->subtitle_text_streams)));
+      track->subtitle_text_streams =
+        calloc(track->num_subtitle_text_streams,
+               sizeof(*(track->subtitle_text_streams)));
     
     if(track->num_subtitle_overlay_streams)
-      track->subtitle_overlay_streams = calloc(track->num_subtitle_overlay_streams,
-                                               sizeof(*(track->subtitle_overlay_streams)));
+      track->subtitle_overlay_streams =
+        calloc(track->num_subtitle_overlay_streams,
+               sizeof(*(track->subtitle_overlay_streams)));
     
     subtitle_text_index = 0;
     subtitle_overlay_index = 0;
@@ -731,16 +723,14 @@ static void set_track(bg_transcoder_track_t * track,
       if(track_info->subtitle_streams[i].is_text)
         {
         track->subtitle_text_streams[subtitle_text_index].label =
-          create_stream_label(track_info->subtitle_streams[i].info,
-                       track_info->subtitle_streams[i].language);
+          create_stream_label(&track_info->subtitle_streams[i].m);
         track->subtitle_text_streams[subtitle_text_index].in_index = i;
         subtitle_text_index++;
         }
       else
         {
         track->subtitle_overlay_streams[subtitle_overlay_index].label =
-          create_stream_label(track_info->subtitle_streams[i].info,
-                       track_info->subtitle_streams[i].language);
+          create_stream_label(&track_info->subtitle_streams[i].m);
         track->subtitle_overlay_streams[subtitle_overlay_index].in_index = i;
         
         subtitle_overlay_index++;
@@ -800,6 +790,7 @@ static void disable_streams(bg_input_plugin_t * plugin, void * priv)
 bg_transcoder_track_t *
 bg_transcoder_track_create(const char * url,
                            const bg_plugin_info_t * input_info,
+                           int prefer_edl,
                            int track, bg_plugin_registry_t * plugin_reg,
                            bg_cfg_section_t * track_defaults_section,
                            bg_cfg_section_t * encoder_section,
@@ -807,38 +798,49 @@ bg_transcoder_track_create(const char * url,
   {
   int i;
 
-  bg_transcoder_track_t * ret = (bg_transcoder_track_t *)0;
-  bg_transcoder_track_t * new_track = (bg_transcoder_track_t *)0;
-  bg_transcoder_track_t * end_track = (bg_transcoder_track_t *)0;
+  bg_transcoder_track_t * ret = NULL;
+  bg_transcoder_track_t * new_track = NULL;
+  bg_transcoder_track_t * end_track = NULL;
   
   bg_input_plugin_t      * input;
   bg_track_info_t        * track_info;
-  bg_plugin_handle_t     * plugin_handle = (bg_plugin_handle_t*)0;
+  bg_plugin_handle_t     * plugin_handle = NULL;
   int num_tracks;
   int streams_enabled = 0;
-  int prefer_edl;
   
   bg_cfg_section_t * input_section;
   
   /* Load the plugin */
 
-  bg_cfg_section_get_parameter_int(track_defaults_section, "prefer_edl", &prefer_edl);
-  
-  if(!bg_input_plugin_load(plugin_reg, url,
-                           input_info, &plugin_handle, (bg_input_callbacks_t*)0, prefer_edl))
+  if(!input_info)
     {
-    bg_log(BG_LOG_ERROR, LOG_DOMAIN, "Loading %s failed", url);
-    return (bg_transcoder_track_t*)0;
+    if(!bg_input_plugin_load(plugin_reg, url,
+                             input_info, &plugin_handle, NULL, 0))
+      {
+      bg_log(BG_LOG_ERROR, LOG_DOMAIN, "Loading %s failed", url);
+      return NULL;
+      }
+    input_info = bg_plugin_find_by_name(plugin_reg, plugin_handle->info->name);
     }
+
+  if(!plugin_handle || prefer_edl)
+    {
+    if(!bg_input_plugin_load(plugin_reg, url,
+                             input_info, &plugin_handle, NULL, prefer_edl))
+      {
+      bg_log(BG_LOG_ERROR, LOG_DOMAIN, "Loading %s failed", url);
+      return NULL;
+      }
+    }
+  
   if(plugin_handle->edl)
     bg_cfg_section_set_parameter_int(track_defaults_section, "prefer_edl", 1);
   else
     bg_cfg_section_set_parameter_int(track_defaults_section, "prefer_edl", 0);
   
-  input = (bg_input_plugin_t*)(plugin_handle->plugin);
+  input = (bg_input_plugin_t*)plugin_handle->plugin;
   
-  input_section = bg_plugin_registry_get_section(plugin_reg,
-                                                 plugin_handle->info->name);
+  input_section = bg_plugin_registry_get_section(plugin_reg, input_info->name);
   
   /* Decide what to load */
   
@@ -870,7 +872,7 @@ bg_transcoder_track_create(const char * url,
       streams_enabled = 1;
       }
     
-    set_track(new_track, track_info, plugin_handle, url, track, num_tracks,
+    set_track(new_track, track_info, plugin_handle, input_info, url, track, num_tracks,
               plugin_reg);
     create_sections(new_track, track_defaults_section, input_section,
                     encoder_section, track_info);
@@ -918,7 +920,7 @@ bg_transcoder_track_create(const char * url,
         streams_enabled = 1;
         }
       
-      set_track(new_track, track_info, plugin_handle, url, i, num_tracks,
+      set_track(new_track, track_info, plugin_handle, input_info, url, i, num_tracks,
                 plugin_reg);
       create_sections(new_track, track_defaults_section, input_section,
                       encoder_section, track_info);
@@ -943,10 +945,9 @@ static bg_transcoder_track_t * remove_redirectors(bg_transcoder_track_t * entrie
                                                   bg_cfg_section_t * encoder_section)
   {
   bg_transcoder_track_t * before, * e;
-  //  bg_album_entry_t * ret_end = (bg_album_entry_t*)0;
   bg_transcoder_track_t * new_entry, * end_entry;
   int done = 0;
-  const char * plugin_name = (const char*)0;
+  const char * plugin_name = NULL;
   const bg_plugin_info_t * info;
   
   done = 1;
@@ -962,15 +963,16 @@ static bg_transcoder_track_t * remove_redirectors(bg_transcoder_track_t * entrie
       if(plugin_name)
         info = bg_plugin_find_by_name(plugin_reg, plugin_name);
       else
-        info = (const bg_plugin_info_t*)0;
+        info = NULL;
 
       /* Load "real" url */
       
       new_entry = bg_transcoder_track_create(e->url,
-                                             info,
+                                             info, 0,
                                              -1, plugin_reg,
-                                             track_defaults_section, encoder_section,
-                                             (char*)0);
+                                             track_defaults_section,
+                                             encoder_section,
+                                             NULL);
       
       if(new_entry)
         {
@@ -1008,7 +1010,7 @@ static bg_transcoder_track_t * remove_redirectors(bg_transcoder_track_t * entrie
         else
           {
           entries = e->next;
-          before = (bg_transcoder_track_t*)0;
+          before = NULL;
           }
         bg_transcoder_track_destroy(e);
         e = (before) ? before->next : entries;
@@ -1032,13 +1034,13 @@ bg_transcoder_track_create_from_urilist(const char * list,
   {
   int i;
   char ** uri_list;
-  bg_transcoder_track_t * ret_last = (bg_transcoder_track_t*)0;
-  bg_transcoder_track_t * ret = (bg_transcoder_track_t*)0;
+  bg_transcoder_track_t * ret_last = NULL;
+  bg_transcoder_track_t * ret = NULL;
   
   uri_list = bg_urilist_decode(list, len);
 
   if(!uri_list)
-    return (bg_transcoder_track_t*)0;
+    return NULL;
 
   i = 0;
 
@@ -1047,10 +1049,11 @@ bg_transcoder_track_create_from_urilist(const char * list,
     if(!ret)
       {
       ret = bg_transcoder_track_create(uri_list[i],
-                                       (const bg_plugin_info_t*)0,
+                                       NULL, 0,
                                        -1,
                                        plugin_reg,
-                                       track_defaults_section, encoder_section, (char*)0);
+                                       track_defaults_section,
+                                       encoder_section, NULL);
       if(ret)
         {
         ret_last = ret;
@@ -1061,11 +1064,12 @@ bg_transcoder_track_create_from_urilist(const char * list,
     else
       {
       ret_last->next = bg_transcoder_track_create(uri_list[i],
-                                                  (const bg_plugin_info_t*)0,
+                                                  NULL, 0,
                                                   -1,
                                                   plugin_reg,
-                                                  track_defaults_section, encoder_section,
-                                                  (char*)0);
+                                                  track_defaults_section,
+                                                  encoder_section,
+                                                  NULL);
       if(ret)
         {
         while(ret_last->next)
@@ -1091,10 +1095,10 @@ bg_transcoder_track_create_from_albumentries(const char * xml_string,
                                              bg_cfg_section_t * encoder_section)
   {
   bg_album_entry_t * new_entries, *entry;
-  bg_transcoder_track_t * ret_last = (bg_transcoder_track_t*)0;
-  bg_transcoder_track_t * ret = (bg_transcoder_track_t*)0;
+  bg_transcoder_track_t * ret_last =NULL;
+  bg_transcoder_track_t * ret =NULL;
   const bg_plugin_info_t * plugin_info;
-
+  int prefer_edl;
   new_entries = bg_album_entries_new_from_xml(xml_string);
 
   entry = new_entries;
@@ -1104,12 +1108,19 @@ bg_transcoder_track_create_from_albumentries(const char * xml_string,
     if(entry->plugin)
       plugin_info = bg_plugin_find_by_name(plugin_reg, entry->plugin);
     else
-      plugin_info = (const bg_plugin_info_t*)0;
+      plugin_info = NULL;
+
+    if(entry->flags & BG_ALBUM_ENTRY_EDL)
+      prefer_edl = 1;
+    else
+      prefer_edl = 0;
+    
     if(!ret)
       {
         
       ret = bg_transcoder_track_create(entry->location,
                                        plugin_info,
+                                       prefer_edl,
                                        entry->index,
                                        plugin_reg,
                                        track_defaults_section, encoder_section,
@@ -1120,6 +1131,7 @@ bg_transcoder_track_create_from_albumentries(const char * xml_string,
       {
       ret_last->next = bg_transcoder_track_create(entry->location,
                                                   plugin_info,
+                                                  prefer_edl,
                                                   entry->index,
                                                   plugin_reg,
                                                   track_defaults_section,
@@ -1318,10 +1330,10 @@ static const bg_parameter_info_t general_parameters_video[] =
       .name =        "action",
       .long_name =   TRS("Action"),
       .type =        BG_PARAMETER_STRINGLIST,
-      .multi_names = (char const *[]){ "transcode", "copy", "forget", (char*)0 },
+      .multi_names = (char const *[]){ "transcode", "copy", "forget", NULL },
       .multi_labels =  (char const *[]){ TRS("Transcode"),
                                          TRS("Copy (if possible)"),
-                                         TRS("Forget"), (char*)0 },
+                                         TRS("Forget"), NULL },
       .val_default = { .val_str = "transcode" },
       .help_string = TRS("Choose the desired action for the stream. If copying is not possible, the stream will be transcoded"),
 
@@ -1348,10 +1360,10 @@ static const bg_parameter_info_t general_parameters_audio[] =
       .long_name =   TRS("Action"),
       .type =        BG_PARAMETER_STRINGLIST,
 
-      .multi_names = (char const *[]){ "transcode", "copy", "forget", (char*)0 },
+      .multi_names = (char const *[]){ "transcode", "copy", "forget", NULL },
       .multi_labels =  (char const *[]){ TRS("Transcode"),
                                          TRS("Copy (if possible)"),
-                                         TRS("Forget"), (char*)0 },
+                                         TRS("Forget"), NULL },
       .val_default = { .val_str = "transcode" },
       .help_string = TRS("Choose the desired action for the stream. If copying is not possible, the stream will be transcoded"),
     },
@@ -1593,7 +1605,7 @@ bg_transcoder_track_global_from_reg(bg_transcoder_track_global_t * g,
   if(bg_plugin_registry_get_encode_pp(plugin_reg))
     {
     plugin_info = bg_plugin_registry_get_default(plugin_reg, BG_PLUGIN_ENCODER_PP, BG_PLUGIN_PP);
-    g->pp_plugin = bg_strdup((char*)0, plugin_info->name);
+    g->pp_plugin = bg_strdup(NULL, plugin_info->name);
     plugin_section = bg_plugin_registry_get_section(plugin_reg, plugin_info->name);
     g->pp_section = bg_cfg_section_copy(plugin_section);
     }
@@ -1605,12 +1617,12 @@ bg_transcoder_track_global_free(bg_transcoder_track_global_t * g)
   if(g->pp_plugin)
     {
     free(g->pp_plugin);
-    g->pp_plugin = (char*)0;
+    g->pp_plugin = NULL;
     }
   if(g->pp_section)
     {
     bg_cfg_section_destroy(g->pp_section);
-    g->pp_section = (bg_cfg_section_t*)0;
+    g->pp_section = NULL;
     }
 
   }
@@ -1623,10 +1635,8 @@ bg_transcoder_track_t *
 bg_transcoder_tracks_delete_selected(bg_transcoder_track_t * t)
   {
   bg_transcoder_track_t * track, *tmp_track;
-  bg_transcoder_track_t * new_tracks =
-    (bg_transcoder_track_t*)0;
-  bg_transcoder_track_t * end_track =
-    (bg_transcoder_track_t*)0;
+  bg_transcoder_track_t * new_tracks = NULL;
+  bg_transcoder_track_t * end_track = NULL;
 
   track = t;
   
@@ -1653,7 +1663,7 @@ bg_transcoder_tracks_delete_selected(bg_transcoder_track_t * t)
         end_track = end_track->next;
         }
       track = track->next;
-      end_track->next = (bg_transcoder_track_t*)0;
+      end_track->next = NULL;
       }
     }
   return new_tracks;
@@ -1683,11 +1693,11 @@ bg_transcoder_tracks_extract_selected(bg_transcoder_track_t ** t)
   {
     bg_transcoder_track_t * track;
   
-  bg_transcoder_track_t * ret = (bg_transcoder_track_t*)0;
-  bg_transcoder_track_t * ret_end = (bg_transcoder_track_t*)0;
+  bg_transcoder_track_t * ret = NULL;
+  bg_transcoder_track_t * ret_end = NULL;
 
-  bg_transcoder_track_t * new_tracks  = (bg_transcoder_track_t*)0;
-  bg_transcoder_track_t * new_tracks_end = (bg_transcoder_track_t*)0;
+  bg_transcoder_track_t * new_tracks  = NULL;
+  bg_transcoder_track_t * new_tracks_end = NULL;
 
   track = *t;
   
@@ -1725,9 +1735,9 @@ bg_transcoder_tracks_extract_selected(bg_transcoder_track_t ** t)
   /* Zero terminate */
 
   if(ret_end)
-    ret_end->next = (bg_transcoder_track_t*)0;
+    ret_end->next = NULL;
   if(new_tracks_end)  
-    new_tracks_end->next = (bg_transcoder_track_t*)0;
+    new_tracks_end->next = NULL;
   *t = new_tracks;
   return ret;
   }
