@@ -140,7 +140,7 @@ static bg_album_t * insert_album_after(bg_album_t * list,
   {
   if(!list)
     {
-    new_album->next = (bg_album_t*)0;
+    new_album->next = NULL;
     return new_album;
     }
   if(!sibling)
@@ -162,7 +162,7 @@ static bg_album_t * insert_album_before(bg_album_t * list,
   
   if(!list)
     {
-    new_album->next = (bg_album_t*)0;
+    new_album->next = NULL;
     return new_album;
     }
   
@@ -298,7 +298,7 @@ static bg_album_t * find_by_plugin(bg_album_t * albums,
       return albums;
     albums = albums->next;
     }
-  return (bg_album_t *)0;
+  return NULL;
   }
 
 static bg_album_t * find_by_device(bg_album_t * albums,
@@ -310,7 +310,7 @@ static bg_album_t * find_by_device(bg_album_t * albums,
       return albums;
     albums = albums->next;
     }
-  return (bg_album_t *)0;
+  return NULL;
   
   }
 
@@ -398,7 +398,7 @@ bg_media_tree_create(const char * filename,
   
   ret = calloc(1, sizeof(*ret));
 
-  ret->cfg_section = bg_cfg_section_create((char*)0);
+  ret->cfg_section = bg_cfg_section_create(NULL);
   
   ret->com.plugin_reg = plugin_reg;
   ret->com.set_current_callback = bg_media_tree_set_current;
@@ -473,12 +473,18 @@ void bg_media_tree_destroy(bg_media_tree_t * t)
     free(t->com.metadata_format);
   if(t->com.blacklist)
     free(t->com.blacklist);
+
+  if(t->com.blacklist_files)
+    free(t->com.blacklist_files);
+
   if(t->com.load_handle)
     bg_plugin_unref(t->com.load_handle);
   
   if(t->filename)
     free(t->filename);
-
+  if(t->add_directory_path)
+    free(t->add_directory_path);
+  
 #ifdef HAVE_INOTIFY
   close(t->com.inotify_fd);
 #endif
@@ -533,7 +539,7 @@ bg_album_t * bg_media_tree_append_album(bg_media_tree_t * tree,
 void bg_media_tree_remove_album(bg_media_tree_t * tree,
                                 bg_album_t * album)
   {
-  char * tmp_path = (char *)0;
+  char * tmp_path = NULL;
 
   if(album->parent)
     bg_album_remove_from_parent(album);
@@ -659,7 +665,7 @@ void bg_media_tree_move_album_before(bg_media_tree_t * t,
   else
     {
     t->children = insert_album_before(t->children, album, after);
-    album->parent = (bg_album_t*)0;
+    album->parent = NULL;
     }
   }
 
@@ -693,7 +699,7 @@ void bg_media_tree_move_album_after(bg_media_tree_t * t,
   else
     {
     t->children = insert_album_after(t->children, album, before);
-    album->parent = (bg_album_t*)0;
+    album->parent = NULL;
     }
 
   
@@ -754,13 +760,13 @@ void bg_media_tree_move_album(bg_media_tree_t * t,
 
   if(!parent)
     {
-    t->children = insert_album_before(t->children, album, (bg_album_t*)0);
-    album->parent = (bg_album_t*)0;
+    t->children = insert_album_before(t->children, album, NULL);
+    album->parent = NULL;
     }
   else
     {
     parent->children = insert_album_before(parent->children,
-                                           album, (bg_album_t*)0);
+                                           album, NULL);
     album->parent = parent;
     }
   }
@@ -797,7 +803,7 @@ void bg_media_tree_set_current(void * data,
     }
   else
     {
-    t->com.current_entry = (bg_album_entry_t*)0;
+    t->com.current_entry = NULL;
     }
 
   if(last_current_album &&
@@ -871,8 +877,8 @@ static void create_shuffle_list(bg_media_tree_t * tree, bg_shuffle_mode_t shuffl
     
   /* 1. Create the list */
   
-  list       = (bg_shuffle_list_t*)0;
-  tmp_entry  = (bg_shuffle_list_t*)0;
+  list       = NULL;
+  tmp_entry  = NULL;
 
   if(shuffle_mode == BG_SHUFFLE_MODE_ALL)
     {
@@ -1073,8 +1079,8 @@ bg_media_tree_get_current_track(bg_media_tree_t * t, int * index)
   bg_track_info_t * track_info;
   const bg_plugin_info_t * info;
   bg_input_plugin_t * input_plugin;
-  bg_plugin_handle_t * ret = (bg_plugin_handle_t *)0;
-  //  char * system_location = (char*)0;
+  bg_plugin_handle_t * ret = NULL;
+
   if(!t->com.current_entry || !t->com.current_album)
     {
     bg_log(BG_LOG_ERROR, LOG_DOMAIN, "Doubleclick on a track first");
@@ -1126,7 +1132,8 @@ bg_media_tree_get_current_track(bg_media_tree_t * t, int * index)
            (char*)t->com.current_entry->location);
     goto fail;
     }
-  bg_album_update_entry(t->com.current_album, t->com.current_entry, track_info, 1);
+  bg_album_update_entry(t->com.current_album,
+                        t->com.current_entry, track_info, 1, 0);
 
   bg_album_common_set_auth_info(&t->com, t->com.current_entry);
   
@@ -1138,7 +1145,7 @@ bg_media_tree_get_current_track(bg_media_tree_t * t, int * index)
   
   fail:
   bg_media_tree_mark_error(t, 1);
-  return (bg_plugin_handle_t *)0;
+  return NULL;
   }
 
 bg_album_t * bg_media_tree_get_current_album(bg_media_tree_t * t)
@@ -1149,7 +1156,7 @@ bg_album_t * bg_media_tree_get_current_album(bg_media_tree_t * t)
 const char * bg_media_tree_get_current_track_name(bg_media_tree_t * t)
   {
   if(!t->com.current_album || !t->com.current_entry)
-    return (const char *)0;
+    return NULL;
   return t->com.current_entry->name;
   }
 
@@ -1189,18 +1196,22 @@ metadata\n\
 unused album files) at program exit")
     },
     {
-      .name =        "prefer_edl",
-      .long_name =   TRS("Prefer EDL"),
-      .type =        BG_PARAMETER_CHECKBUTTON,
-      .val_default = { .val_i = 0 },
-      .help_string = TRS("For files, which contain edit decision lists and raw streams, this option selects which one to decode. This setting is saved in the album once the file is loaded.")
+      .name =        "blacklist",
+      .long_name =   TRS("Blacklisted extensions"),
+      .type =        BG_PARAMETER_STRING,
+      .val_default = { .val_str = "srt txt pdf nfo" },
+      .help_string = TRS("File extensions, which are never loaded automatically"),
     },
     {
-      .name =        "blacklist",
-      .long_name =   TRS("Blacklist"),
+      .name =        "blacklist_files",
+      .long_name =   TRS("Blacklisted filenames"),
       .type =        BG_PARAMETER_STRING,
-      .val_default = { .val_str = "srt txt pdf" },
-      .help_string = TRS("File extensions, which are never loaded automatically"),
+      .help_string = TRS("Filenames, which are never loaded automatically"),
+    },
+    {
+      .name =        "add_directory_path",
+      .type =        BG_PARAMETER_STRING,
+      .flags =       BG_PARAMETER_HIDE_DIALOG,
     },
     { /* End of parameters */ }
   };
@@ -1210,11 +1221,26 @@ const bg_parameter_info_t * bg_media_tree_get_parameters(bg_media_tree_t * tree)
   return parameters;
   }
 
+int
+bg_media_tree_get_parameter(void * priv, const char * name,
+                            bg_parameter_value_t * val)
+  {
+  bg_media_tree_t * tree = priv;
+  if(!name)
+    return 0;
+  if(!strcmp(name, "add_directory_path"))
+    {
+    val->val_str =
+      bg_strdup(val->val_str, tree->add_directory_path);
+    return 1;
+    }
+  return 9;
+  }
+
 void bg_media_tree_set_parameter(void * priv, const char * name,
                                  const bg_parameter_value_t * val)
   {
-  bg_media_tree_t * tree;
-  tree = (bg_media_tree_t*)priv;
+  bg_media_tree_t * tree = priv;
   if(!name)
     return;
 
@@ -1230,13 +1256,18 @@ void bg_media_tree_set_parameter(void * priv, const char * name,
     {
     tree->com.blacklist = bg_strdup(tree->com.blacklist, val->val_str);
     }
+  else if(!strcmp(name, "blacklist_files"))
+    {
+    tree->com.blacklist_files = bg_strdup(tree->com.blacklist_files, val->val_str);
+    }
   else if(!strcmp(name, "purge_directory"))
     {
     tree->purge_directory = val->val_i;
     }
-  else if(!strcmp(name, "prefer_edl"))
+  else if(!strcmp(name, "add_directory_path"))
     {
-    tree->com.prefer_edl = val->val_i;
+    tree->add_directory_path = 
+      bg_strdup(tree->add_directory_path, val->val_str);
     }
   }
 
@@ -1268,6 +1299,7 @@ static void add_directory(bg_media_tree_t * t, bg_album_t * parent,
                           int subdirs_to_subalbums,
                           int watch,
                           const char * plugin,
+                          int prefer_edl,
                           int depth)
   {
   char * tmp_string;
@@ -1318,7 +1350,7 @@ static void add_directory(bg_media_tree_t * t, bg_album_t * parent,
     return;
 
   urls[0] = filename;
-  urls[1] = (char*)0;
+  urls[1] = NULL;
   
   while(!readdir_r(dir, &dent.d, &dent_ptr))
     {
@@ -1339,19 +1371,19 @@ static void add_directory(bg_media_tree_t * t, bg_album_t * parent,
       {
       add_directory(t, a, filename, recursive, subdirs_to_subalbums,
                     watch,
-                    plugin, depth + 1);
+                    plugin, prefer_edl, depth + 1);
       }
     else if(S_ISREG(stat_buf.st_mode))
       {
       if(watch)
         bg_album_insert_file_before(a, filename,
-                                    plugin,
-                                    (bg_album_entry_t *)0,
+                                    plugin, prefer_edl,
+                                    NULL,
                                     stat_buf.st_mtime);
       else
         bg_album_insert_file_before(a, filename,
-                                    plugin,
-                                    (bg_album_entry_t *)0,
+                                    plugin, prefer_edl,
+                                    NULL,
                                     0);
       }
     if(t->change_callback)
@@ -1375,12 +1407,24 @@ void bg_media_tree_add_directory(bg_media_tree_t * t, bg_album_t * parent,
                                  int recursive,
                                  int subdirs_to_subalbums,
                                  int watch,
-                                 const char * plugin)
+                                 const char * plugin, int prefer_edl)
   {
+  char * pos;
   add_directory(t, parent, directory, recursive, subdirs_to_subalbums,
                 watch,
-                plugin, 0);
-  
+                plugin, prefer_edl, 0);
+  t->add_directory_path = bg_strdup(t->add_directory_path, directory);
+
+  pos = strrchr(t->add_directory_path, '/');
+
+  if(pos && (pos - t->add_directory_path < strlen(t->add_directory_path) - 1))
+    *pos = '\0';
+  }
+
+const char *
+bg_media_tree_get_add_directory_path(bg_media_tree_t * t)
+  {
+  return t->add_directory_path;
   }
 
 static int albums_have_file(bg_album_t * album, const char * filename)
@@ -1453,8 +1497,8 @@ void bg_album_common_prepare_callbacks(bg_album_common_t * com, bg_album_entry_t
   {
   if(!entry)
     {
-    if(com->username) { free(com->username); com->username = (char*)0; }
-    if(com->password) { free(com->password); com->password = (char*)0; }
+    if(com->username) { free(com->username); com->username = NULL; }
+    if(com->password) { free(com->password); com->password = NULL; }
     com->save_auth = 0;
     }
   else
@@ -1484,19 +1528,19 @@ void bg_album_common_set_auth_info(bg_album_common_t * com, bg_album_entry_t * e
 
 bg_album_t * bg_media_tree_get_device_album(bg_media_tree_t * t, const char * gml)
   {
-  bg_album_t * ret = (bg_album_t *)0;
+  bg_album_t * ret = NULL;
   const bg_plugin_info_t * plugin_info;
-  char * protocol = (char *)0;
-  char * path = (char *)0;
+  char * protocol = NULL;
+  char * path = NULL;
   
   if(!bg_url_split(gml,
                    &protocol,
-                   (char **)0, // user,
-                   (char **)0, //  password,
-                   (char **)0, //  hostname,
-                   (int*)0, //  port,
+                   NULL, // user,
+                   NULL, //  password,
+                   NULL, //  hostname,
+                   NULL, //  port,
                    &path)) //  path)
-    return (bg_album_t*)0;
+    return NULL;
 
   /* 1. Seek the plugin */
   plugin_info = bg_plugin_find_by_protocol(t->com.plugin_reg, protocol);
@@ -1546,7 +1590,7 @@ void bg_media_tree_copy_current_to_favourites(bg_media_tree_t * t)
   bg_album_insert_entries_before(t->com.favourites,
                                  bg_album_entry_copy(t->com.current_album,
                                                      t->com.current_entry),
-                                 (bg_album_entry_t*)0);
+                                 NULL);
   
   if(!was_open)
     bg_album_close(t->com.favourites);
@@ -1572,7 +1616,7 @@ void bg_media_tree_check_sync(bg_media_tree_t * t)
   FD_ZERO(&read_fds);
   FD_SET(t->com.inotify_fd, &read_fds);
   if(!select(t->com.inotify_fd+1,
-             &read_fds, (fd_set*)0, (fd_set*)0,&timeout))
+             &read_fds, NULL, NULL,&timeout))
     return;
 
   result = read(t->com.inotify_fd, buffer, BUF_LEN);
