@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -122,8 +122,11 @@ int bg_x11_window_init_gl(bg_x11_window_t * win)
                                         attr_list, &num_fbconfigs);
 
   if(!win->gl_fbconfigs)
+    {
+    bg_log(BG_LOG_ERROR, LOG_DOMAIN,
+           "No framebuffer configs found (insufficient driver or hardware)");
     return 0;
-  
+    }
   /* Create context */
   
   win->glxcontext =
@@ -145,10 +148,14 @@ void bg_x11_window_set_gl_attribute(bg_x11_window_t * win,
   win->gl_attributes[attribute].changed = 1;
   }
 
-void bg_x11_window_start_gl(bg_x11_window_t * win)
+int bg_x11_window_start_gl(bg_x11_window_t * win)
   {
-  XVisualInfo * vi =
-    glXGetVisualFromFBConfig(win->dpy, win->gl_fbconfigs[0]);
+  XVisualInfo * vi;
+
+  if(!win->gl_fbconfigs)
+    return 0;
+  
+  vi = glXGetVisualFromFBConfig(win->dpy, win->gl_fbconfigs[0]);
   
   /* Create subwindows */
   bg_x11_window_create_subwins(win, vi->depth, vi->visual);
@@ -161,6 +168,7 @@ void bg_x11_window_start_gl(bg_x11_window_t * win)
                                             win->gl_fbconfigs[0],
                                             win->fullscreen.subwin, NULL);
   XFree(vi);
+  return 1;
   }
 
 void bg_x11_window_stop_gl(bg_x11_window_t * win)
@@ -222,9 +230,9 @@ int bg_x11_window_init_gl(bg_x11_window_t * win)
   return 0;
   }
 
-void bg_x11_window_start_gl(bg_x11_window_t * win)
+int bg_x11_window_start_gl(bg_x11_window_t * win)
   {
-  
+  return 0;
   }
 
 void bg_x11_window_stop_gl(bg_x11_window_t * win)
