@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -51,7 +51,7 @@ static gavl_video_frame_t * create_frame_ximage(driver_data_t * d)
     /* Create Shm Image */
     frame->x11_image = XShmCreateImage(w->dpy, w->visual,
                                        w->depth, ZPixmap,
-                                       NULL, &(frame->shminfo),
+                                       NULL, &frame->shminfo,
                                        w->window_format.frame_width,
                                        w->window_format.frame_height);
     if(!frame->x11_image)
