@@ -34,6 +34,8 @@
 
 #define LOG_DOMAIN "i_cdaudio"
 
+#include <gavl/metatags.h>
+
 typedef struct
   {
   bg_parameter_info_t * parameters;
@@ -108,12 +110,12 @@ static void destroy_cd_data(cdaudio_t* cd)
     for(i = 0; i < cd->index->num_audio_tracks; i++)
       bg_track_info_free(&cd->track_info[i]);
     free(cd->track_info);
-    cd->track_info = (bg_track_info_t*)0;
+    cd->track_info = NULL;
     }
   if(cd->index)
     {
     bg_cdaudio_index_destroy(cd->index);
-    cd->index = (bg_cdaudio_index_t*)0;
+    cd->index = NULL;
     }
 
   }
@@ -122,7 +124,7 @@ static void destroy_cd_data(cdaudio_t* cd)
 static const char * get_disc_name_cdaudio(void* priv)
   {
   cdaudio_t * cd;
-  cd = (cdaudio_t *)priv;
+  cd = priv;
   return cd->disc_name;
   }
 
@@ -140,14 +142,14 @@ static void set_callbacks_cdaudio(void * data,
                            bg_input_callbacks_t * callbacks)
   {
   cdaudio_t * cd;
-  cd = (cdaudio_t *)data;
+  cd = data;
   cd->callbacks = callbacks;
   }
 
 static void destroy_cdaudio(void * data)
   {
   cdaudio_t * cd;
-  cd = (cdaudio_t *)data;
+  cd = data;
 
   destroy_cd_data(cd);
   
@@ -171,7 +173,7 @@ static int open_cdaudio(void * data, const char * arg)
 
   char * tmp_filename;
     
-  cdaudio_t * cd = (cdaudio_t*)data;
+  cdaudio_t * cd = data;
 
   /* Destroy data from previous open */
   destroy_cd_data(cd);
@@ -206,7 +208,8 @@ static int open_cdaudio(void * data, const char * arg)
       cd->track_info[j].audio_streams[0].format.num_channels = 2;
       cd->track_info[j].audio_streams[0].format.sample_format = GAVL_SAMPLE_S16;
       cd->track_info[j].audio_streams[0].format.interleave_mode = GAVL_INTERLEAVE_ALL;
-      cd->track_info[j].audio_streams[0].description = bg_strdup(NULL, "CD audio");
+      gavl_metadata_set(&cd->track_info[j].audio_streams[0].m, GAVL_META_FORMAT,
+                        "CD Audio");
       
       gavl_set_channel_setup(&cd->track_info[j].audio_streams[0].format);
       
@@ -214,8 +217,11 @@ static int open_cdaudio(void * data, const char * arg)
         ((int64_t)(cd->index->tracks[i].last_sector -
                    cd->index->tracks[i].first_sector + 1) *
          GAVL_TIME_SCALE) / 75;
-      cd->track_info[j].description = bg_strdup(NULL, TR("CD audio track"));
-      cd->track_info[j].metadata.track = j+1;
+
+      gavl_metadata_set(&cd->track_info[j].metadata, GAVL_META_FORMAT,
+                        "CD Audio");
+      gavl_metadata_set_int(&cd->track_info[j].metadata, GAVL_META_TRACKNUMBER,
+                            j+1);
       cd->track_info[j].flags = BG_TRACK_SEEKABLE | BG_TRACK_PAUSABLE;
       }
     }
@@ -329,9 +335,7 @@ static int open_cdaudio(void * data, const char * arg)
                                  cd->trackname_template);
         }
       }
-    if(cd->track_info[0].metadata.album)
-      cd->disc_name = cd->track_info[0].metadata.album;
-    
+    cd->disc_name = gavl_metadata_get(&cd->track_info[0].metadata, GAVL_META_ALBUM);
     }
 
   /* We close it again, so other apps won't cry */
@@ -343,20 +347,20 @@ static int open_cdaudio(void * data, const char * arg)
 
 static int get_num_tracks_cdaudio(void * data)
   {
-  cdaudio_t * cd = (cdaudio_t*)data;
+  cdaudio_t * cd = data;
   return cd->index->num_audio_tracks;
   }
 
 static bg_track_info_t * get_track_info_cdaudio(void * data, int track)
   {
-  cdaudio_t * cd = (cdaudio_t*)data;
+  cdaudio_t * cd = data;
   return &cd->track_info[track];
   }
 
 static int set_track_cdaudio(void * data, int track)
   {
   int i;
-  cdaudio_t * cd = (cdaudio_t*)data;
+  cdaudio_t * cd = data;
 
   for(i = 0; i < cd->index->num_tracks; i++)
     {
@@ -381,7 +385,7 @@ static int set_audio_stream_cdaudio(void * priv, int stream,
 static int start_cdaudio(void * priv)
   {
   int i;
-  cdaudio_t * cd = (cdaudio_t*)priv;
+  cdaudio_t * cd = priv;
 
 
   if(!cd->cdio)
@@ -406,7 +410,7 @@ static int start_cdaudio(void * priv)
 
 static void stop_cdaudio(void * priv)
   {
-  cdaudio_t * cd = (cdaudio_t*)priv;
+  cdaudio_t * cd = priv;
   if(cd->rip_initialized)
     {
     bg_cdaudio_rip_close(cd->ripper);
@@ -414,10 +418,10 @@ static void stop_cdaudio(void * priv)
     if(cd->frame)
       {
       gavl_audio_frame_destroy(cd->frame);
-      cd->frame = (gavl_audio_frame_t*)0;
+      cd->frame = NULL;
       }
     }
-  cd->cdio = (CdIo_t*)0;
+  cd->cdio = NULL;
   }
 
 static void read_frame(cdaudio_t * cd)
@@ -446,7 +450,7 @@ static int read_audio_cdaudio(void * priv,
                               int num_samples)
   {
   int samples_read = 0, samples_copied;
-  cdaudio_t * cd = (cdaudio_t*)priv;
+  cdaudio_t * cd = priv;
   
   if(cd->current_sector > cd->index->tracks[cd->current_track].last_sector)
     {
@@ -485,7 +489,7 @@ static void seek_cdaudio(void * priv, int64_t * time, int scale)
 
   uint32_t sample_position, samples_to_skip;
   
-  cdaudio_t * cd = (cdaudio_t*)priv;
+  cdaudio_t * cd = priv;
   
   if(!cd->rip_initialized)
     {
@@ -520,12 +524,12 @@ static void seek_cdaudio(void * priv, int64_t * time, int scale)
 
 static void close_cdaudio(void * priv)
   {
-  cdaudio_t * cd = (cdaudio_t*)priv;
+  cdaudio_t * cd = priv;
   if(cd->cdio)
     {
     bg_cdaudio_close(cd->cdio);
     }
-  cd->cdio = (CdIo_t*)0;
+  cd->cdio = NULL;
   }
 
 /* Configuration stuff */
@@ -683,14 +687,14 @@ $HOME/.gmerlin/cdaudio_metadata. If you got wrong metadata for a CD,\
 
 static const bg_parameter_info_t * get_parameters_cdaudio(void * data)
   {
-  cdaudio_t * cd = (cdaudio_t*)data;
+  cdaudio_t * cd = data;
   bg_parameter_info_t const * srcs[3];
 
   if(!cd->parameters)
     {
     srcs[0] = parameters;
     srcs[1] = bg_cdaudio_rip_get_parameters();
-    srcs[2] = (bg_parameter_info_t*)0;
+    srcs[2] = NULL;
     cd->parameters = bg_parameter_info_concat_arrays(srcs);
     }
     
@@ -700,7 +704,7 @@ static const bg_parameter_info_t * get_parameters_cdaudio(void * data)
 static void set_parameter_cdaudio(void * data, const char * name,
                                   const bg_parameter_value_t * val)
   {
-  cdaudio_t * cd = (cdaudio_t*)data;
+  cdaudio_t * cd = data;
 
   if(!name)
     return;
