@@ -36,6 +36,8 @@
 #include <gmerlin/log.h>
 #define LOG_DOMAIN "ir_bmp"
 
+#include <gavl/metatags.h>
+
 
 #define BI_RGB       0
 #define BI_RLE8      1
@@ -58,6 +60,8 @@ typedef struct
   unsigned long width, height;
   unsigned long y_per_meter, x_per_meter;
   RGBQUAD rgbQuads[256];
+
+  gavl_metadata_t m;
   } bmp_t;
 
 
@@ -92,7 +96,11 @@ static void * create_bmp()
 
 static void destroy_bmp(void* priv) 
   {
-  bmp_t * bmp = (bmp_t*)priv;
+  bmp_t * bmp = priv;
+
+  if(bmp->bmp_file)
+    fclose(bmp->bmp_file);
+  
   if(bmp)
     free(bmp);
   }
@@ -210,7 +218,7 @@ static gavl_pixelformat_t get_csp(int bits, uint32_t r_mask,
 static int read_header_bmp(void *priv,const char *filename, gavl_video_format_t * format)
   {
   int i;
-  bmp_t *p = (bmp_t*)priv;
+  bmp_t *p = priv;
   char type[2];
   unsigned short ncols, tmpShort = 0, planes;
   unsigned long headSize = 0, size;
@@ -234,13 +242,11 @@ static int read_header_bmp(void *priv,const char *filename, gavl_video_format_t
   if(fread(type, 1, 2, p->bmp_file)!=2)
     {
     bg_log(BG_LOG_ERROR, LOG_DOMAIN, "Cannot read File type");
-    fclose(p->bmp_file);
     return 0;
     }
   if(strncmp(type, "BM", 2))
     {
     bg_log(BG_LOG_ERROR, LOG_DOMAIN,"File is no BMP");
-    fclose(p->bmp_file);
     return 0;
     }
 
@@ -274,7 +280,6 @@ static int read_header_bmp(void *priv,const char *filename, gavl_video_format_t
     }
   else
     {
-    fclose(p->bmp_file);
     return 0;
     }
 
@@ -282,7 +287,6 @@ static int read_header_bmp(void *priv,const char *filename, gavl_video_format_t
   
   if ((p->width < 1) || (p->height < 1) || (p->width > 8192) || (p->height > 8192))
     {
-    fclose(p->bmp_file);
     bg_log(BG_LOG_ERROR, LOG_DOMAIN,"Cannot detect image dimensions");
     return 0;
     }
@@ -291,7 +295,6 @@ static int read_header_bmp(void *priv,const char *filename, gavl_video_format_t
   
   if ((p->bitcount != 1) && (p->bitcount != 4) && (p->bitcount != 8) && (p->bitcount != 16) && (p->bitcount != 24) && (p->bitcount != 32))
     {
-    fclose(p->bmp_file);
     bg_log(BG_LOG_ERROR, LOG_DOMAIN,"Depth %d not supported", p->bitcount);
     return 0;
     }
@@ -346,6 +349,9 @@ static int read_header_bmp(void *priv,const char *filename, gavl_video_format_t
   format->image_height = format->frame_height;
   format->pixel_width = 1;
   format->pixel_height = 1;
+
+  gavl_metadata_set(&p->m, GAVL_META_FORMAT, "BMP");
+  
   
   return 1;
   }
@@ -353,7 +359,7 @@ static int read_header_bmp(void *priv,const char *filename, gavl_video_format_t
 static int read_image_bmp(void *priv, gavl_video_frame_t *frame)
   {
   int keep_going;
-  bmp_t *p = (bmp_t*)priv;
+  bmp_t *p = priv;
   uint8_t * frame_ptr;
   uint8_t * frame_ptr_start;
   unsigned char byte = 0;
@@ -369,6 +375,7 @@ static int read_image_bmp(void *priv, gavl_video_frame_t *frame)
   if(!frame)
     {
     fclose(p->bmp_file);
+    p->bmp_file = NULL;
     return 1;
     }
   
@@ -379,11 +386,13 @@ static int read_image_bmp(void *priv, gavl_video_frame_t *frame)
   if (!buffer)
     {
     fclose(p->bmp_file);
+    p->bmp_file = NULL;
     return 0;
     }
   
   fread(buffer, 1, p->imgsize, p->bmp_file);
   fclose(p->bmp_file);
+  p->bmp_file = NULL;
   
   buffer_ptr = buffer;
   buffer_end = buffer + p->imgsize;
@@ -736,6 +745,12 @@ static int read_image_bmp(void *priv, gavl_video_frame_t *frame)
   return 1;
   }
 
+static const gavl_metadata_t * get_metadata_bmp(void * priv)
+  {
+  bmp_t *p = priv;
+  return &p->m;
+  }
+
 const bg_image_reader_plugin_t the_plugin =
   {
     .common =
@@ -752,6 +767,7 @@ const bg_image_reader_plugin_t the_plugin =
     },
     .extensions =    "bmp",
     .read_header = read_header_bmp,
+    .get_metadata = get_metadata_bmp,
     .read_image =  read_image_bmp,
   };
 
