@@ -92,7 +92,8 @@ static void destroy_jpeg(void * priv)
 
 static
 int write_header_jpeg(void * priv, const char * filename,
-                      gavl_video_format_t * format, const bg_metadata_t * metadata)
+                      gavl_video_format_t * format,
+                      const gavl_metadata_t * metadata)
   {
   jpeg_t * jpeg = priv;
 
@@ -275,7 +276,7 @@ static const bg_parameter_info_t parameters[] =
       .multi_names = (char const *[]) { "4:2:0",
                            "4:2:2",
                            "4:4:4",
-                           (char*)0 },
+                           NULL },
       
     },
     { /* End of parameters */ }
@@ -291,7 +292,7 @@ static void set_parameter_jpeg(void * p, const char * name,
                                const bg_parameter_value_t * val)
   {
   jpeg_t * jpeg;
-  jpeg = (jpeg_t *)p;
+  jpeg = p;
   
   if(!name)
     return;
