@@ -28,6 +28,7 @@
 #include <gmerlin/pluginfuncs.h>
 #include <gmerlin/utils.h>
 #include <gmerlin/log.h>
+#include <gavl/metatags.h>
 
 #include "lqt_common.h"
 #include "lqtgavl.h"
@@ -92,6 +93,8 @@ typedef struct
     uint8_t ** rows;
     lqt_codec_info_t ** codec_info;
     bg_encoder_framerate_t fr;
+    int64_t frames_written;
+    int64_t pts_offset;
     } * video_streams;
   
   struct
@@ -152,10 +155,9 @@ static const char * get_extension(int type)
   }
 
 static int open_lqt(void * data, const char * filename,
-                    const bg_metadata_t * metadata,
+                    const gavl_metadata_t * m,
                     const bg_chapter_list_t * chapter_list)
   {
-  char * track_string;
   e_lqt_t * e = data;
 
   e->filename = bg_filename_ensure_extension(filename, get_extension(e->file_type));
@@ -174,7 +176,6 @@ static int open_lqt(void * data, const char * filename,
     }
   else
     {
-    
     e->file = lqt_open_write(e->filename, e->file_type);
     }
   if(!e->file)
@@ -188,29 +189,67 @@ static int open_lqt(void * data, const char * filename,
     
   /* Set metadata */
 
-  if(metadata)
+  if(m)
     {
-    if(metadata->copyright)
-      quicktime_set_copyright(e->file, metadata->copyright);
-    if(metadata->title)
-      quicktime_set_name(e->file, metadata->title);
+    char * tag;
 
-    if(metadata->comment)
-      lqt_set_comment(e->file, metadata->comment);
-    if(metadata->artist)
-      lqt_set_artist(e->file, metadata->artist);
-    if(metadata->genre)
-      lqt_set_genre(e->file, metadata->genre);
-    if(metadata->track)
+    /* TODO: Make the arguments in lqt const friendly */
+    
+    tag = bg_strdup(NULL, gavl_metadata_get(m, GAVL_META_COPYRIGHT));
+    if(tag)
       {
-      track_string = bg_sprintf("%d", metadata->track);
-      lqt_set_track(e->file, track_string);
-      free(track_string);
+      quicktime_set_copyright(e->file, tag);
+      free(tag);
+      }
+
+    tag = bg_strdup(NULL, gavl_metadata_get(m, GAVL_META_TITLE));
+    if(tag)
+      {
+      quicktime_set_name(e->file, tag);
+      free(tag);
+      }
+    
+    tag = bg_strdup(NULL, gavl_metadata_get(m, GAVL_META_COMMENT));
+    if(tag)
+      {
+      lqt_set_comment(e->file, tag);
+      free(tag);
+      }
+    
+    tag = bg_strdup(NULL, gavl_metadata_get(m, GAVL_META_ARTIST));
+    if(tag)
+      {
+      lqt_set_artist(e->file, tag);
+      free(tag);
+      }
+    
+    tag = bg_strdup(NULL, gavl_metadata_get(m, GAVL_META_GENRE));
+    if(tag)
+      {
+      lqt_set_genre(e->file, tag);
+      free(tag);
+      }
+    
+    tag = bg_strdup(NULL, gavl_metadata_get(m, GAVL_META_TRACKNUMBER));
+    if(tag)
+      {
+      lqt_set_track(e->file, tag);
+      free(tag);
+      }
+
+    tag = bg_strdup(NULL, gavl_metadata_get(m, GAVL_META_ALBUM));
+    if(tag)
+      {
+      lqt_set_album(e->file, tag);
+      free(tag);
+      }
+
+    tag = bg_strdup(NULL, gavl_metadata_get(m, GAVL_META_AUTHOR));
+    if(tag)
+      {
+      lqt_set_author(e->file, tag);
+      free(tag);
       }
-    if(metadata->album)
-      lqt_set_album(e->file, metadata->album);
-    if(metadata->author)
-      lqt_set_author(e->file, metadata->author);
     }
   
   e->chapter_list = chapter_list;
@@ -231,18 +270,16 @@ static int writes_compressed_video_lqt(void * data,
                                        const gavl_compression_info_t * ci)
   {
   e_lqt_t * e = data;
-
-  fprintf(stderr, "writes_compressed_video_lqt\n");
-  gavl_video_format_dump(format);
-
   return lqt_gavl_writes_compressed_video(e->file_type, format, ci);
   }
 
 
 
-static int add_audio_stream_lqt(void * data, const char * language,
+static int add_audio_stream_lqt(void * data,
+                                const gavl_metadata_t * m,
                                 const gavl_audio_format_t * format)
   {
+  const char * tag;
   e_lqt_t * e = data;
 
   e->audio_streams =
@@ -255,16 +292,22 @@ static int add_audio_stream_lqt(void * data, const char * language,
   
   lqt_gavl_add_audio_track(e->file, &e->audio_streams[e->num_audio_streams].format,
                            NULL);
-  lqt_set_audio_language(e->file, e->num_audio_streams, language);
+
+  tag = gavl_metadata_get(m, GAVL_META_LANGUAGE);
+  if(tag)
+    lqt_set_audio_language(e->file, e->num_audio_streams, tag);
   
   e->num_audio_streams++;
   return e->num_audio_streams-1;
   }
 
-static int add_audio_stream_compressed_lqt(void * data, const char * language,
-                                           const gavl_audio_format_t * format,
-                                           const gavl_compression_info_t * ci)
+static int
+add_audio_stream_compressed_lqt(void * data,
+                                const gavl_metadata_t * m,
+                                const gavl_audio_format_t * format,
+                                const gavl_compression_info_t * ci)
   {
+  const char * tag;
   e_lqt_t * e = data;
 
   e->audio_streams =
@@ -273,12 +316,20 @@ static int add_audio_stream_compressed_lqt(void * data, const char * language,
   memset(&e->audio_streams[e->num_audio_streams], 0,
          sizeof(*(e->audio_streams)));
   lqt_gavl_add_audio_track_compressed(e->file, format, ci);
+
+  tag = gavl_metadata_get(m, GAVL_META_LANGUAGE);
+  if(tag)
+    lqt_set_audio_language(e->file, e->num_audio_streams, tag);
+  
   e->num_audio_streams++;
   return e->num_audio_streams-1;
   }
 
-static int add_subtitle_text_stream_lqt(void * data, const char * language, int * timescale)
+static int add_subtitle_text_stream_lqt(void * data,
+                                        const gavl_metadata_t * m,
+                                        int * timescale)
   {
+  const char * tag;
   e_lqt_t * e = data;
 
   e->subtitle_text_streams =
@@ -289,8 +340,11 @@ static int add_subtitle_text_stream_lqt(void * data, const char * language, int
   memset(&e->subtitle_text_streams[e->num_subtitle_text_streams], 0,
          sizeof(*(e->subtitle_text_streams)));
 
-  strncpy(e->subtitle_text_streams[e->num_subtitle_text_streams].language,
-          language, 3);
+  tag = gavl_metadata_get(m, GAVL_META_LANGUAGE);
+  if(tag)
+    strncpy(e->subtitle_text_streams[e->num_subtitle_text_streams].language,
+            tag, 3);
+  
   e->subtitle_text_streams[e->num_subtitle_text_streams].timescale = *timescale;
   
   e->num_subtitle_text_streams++;
@@ -299,6 +353,7 @@ static int add_subtitle_text_stream_lqt(void * data, const char * language, int
 
 
 static int add_video_stream_lqt(void * data,
+                                const gavl_metadata_t* m,
                                 const gavl_video_format_t* format)
   {
   e_lqt_t * e = data;
@@ -319,9 +374,11 @@ static int add_video_stream_lqt(void * data,
   return e->num_video_streams-1;
   }
 
-static int add_video_stream_compressed_lqt(void * data,
-                                           const gavl_video_format_t* format,
-                                           const gavl_compression_info_t * ci)
+static int
+add_video_stream_compressed_lqt(void * data,
+                                const gavl_metadata_t* m,
+                                const gavl_video_format_t* format,
+                                const gavl_compression_info_t * ci)
   {
   e_lqt_t * e = data;
 
@@ -435,6 +492,9 @@ static int write_audio_frame_lqt(void * data, gavl_audio_frame_t* frame,
   gavl_time_t test_time;
   e_lqt_t * e = data;
 
+  if(!e->audio_streams[stream].samples_written && frame->timestamp)
+    lqt_set_audio_pts_offset(e->file, stream, frame->timestamp);
+  
   e->audio_streams[stream].samples_written += frame->valid_samples;
   
   test_time = gavl_time_unscale(e->audio_streams[stream].format.samplerate,
@@ -447,7 +507,7 @@ static int write_audio_frame_lqt(void * data, gavl_audio_frame_t* frame,
   }
 
 static int write_video_frame_lqt(void * data, gavl_video_frame_t* frame,
-                                  int stream)
+                                 int stream)
   {
   gavl_time_t test_time;
   e_lqt_t * e = data;
@@ -456,9 +516,19 @@ static int write_video_frame_lqt(void * data, gavl_video_frame_t* frame,
                                 frame->timestamp);
   if(e->duration < test_time)
     e->duration = test_time;
+
+  if(!e->video_streams[stream].frames_written)
+    {
+    e->video_streams[stream].pts_offset = frame->timestamp;
+    if(e->video_streams[stream].pts_offset)
+      lqt_set_video_pts_offset(e->file, stream,
+                               e->video_streams[stream].pts_offset);
+    }
+  e->video_streams[stream].frames_written++;
   
   return !lqt_gavl_encode_video(e->file, stream, frame,
-                                e->video_streams[stream].rows);
+                                e->video_streams[stream].rows,
+                                e->video_streams[stream].pts_offset);
   }
 
 static int write_subtitle_text_lqt(void * data,const char * text,
@@ -549,7 +619,7 @@ static int close_lqt(void * data, int do_delete)
     }
   
   quicktime_close(e->file);
-  e->file = (quicktime_t*)0;
+  e->file = NULL;
   
   if(do_delete)
     remove(e->filename);
@@ -565,12 +635,12 @@ static int close_lqt(void * data, int do_delete)
   if(e->filename)
     {
     free(e->filename);
-    e->filename = (char*)0;
+    e->filename = NULL;
     }
   if(e->filename_tmp)
     {
     free(e->filename_tmp);
-    e->filename_tmp = (char*)0;
+    e->filename_tmp = NULL;
     }
   if(e->audio_streams)
     {
@@ -632,9 +702,9 @@ static const bg_parameter_info_t common_parameters[] =
       .name =      "format",
       .long_name = TRS("Format"),
       .type =      BG_PARAMETER_STRINGLIST,
-      .multi_names =    (char const *[]) { "quicktime", "avi", "avi_opendml",   "mp4", "m4a", "3gp", (char*)0 },
+      .multi_names =    (char const *[]) { "quicktime", "avi", "avi_opendml",   "mp4", "m4a", "3gp", NULL },
       .multi_labels =   (char const *[]) { TRS("Quicktime"), TRS("AVI"), TRS("AVI (Opendml)"),
-                                  TRS("MP4"), TRS("M4A"), TRS("3GP"), (char*)0 },
+                                  TRS("MP4"), TRS("M4A"), TRS("3GP"), NULL },
       .val_default = { .val_str = "quicktime" },
     },
     {
@@ -796,13 +866,41 @@ static void set_video_parameter_lqt(void * data, int stream, const char * name,
 
 static int write_video_packet_lqt(void * data, gavl_packet_t * p, int stream)
   {
+  gavl_time_t test_time;
   e_lqt_t * e = data;
+  
+  test_time = gavl_time_unscale(e->video_streams[stream].format.timescale,
+                                p->pts);
+  if(e->duration < test_time)
+    e->duration = test_time;
+
+  
+  if(!e->video_streams[stream].frames_written)
+    {
+    e->video_streams[stream].pts_offset = p->pts;
+    if(e->video_streams[stream].pts_offset)
+      lqt_set_video_pts_offset(e->file, stream,
+                               e->video_streams[stream].pts_offset);
+    }
+  e->video_streams[stream].frames_written++;
+  
   return lqt_gavl_write_video_packet(e->file, stream, p);
   }
 
 static int write_audio_packet_lqt(void * data, gavl_packet_t * p, int stream)
   {
+  gavl_time_t test_time;
   e_lqt_t * e = data;
+
+  if(!e->audio_streams[stream].samples_written && p->pts)
+    lqt_set_audio_pts_offset(e->file, stream, p->pts);
+  e->audio_streams[stream].samples_written += p->duration;
+
+  test_time = gavl_time_unscale(e->audio_streams[stream].format.samplerate,
+                                e->audio_streams[stream].samples_written);
+  if(e->duration < test_time)
+    e->duration = test_time;
+  
   return lqt_gavl_write_audio_packet(e->file, stream, p);
   }
 
