@@ -27,6 +27,7 @@
 #include <gmerlin/translation.h>
 #include <gmerlin/plugin.h>
 #include <gmerlin/utils.h>
+#include <gavl/metatags.h>
 
 #include <png.h>
 
@@ -40,7 +41,7 @@ typedef struct
 
   FILE * file;
   
-  bg_metadata_t metadata;
+  gavl_metadata_t metadata;
   } png_t;
 
 static void * create_png()
@@ -55,6 +56,13 @@ static void destroy_png(void* priv)
   {
   png_t * png = priv;
 
+  if(png->png_ptr)
+    png_destroy_read_struct(&png->png_ptr, &png->info_ptr,
+                            &png->end_info);
+  
+  if(png->file)
+    fclose(png->file);
+  
   free(png);
   }
 
@@ -86,8 +94,7 @@ static int read_header_png(void * priv, const char * filename,
     goto fail;
 
   png->png_ptr = png_create_read_struct
-    (PNG_LIBPNG_VER_STRING, (png_voidp)0,
-     NULL, NULL);
+    (PNG_LIBPNG_VER_STRING, NULL, NULL, NULL);
 
   setjmp(png_jmpbuf(png->png_ptr));
 
@@ -130,10 +137,8 @@ static int read_header_png(void * priv, const char * filename,
 #if BG_MAKE_BUILD(PNG_LIBPNG_VER_MAJOR, PNG_LIBPNG_VER_MINOR, PNG_LIBPNG_VER_RELEASE) < BG_MAKE_BUILD(1,2,9)
         png_set_gray_1_2_4_to_8(png->png_ptr);
 #else
-      png_set_expand_gray_1_2_4_to_8(png->png_ptr);
+        png_set_expand_gray_1_2_4_to_8(png->png_ptr);
 #endif
-
-        png_set_gray_1_2_4_to_8(png->png_ptr);
       if (png_get_valid(png->png_ptr, png->info_ptr, PNG_INFO_tRNS))
         {
         png_set_tRNS_to_alpha(png->png_ptr);
@@ -231,17 +236,17 @@ static int read_header_png(void * priv, const char * filename,
       if(text[i].compression == PNG_TEXT_COMPRESSION_NONE)
         {
         if(!strcasecmp(text[i].key, "Author"))
-          png->metadata.author = bg_strdup(png->metadata.author, text[i].text);
-        else if(!strcasecmp(text[i].key, "Title"))
-          png->metadata.title = bg_strdup(png->metadata.title, text[i].text);
-        else if(!strcasecmp(text[i].key, "Copyright"))
-          png->metadata.copyright = bg_strdup(png->metadata.copyright, text[i].text);
+          gavl_metadata_set(&png->metadata, GAVL_META_AUTHOR, text[i].text);
+        if(!strcasecmp(text[i].key, "Title"))
+          gavl_metadata_set(&png->metadata, GAVL_META_TITLE, text[i].text);
+        if(!strcasecmp(text[i].key, "Copyright"))
+          gavl_metadata_set(&png->metadata, GAVL_META_COPYRIGHT, text[i].text);
         else
-          bg_metadata_append_ext(&png->metadata, text[i].key, text[i].text);
-        // fprintf(stderr, "png text: key: %s text: %s\n", text[i].key, text[i].text);
+          gavl_metadata_set(&png->metadata, text[i].key, text[i].text);
         }
       }
     }
+  gavl_metadata_set(&png->metadata, GAVL_META_FORMAT, "PNG");
   
   gavl_video_format_copy(&png->format, format);
   return 1;
@@ -257,10 +262,10 @@ static int get_compression_info_png(void * priv, gavl_compression_info_t * ci)
   }
 
 
-static const bg_metadata_t * get_metadata_png(void * priv)
+static const gavl_metadata_t * get_metadata_png(void * priv)
   {
   png_t * png = priv;
-  return(&png->metadata);
+  return &png->metadata;
   }
 
 static int read_image_png(void * priv, gavl_video_frame_t * frame)
@@ -283,11 +288,16 @@ static int read_image_png(void * priv, gavl_video_frame_t * frame)
   
   png_destroy_read_struct(&png->png_ptr, &png->info_ptr,
                           &png->end_info);
+  
+  png->png_ptr = NULL;
+  png->info_ptr = NULL;
+  png->end_info = NULL;
+  
   fclose(png->file);
-
+  png->file = NULL;
   if(rows)
     free(rows);
-  bg_metadata_free(&png->metadata);
+  gavl_metadata_free(&png->metadata);
   return 1;
   }
 
