@@ -81,7 +81,7 @@ static void * create_vcdimager()
 static void destroy_vcdimager(void * priv)
   {
   vcdimager_t * vcdimager;
-  vcdimager = (vcdimager_t*)priv;
+  vcdimager = priv;
 
   FREE(vcdimager->xml_file);
   FREE(vcdimager->bin_file);
@@ -110,8 +110,8 @@ static const bg_parameter_info_t parameters[] =
       .long_name = TRS("Format"),
       .type = BG_PARAMETER_STRINGLIST,
       .val_default = { .val_str = "vcd2" },
-      .multi_names = (char const *[]){ "vcd11", "vcd2", "svcd", "hqsvcd", (char*)0 },
-      .multi_labels = (char const *[]){ TRS("VCD 1.1"), TRS("VCD 2.0"), TRS("SVCD"), TRS("HQSVCD"), (char*)0 },
+      .multi_names = (char const *[]){ "vcd11", "vcd2", "svcd", "hqsvcd", NULL },
+      .multi_labels = (char const *[]){ TRS("VCD 1.1"), TRS("VCD 2.0"), TRS("SVCD"), TRS("HQSVCD"), NULL },
     },
     {
       .name = "volume_label",
@@ -150,7 +150,7 @@ static const bg_parameter_info_t * get_parameters_vcdimager(void * data)
 
 static void set_parameter_vcdimager(void * data, const char * name, const bg_parameter_value_t * v)
   {
-  vcdimager_t * vcd = (vcdimager_t*)data;
+  vcdimager_t * vcd = data;
   if(!name)
     return;
   SET_STR(bin_file);
@@ -165,7 +165,7 @@ static void set_parameter_vcdimager(void * data, const char * name, const bg_par
 static void set_callbacks_vcdimager(void * data, bg_e_pp_callbacks_t * callbacks)
   {
   vcdimager_t * vcdimager;
-  vcdimager = (vcdimager_t*)data;
+  vcdimager = data;
   vcdimager->callbacks = callbacks;
   bg_cdrdao_set_callbacks(vcdimager->cdr, callbacks);
   
@@ -174,11 +174,11 @@ static void set_callbacks_vcdimager(void * data, bg_e_pp_callbacks_t * callbacks
 static int init_vcdimager(void * data)
   {
   vcdimager_t * vcdimager;
-  vcdimager = (vcdimager_t*)data;
+  vcdimager = data;
 #if 0
-  if(!bg_search_file_exec("cdrdao", (char**)0) ||
-     !bg_search_file_exec("vcdxgen", (char**)0) ||
-     !bg_search_file_exec("vcdxbuild", (char**)0))
+  if(!bg_search_file_exec("cdrdao", NULL) ||
+     !bg_search_file_exec("vcdxgen", NULL) ||
+     !bg_search_file_exec("vcdxbuild", NULL))
     return 0;
 #endif
   free_tracks(vcdimager);
@@ -187,13 +187,13 @@ static int init_vcdimager(void * data)
   }
 
 static void add_track_vcdimager(void * data, const char * filename,
-                                bg_metadata_t * metadata, int pp_only)
+                                gavl_metadata_t * metadata, int pp_only)
   {
   vcdimager_t * vcdimager;
-  vcdimager = (vcdimager_t*)data;
+  vcdimager = data;
   vcdimager->files = realloc(vcdimager->files,
                              sizeof(*(vcdimager->files)) * (vcdimager->num_files+1));
-  vcdimager->files[vcdimager->num_files].name = bg_strdup((char*)0, filename);
+  vcdimager->files[vcdimager->num_files].name = bg_strdup(NULL, filename);
   vcdimager->files[vcdimager->num_files].pp_only = pp_only;
   vcdimager->num_files++;
   }
@@ -276,14 +276,14 @@ static void run_vcdimager(void * data, const char * directory, int cleanup)
   vcdimager_t * vcdimager;
   bg_subprocess_t * proc;
   char * str;
-  char * commandline = (char*)0;
+  char * commandline = NULL;
   int i;
-  char * line = (char*)0;
+  char * line = NULL;
   int line_alloc = 0;
-  char * bin_file = (char*)0;
-  char * cue_file = (char*)0;
-  char * xml_file = (char*)0;
-  vcdimager = (vcdimager_t*)data;
+  char * bin_file = NULL;
+  char * cue_file = NULL;
+  char * xml_file = NULL;
+  vcdimager = data;
   
   /* Build vcdxgen commandline */
 
@@ -312,7 +312,7 @@ static void run_vcdimager(void * data, const char * directory, int cleanup)
   
   proc = bg_subprocess_create(commandline, 0, 0, 1);
   free(commandline);
-  commandline = (char*)0;
+  commandline = NULL;
   
   while(bg_subprocess_read_line(proc->stderr_fd, &line, &line_alloc, -1))
     {
@@ -389,7 +389,7 @@ static void run_vcdimager(void * data, const char * directory, int cleanup)
 static void stop_vcdimager(void * data)
   {
   vcdimager_t * vcdimager;
-  vcdimager = (vcdimager_t*)data;
+  vcdimager = data;
   bg_cdrdao_stop(vcdimager->cdr);
   }
 
