@@ -35,6 +35,9 @@
 #include <gmerlin/log.h>
 #define LOG_DOMAIN "ir_tiff"
 
+#include <gavl/metatags.h>
+
+
 typedef struct
   {
   uint8_t *buffer;
@@ -57,7 +60,8 @@ typedef struct
   void (*convert_scanline)(uint8_t * dst, uint8_t * src,
                            int width, int plane);
   
-
+  gavl_metadata_t m;
+  
   } tiff_t;
 
 static void * create_tiff()
@@ -69,15 +73,17 @@ static void * create_tiff()
 
 static void destroy_tiff(void* priv)
   {
-  tiff_t * tiff = (tiff_t*)priv;
-  if(tiff->buffer) free(tiff->buffer);
+  tiff_t * tiff = priv;
+  if(tiff->buffer)
+    free(tiff->buffer);
+  gavl_metadata_free(&tiff->m);
   free(tiff);
   }
 
 static tsize_t read_function(thandle_t fd, tdata_t data, tsize_t length)
   {
   uint32_t bytes_read;
-  tiff_t *p = (tiff_t*)(fd);
+  tiff_t *p = (tiff_t*)fd;
 
   bytes_read = length;
   if(length > p->buffer_size - p->buffer_position)
@@ -90,7 +96,7 @@ static tsize_t read_function(thandle_t fd, tdata_t data, tsize_t length)
 	
 static toff_t seek_function(thandle_t fd, toff_t off, int whence)
   {
-  tiff_t *p = (tiff_t*)(fd);
+  tiff_t *p = (tiff_t*)fd;
 	
   if (whence == SEEK_SET) p->buffer_position = off;
   else if (whence == SEEK_CUR) p->buffer_position += off;
@@ -109,8 +115,8 @@ static toff_t seek_function(thandle_t fd, toff_t off, int whence)
 
 static toff_t size_function(thandle_t fd)
   {
-  tiff_t *p = (tiff_t*)(fd);
-  return (p->buffer_size);
+  tiff_t *p = (tiff_t*)fd;
+  return p->buffer_size;
   }
 
 static int close_function(thandle_t fd)
@@ -563,7 +569,7 @@ read_header_tiff(void *priv,const char *filename,
   {
   double minmax_d[4];
   uint16_t tmp_16;
-  tiff_t *p = (tiff_t*)priv;
+  tiff_t *p = priv;
   
   tiff_read_mem(priv, filename);
 
@@ -740,7 +746,8 @@ read_header_tiff(void *priv,const char *filename,
         
       }
     }
-  
+
+  gavl_metadata_set(&p->m, GAVL_META_FORMAT, "TIFF");
   return 1;
   }
 
@@ -781,7 +788,7 @@ static int read_image_tiff(void *priv, gavl_video_frame_t *frame)
   {
   int i, j;
   uint32_t *raster;
-  tiff_t *p = (tiff_t*)priv;
+  tiff_t *p = priv;
   uint32_t * raster_ptr;
   uint8_t * frame_ptr;
   uint8_t * frame_ptr_start;
@@ -883,6 +890,12 @@ static int read_image_tiff(void *priv, gavl_video_frame_t *frame)
   return 1;
   }
 
+static const gavl_metadata_t * get_metadata_tiff(void * priv)
+  {
+  tiff_t * t = priv;
+  return &t->m;
+  }
+
 const bg_image_reader_plugin_t the_plugin =
   {
     .common =
@@ -899,6 +912,7 @@ const bg_image_reader_plugin_t the_plugin =
     },
     .extensions =    "tif tiff",
     .read_header = read_header_tiff,
+    .get_metadata = get_metadata_tiff,
     .read_image =  read_image_tiff,
   };
 
