@@ -65,17 +65,19 @@ static void * create_tiff()
 
 static void destroy_tiff(void* priv)
   {
-  tiff_t * tiff = (tiff_t*)priv;
+  tiff_t * tiff = priv;
   free(tiff);
   }
 
 static int write_header_tiff(void * priv, const char * filename,
-                             gavl_video_format_t * format, const bg_metadata_t * m)
+                             gavl_video_format_t * format,
+                             const gavl_metadata_t * m)
   {
-  tiff_t * p = (tiff_t*)priv;
+  tiff_t * p = priv;
   uint16_t v[1];
-
+  int photometric;
   char * real_filename;
+  int has_alpha;
   
   real_filename = bg_filename_ensure_extension(filename, "tif");
   
@@ -105,13 +107,35 @@ static int write_header_tiff(void * priv, const char * filename,
   
   if(gavl_pixelformat_has_alpha(format->pixelformat))
     {
-    format->pixelformat = GAVL_RGBA_32;
-    p->SamplesPerPixel = 4;
+    if(gavl_pixelformat_is_gray(format->pixelformat))
+      {
+      format->pixelformat = GAVL_GRAYA_16;
+      p->SamplesPerPixel = 2;
+      photometric = PHOTOMETRIC_MINISBLACK;
+      }
+    else
+      {
+      format->pixelformat = GAVL_RGBA_32;
+      p->SamplesPerPixel = 4;
+      photometric = PHOTOMETRIC_RGB;
+      }
+    has_alpha = 1;
     }
   else
     {
-    format->pixelformat = GAVL_RGB_24;
-    p->SamplesPerPixel = 3;
+    if(gavl_pixelformat_is_gray(format->pixelformat))
+      {
+      format->pixelformat = GAVL_GRAY_8;
+      p->SamplesPerPixel = 1;
+      photometric = PHOTOMETRIC_MINISBLACK;
+      }
+    else
+      {
+      format->pixelformat = GAVL_RGB_24;
+      p->SamplesPerPixel = 3;
+      photometric = PHOTOMETRIC_RGB;
+      }
+    has_alpha = 0;
     }
   
   TIFFSetField(p->output, TIFFTAG_IMAGEWIDTH, p->Width);
@@ -124,11 +148,11 @@ static int write_header_tiff(void * priv, const char * filename,
   if(p->compression == COMPRESSION_DEFLATE)
     TIFFSetField(p->output, TIFFTAG_ZIPQUALITY, p->zip_quality);
   TIFFSetField(p->output, TIFFTAG_SAMPLEFORMAT, SAMPLEFORMAT_UINT);
-  TIFFSetField(p->output, TIFFTAG_PHOTOMETRIC, PHOTOMETRIC_RGB);
+  TIFFSetField(p->output, TIFFTAG_PHOTOMETRIC, photometric);
   TIFFSetField(p->output, TIFFTAG_PLANARCONFIG, PLANARCONFIG_CONTIG);
   TIFFSetField(p->output, TIFFTAG_ORIENTATION, ORIENTATION_TOPLEFT);
-
-  if(p->SamplesPerPixel == 4)
+  
+  if(has_alpha)
     {
     v[0] = EXTRASAMPLE_ASSOCALPHA;
     TIFFSetField(p->output, TIFFTAG_EXTRASAMPLES, 1, v);
@@ -139,7 +163,7 @@ static int write_header_tiff(void * priv, const char * filename,
 static int write_image_tiff(void *priv, gavl_video_frame_t *frame)
   {
   int i;
-  tiff_t *p = (tiff_t*)priv;
+  tiff_t *p = priv;
   uint8_t * frame_ptr_start;
   
   frame_ptr_start = frame->planes[0];
@@ -163,9 +187,9 @@ static const bg_parameter_info_t parameters[] =
       .name =        "compression",
       .long_name =   TRS("Compression"),
       .type =        BG_PARAMETER_STRINGLIST,
-      .multi_names = (char const *[]){ "none", "packbits", "deflate", "jpeg", (char*)0 },
+      .multi_names = (char const *[]){ "none", "packbits", "deflate", "jpeg", NULL },
       .multi_labels =  (char const *[]){ TRS("None"), TRS("Packbits"), TRS("Deflate"), TRS("JPEG"),
-                                (char*)0 },
+                                NULL },
 
       .val_default = { .val_str = "none" },
     },
@@ -197,7 +221,7 @@ static void set_parameter_tiff(void * p, const char * name,
                                const bg_parameter_value_t * val)
   {
   tiff_t * tiff;
-  tiff = (tiff_t *)p;
+  tiff = p;
 
   if(!name)
     return;
