@@ -34,9 +34,6 @@
 #include <sys/mman.h>
 #include <sys/ioctl.h>
 
-#include <asm/types.h>          /* for videodev2.h */
-
-#include <linux/videodev2.h>
 
 
 #include <config.h>
@@ -55,15 +52,7 @@
 #include "convert.h"
 #endif
 
-#define CLEAR(x) memset (&(x), 0, sizeof (x))
-
 /* Input module */
-typedef enum
-  {
-    IO_METHOD_READ = 0,
-    IO_METHOD_MMAP = 1,
-    IO_METHOD_USERPTR = 2,
-  } io_method;
 
 typedef struct
   {
@@ -75,7 +64,7 @@ typedef struct
   {
   bg_parameter_info_t * parameters;
   char *           device;
-  io_method	io;
+  bgv4l2_io_method_t	io;
   int              fd;
   buffer_t *         buffers;
   unsigned int     n_buffers;
@@ -96,164 +85,29 @@ typedef struct
   struct v4l2_queryctrl * controls;
   int num_controls;
   gavl_timer_t * timer;
+
+  int force_rw;
 #ifdef HAVE_V4LCONVERT
   bg_v4l2_convert_t * converter;
 #endif
+  int strides[GAVL_MAX_PLANES];
+  int num_strides;
   } v4l2_t;
 
-static int
-xioctl(int fd, int request, void * arg)
-  {
-  int r;
-  
-  do{
-    r = ioctl (fd, request, arg);
-  } while (-1 == r && EINTR == errno);
-  
-  return r;
-  }
-
-static int append_param(bg_parameter_info_t ** ret, int * num,
-                        int fd, struct v4l2_queryctrl * ctrl)
-  {
-  bg_parameter_info_t * info;
-
-  switch(ctrl->type)
-    {
-    case V4L2_CTRL_TYPE_INTEGER:
-    case V4L2_CTRL_TYPE_INTEGER64:
-    case V4L2_CTRL_TYPE_BOOLEAN:
-    case V4L2_CTRL_TYPE_BUTTON:
-      break;
-    case V4L2_CTRL_TYPE_MENU:
-    default:
-      return 0;
-    }
-  
-  if(ctrl->flags & V4L2_CTRL_FLAG_DISABLED)
-    return 0;
-  
-  *ret = realloc(*ret, ( (*num)+2 ) * sizeof(**ret));
-  memset((*ret) + *num, 0, 2 * sizeof(**ret));
-
-  info = &(*ret)[*num];
-
-  info->name = bg_strdup(info->name, (char*)ctrl->name);
-  info->long_name = bg_strdup(info->long_name, (char*)ctrl->name);
-  info->flags = BG_PARAMETER_SYNC;
-  
-  switch(ctrl->type)
-    {
-    case V4L2_CTRL_TYPE_INTEGER:
-      if(ctrl->maximum > ctrl->minimum)
-        info->type = BG_PARAMETER_SLIDER_INT;
-      else
-        info->type = BG_PARAMETER_INT;
-      info->val_min.val_i = ctrl->minimum;
-      info->val_max.val_i = ctrl->maximum;
-      info->val_default.val_i = ctrl->default_value;
-      break;
-    case V4L2_CTRL_TYPE_INTEGER64:
-      info->type = BG_PARAMETER_INT;
-      break;
-    case V4L2_CTRL_TYPE_BOOLEAN:
-      info->type = BG_PARAMETER_CHECKBUTTON;
-      info->val_default.val_i = ctrl->default_value;
-      break;
-    case V4L2_CTRL_TYPE_BUTTON:
-      info->type = BG_PARAMETER_BUTTON;
-      break;
-    case V4L2_CTRL_TYPE_MENU:
-      info->type = BG_PARAMETER_STRINGLIST;
-      break;
-    default:
-      break;
-    }
-  *num += 1;
-  return 1;
-  }
-
-static bg_parameter_info_t * create_card_parameters(int fd)
-  {
-  int num = 0;
-  int i;
-  struct v4l2_queryctrl ctrl;
-  bg_parameter_info_t * ret = NULL;
-  
-  for(i = V4L2_CID_BASE; i < V4L2_CID_LASTP1; i++)
-    {
-    ctrl.id = i;
-    if(xioctl(fd, VIDIOC_QUERYCTRL, &ctrl) < 0)
-      continue;
-    append_param(&ret, &num, fd, &ctrl);
-    }
-  
-  i = V4L2_CID_PRIVATE_BASE;
-  while(1)
-    {
-    ctrl.id = i;
-    if(xioctl(fd, VIDIOC_QUERYCTRL, &ctrl) < 0)
-      break;
-    append_param(&ret, &num, fd, &ctrl);
-    i++;
-    }
-  return ret;
-  }
-
-static void append_control(struct v4l2_queryctrl ** ret, int * num,
-                           struct v4l2_queryctrl * ctrl)
-  {
-  *ret = realloc(*ret, ( (*num)+2 ) * sizeof(**ret));
-  memcpy((*ret) + *num, ctrl, sizeof(**ret));
-  *num += 1;
-  }
-
-static struct v4l2_queryctrl * create_card_controls(int fd, int * num)
-  {
-  int i;
-  struct v4l2_queryctrl ctrl;
-  struct v4l2_queryctrl * ret = (struct v4l2_queryctrl *)0;
-  *num = 0;
-  
-  for(i = V4L2_CID_BASE; i < V4L2_CID_LASTP1; i++)
-    {
-    ctrl.id = i;
-    if(xioctl(fd, VIDIOC_QUERYCTRL, &ctrl) < 0)
-      continue;
-    append_control(&ret, num, &ctrl);
-    }
-  
-  i = V4L2_CID_PRIVATE_BASE;
-  while(1)
-    {
-    ctrl.id = i;
-    if(xioctl(fd, VIDIOC_QUERYCTRL, &ctrl) < 0)
-      break;
-    append_control(&ret, num, &ctrl);
-    i++;
-    }
-  return ret;
-  }
 
 static int
-init_read(v4l2_t * v4l, unsigned int		buffer_size)
+init_read(v4l2_t * v4l)
   {
   v4l->buffers = calloc (1, sizeof (*v4l->buffers));
+
+  v4l->num_strides = bgv4l2_set_strides(&v4l->format,
+                                        &v4l->fmt, v4l->strides);
   
   if (!v4l->buffers)
     {
     bg_log(BG_LOG_ERROR, LOG_DOMAIN, "Out of memory");
     return 0;
     }
-  
-  v4l->buffers[0].length = buffer_size;
-  v4l->buffers[0].start = malloc (buffer_size);
-  
-  if (!v4l->buffers[0].start)
-    {
-    bg_log(BG_LOG_ERROR, LOG_DOMAIN, "Out of memory");
-    return 0;
-    }
   return 1;
   }
 
@@ -261,6 +115,8 @@ static int
 init_mmap(v4l2_t * v4l)
   {
   struct v4l2_requestbuffers req;
+  int i;
+  enum v4l2_buf_type type;
   
   CLEAR (req);
   
@@ -268,7 +124,7 @@ init_mmap(v4l2_t * v4l)
   req.type                = V4L2_BUF_TYPE_VIDEO_CAPTURE;
   req.memory              = V4L2_MEMORY_MMAP;
   
-  if (-1 == xioctl (v4l->fd, VIDIOC_REQBUFS, &req))
+  if (-1 == bgv4l2_ioctl (v4l->fd, VIDIOC_REQBUFS, &req))
     {
     if (EINVAL == errno)
       {
@@ -278,6 +134,7 @@ init_mmap(v4l2_t * v4l)
       }
     else
       {
+      bg_log(BG_LOG_ERROR, LOG_DOMAIN, "VIDIOC_REQBUFS failed: %s", strerror(errno));
       return 0;
       }
     }
@@ -307,9 +164,11 @@ init_mmap(v4l2_t * v4l)
     buf.memory      = V4L2_MEMORY_MMAP;
     buf.index       = v4l->n_buffers;
     
-    if (-1 == xioctl (v4l->fd, VIDIOC_QUERYBUF, &buf))
+    if (-1 == bgv4l2_ioctl (v4l->fd, VIDIOC_QUERYBUF, &buf))
+      {
+      bg_log(BG_LOG_ERROR, LOG_DOMAIN, "VIDIOC_QUERYBUF failed: %s", strerror(errno));
       return 0;
-    
+      }
     v4l->buffers[v4l->n_buffers].length = buf.length;
     v4l->buffers[v4l->n_buffers].start =
       mmap (NULL /* start anywhere */,
@@ -321,57 +180,32 @@ init_mmap(v4l2_t * v4l)
     if (MAP_FAILED == v4l->buffers[v4l->n_buffers].start)
       return 0;
     }
-  return 1;
-  }
 
-static int
-init_userp(v4l2_t * v4l, unsigned int		buffer_size)
-  {
-  struct v4l2_requestbuffers req;
-  unsigned int page_size;
-
-  page_size = getpagesize ();
-  buffer_size = (buffer_size + page_size - 1) & ~(page_size - 1);
-
-  CLEAR (req);
-
-  req.count               = 4;
-  req.type                = V4L2_BUF_TYPE_VIDEO_CAPTURE;
-  req.memory              = V4L2_MEMORY_USERPTR;
-
-  if (-1 == xioctl (v4l->fd, VIDIOC_REQBUFS, &req))
+  for (i = 0; i < v4l->n_buffers; ++i)
     {
-    if (EINVAL == errno)
-      {
-      bg_log(BG_LOG_ERROR, LOG_DOMAIN, "%s does not support "
-               "user pointer i/o", v4l->device);
-      return 0;
-      }
-    else
-      {
-      return 0;
-      }
-    }
-  
-  v4l->buffers = calloc (4, sizeof (*v4l->buffers));
-
-  if (!v4l->buffers)
-    {
-    bg_log(BG_LOG_ERROR, LOG_DOMAIN, "Out of memory");
-    return 0;
-    }
-  
-  for (v4l->n_buffers = 0; v4l->n_buffers < 4; ++v4l->n_buffers)
-    {
-    v4l->buffers[v4l->n_buffers].length = buffer_size;
-    v4l->buffers[v4l->n_buffers].start = memalign (/* boundary */ page_size,
-                                                   buffer_size);
+    struct v4l2_buffer buf;
+    CLEAR (buf);
     
-    if (!v4l->buffers[v4l->n_buffers].start)
+    buf.type        = V4L2_BUF_TYPE_VIDEO_CAPTURE;
+    buf.memory      = V4L2_MEMORY_MMAP;
+    buf.index       = i;
+    
+    if (-1 == bgv4l2_ioctl (v4l->fd, VIDIOC_QBUF, &buf))
       {
-      bg_log(BG_LOG_ERROR, LOG_DOMAIN, "Out of memory");
+      bg_log(BG_LOG_ERROR, LOG_DOMAIN, "VIDIOC_QBUF failed: %s",
+             strerror(errno));
       return 0;
       }
+    //    fprintf(stderr, "VIDIOC_QBUF %d\n", buf.index);
+    }
+  
+  type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
+  
+  if (-1 == bgv4l2_ioctl (v4l->fd, VIDIOC_STREAMON, &type))
+    {
+    bg_log(BG_LOG_ERROR, LOG_DOMAIN, "VIDIOC_STREAMON failed: %s",
+           strerror(errno));
+    return 0;
     }
   return 1;
   }
@@ -380,13 +214,21 @@ static int get_pixelformat(int fd, uint32_t * ret)
   {
   int index = 0;
   struct v4l2_fmtdesc desc;
+
+  CLEAR(desc);
+  
   desc.type = V4L2_BUF_TYPE_VIDEO_CAPTURE; 
   
   while(1)
     {
     desc.index = index;
-    if(-1 == xioctl (fd, VIDIOC_ENUM_FMT, &desc))
-      return 0;
+    if(-1 == bgv4l2_ioctl (fd, VIDIOC_ENUM_FMT, &desc))
+      {
+      if((errno != EINVAL) || !index)
+        bg_log(BG_LOG_ERROR, LOG_DOMAIN,
+               "VIDIOC_ENUM_FMT failed: %s", strerror(errno));
+      break;
+      }
 #if 0
     fprintf(stderr, "Cam pixelformat %c%c%c%c\n",
             desc.pixelformat & 0xff,
@@ -399,13 +241,29 @@ static int get_pixelformat(int fd, uint32_t * ret)
     if(!desc.index)
       *ret = desc.pixelformat;
     
-    if(pixelformat_v4l2_2_gavl(desc.pixelformat) != GAVL_PIXELFORMAT_NONE)
+    if(bgv4l2_pixelformat_v4l2_2_gavl(desc.pixelformat) !=
+       GAVL_PIXELFORMAT_NONE)
       {
       *ret = desc.pixelformat;
       return 1;
       }
     index++;
     }
+
+#if 0  
+  if(!index)
+    {
+    struct v4l2_format fmt;
+    CLEAR (fmt);
+    fmt.type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
+    if (-1 == bgv4l2_ioctl (fd, VIDIOC_G_FMT, &fmt))
+      {
+      bg_log(BG_LOG_ERROR, LOG_DOMAIN, "VIDIOC_G_FMT failed: %s", strerror(errno));
+      return 0;
+      }
+    *ret = fmt.fmt.pix.pixelformat;
+    }
+#endif
   return 0;
   }
 
@@ -419,61 +277,38 @@ static int open_v4l(void * priv,
   //  struct v4l2_cropcap cropcap;
   //  struct v4l2_crop crop;
   //  unsigned int min;
-  unsigned int i;
-  enum v4l2_buf_type type;
-
-  v4l = (v4l2_t*)priv;
+  
+  v4l = priv;
   gavl_timer_set(v4l->timer, 0);
   gavl_timer_start(v4l->timer);
-  /* Open device */
-  v4l->fd = open(v4l->device, O_RDWR /* required */ | O_NONBLOCK, 0);
-  
-  if(v4l->fd < 0)
-    {
-    bg_log(BG_LOG_ERROR, LOG_DOMAIN, "Opening %s failed: %s", v4l->device, strerror(errno));
-    return 0;
-    }
-  
-  if (-1 == xioctl (v4l->fd, VIDIOC_QUERYCAP, &cap))
-    {
-    if (EINVAL == errno)
-      {
-      bg_log(BG_LOG_ERROR, LOG_DOMAIN, "%s is no V4L2 device",
-               v4l->device);
-      return 0;
-      }
-    else
-      {
-      bg_log(BG_LOG_ERROR, LOG_DOMAIN, "VIDIOC_QUERYCAP failed: %s", strerror(errno));
-      return 0;
-      }
-    }
 
+  v4l->fd = bgv4l2_open_device(v4l->device, V4L2_CAP_VIDEO_CAPTURE,
+                               &cap);
+  
   //  create_card_parameters(v4l->fd);
 
   if(v4l->controls)
-    free(v4l->controls);
-  
-  v4l->controls = create_card_controls(v4l->fd, &v4l->num_controls);
-
-  bg_log(BG_LOG_DEBUG, LOG_DOMAIN, "Device name: %s", cap.card);
-  
-  if (!(cap.capabilities & V4L2_CAP_VIDEO_CAPTURE))
     {
-    bg_log(BG_LOG_ERROR, LOG_DOMAIN, "%s is no video capture device",
-           v4l->device);
-    return 0;
+    free(v4l->controls);
+    v4l->controls = NULL;
     }
+  if(v4l->fd < 0)
+    return 0;
+  
+  v4l->controls =
+    bgv4l2_create_device_controls(v4l->fd, &v4l->num_controls);
+  
+  bg_log(BG_LOG_DEBUG, LOG_DOMAIN, "Device name: %s", cap.card);
 
-  if (cap.capabilities & V4L2_CAP_STREAMING)
+  if ((cap.capabilities & V4L2_CAP_STREAMING) && !v4l->force_rw)
     {
     bg_log(BG_LOG_INFO, LOG_DOMAIN, "Trying mmap i/o");
-    v4l->io = IO_METHOD_MMAP;
+    v4l->io = BGV4L2_IO_METHOD_MMAP;
     }
   else if(cap.capabilities & V4L2_CAP_READWRITE)
     {
     bg_log(BG_LOG_INFO, LOG_DOMAIN, "Trying read i/o");
-    v4l->io = IO_METHOD_READ;
+    v4l->io = BGV4L2_IO_METHOD_RW;
     }
   
   /* Select video input, video standard and tune here. */
@@ -483,12 +318,12 @@ static int open_v4l(void * priv,
 
   cropcap.type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
 
-  if (0 == xioctl (v4l->fd, VIDIOC_CROPCAP, &cropcap))
+  if (0 == bgv4l2_ioctl (v4l->fd, VIDIOC_CROPCAP, &cropcap))
     {
     crop.type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
     crop.c = cropcap.defrect; /* reset to default */
     
-    if (-1 == xioctl (v4l->fd, VIDIOC_S_CROP, &crop))
+    if (-1 == bgv4l2_ioctl (v4l->fd, VIDIOC_S_CROP, &crop))
       {
       switch (errno)
         {
@@ -516,9 +351,7 @@ static int open_v4l(void * priv,
                                             &format->pixelformat, v4l->width,
                                             v4l->height);
     if(!v4l->converter)
-      {
       return 0;
-      }
 #else
     bg_log(BG_LOG_ERROR, LOG_DOMAIN, "Got no supported pixelformat");
     return 0;
@@ -526,12 +359,13 @@ static int open_v4l(void * priv,
     }
   else
     {
-    format->pixelformat  = pixelformat_v4l2_2_gavl(v4l->v4l2_pixelformat);
+    format->pixelformat =
+      bgv4l2_pixelformat_v4l2_2_gavl(v4l->v4l2_pixelformat);
     }
   
   v4l->fmt.type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
   
-  if (-1 == xioctl (v4l->fd, VIDIOC_G_FMT, &v4l->fmt))
+  if (-1 == bgv4l2_ioctl (v4l->fd, VIDIOC_G_FMT, &v4l->fmt))
     {
     bg_log(BG_LOG_ERROR, LOG_DOMAIN, "VIDIOC_G_FMT failed: %s", strerror(errno));
     return 0;
@@ -544,7 +378,7 @@ static int open_v4l(void * priv,
   v4l->fmt.fmt.pix.height      = v4l->height;
   v4l->fmt.fmt.pix.pixelformat = v4l->v4l2_pixelformat;
   
-  if (-1 == xioctl (v4l->fd, VIDIOC_S_FMT, &v4l->fmt))
+  if (-1 == bgv4l2_ioctl (v4l->fd, VIDIOC_S_FMT, &v4l->fmt))
     {
     bg_log(BG_LOG_ERROR, LOG_DOMAIN, "VIDIOC_S_FMT failed: %s", strerror(errno));
     return 0;
@@ -561,7 +395,7 @@ static int open_v4l(void * priv,
     fmt.fmt.pix.sizeimage = min;
 #endif
 
-  if (-1 == xioctl (v4l->fd, VIDIOC_G_FMT, &v4l->fmt))
+  if (-1 == bgv4l2_ioctl (v4l->fd, VIDIOC_G_FMT, &v4l->fmt))
     {
     bg_log(BG_LOG_ERROR, LOG_DOMAIN, "VIDIOC_G_FMT failed: %s", strerror(errno));
     return 0;
@@ -578,86 +412,19 @@ static int open_v4l(void * priv,
   format->framerate_mode = GAVL_FRAMERATE_VARIABLE;
 
   gavl_video_format_copy(&v4l->format, format);
-  //  gavl_video_format_dump(&v4l->format);
-
-  //  fprintf(stderr, "Bytesperline: %d, sizeimage: %d\n",
-  //          v4l->fmt.fmt.pix.bytesperline, v4l->fmt.fmt.pix.sizeimage);
-
-  gavl_video_frame_set_strides(v4l->frame, &v4l->format);
   
   switch (v4l->io)
     {
-    case IO_METHOD_READ:
-      if(!init_read (v4l, v4l->fmt.fmt.pix.sizeimage))
+    case BGV4L2_IO_METHOD_RW:
+      if(!init_read (v4l))
         return 0;
       break;
       
-    case IO_METHOD_MMAP:
+    case BGV4L2_IO_METHOD_MMAP:
       if(!init_mmap (v4l))
         return 0;
       break;
-      
-    case IO_METHOD_USERPTR:
-      if(!init_userp (v4l, v4l->fmt.fmt.pix.sizeimage))
-        return 0;
-      break;
     }
-  
-  /* start_capturing  */
-
-  switch (v4l->io)
-    {
-    case IO_METHOD_READ:
-      /* Nothing to do. */
-      break;
-      
-    case IO_METHOD_MMAP:
-      for (i = 0; i < v4l->n_buffers; ++i)
-        {
-        struct v4l2_buffer buf;
-        
-        CLEAR (buf);
-        
-        buf.type        = V4L2_BUF_TYPE_VIDEO_CAPTURE;
-        buf.memory      = V4L2_MEMORY_MMAP;
-        buf.index       = i;
-        
-        if (-1 == xioctl (v4l->fd, VIDIOC_QBUF, &buf))
-          return 0;
-        }
-      
-      type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
-      
-      if (-1 == xioctl (v4l->fd, VIDIOC_STREAMON, &type))
-        return 0;
-      
-      break;
-      
-    case IO_METHOD_USERPTR:
-      for (i = 0; i < v4l->n_buffers; ++i)
-        {
-        struct v4l2_buffer buf;
-        
-        CLEAR (buf);
-        
-        buf.type        = V4L2_BUF_TYPE_VIDEO_CAPTURE;
-        buf.memory      = V4L2_MEMORY_USERPTR;
-        buf.index       = i;
-        buf.m.userptr	= (unsigned long) v4l->buffers[i].start;
-        buf.length      = v4l->buffers[i].length;
-        
-        if (-1 == xioctl (v4l->fd, VIDIOC_QBUF, &buf))
-          return 0;
-        }
-      
-      type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
-      
-      if (-1 == xioctl (v4l->fd, VIDIOC_STREAMON, &type))
-        return 0;
-      
-      break;
-    }
-  
   return 1;
   }
 
@@ -666,47 +433,51 @@ static void close_v4l(void * priv)
   v4l2_t * v4l;
   enum v4l2_buf_type type;
   unsigned int i;
-  v4l = (v4l2_t*)priv;
+  v4l = priv;
+
+  if(v4l->fd < 0)
+    return;
+  
   gavl_timer_stop(v4l->timer);
 
-  // stop_capturing                  (void)
-
   switch (v4l->io)
     {
-    case IO_METHOD_READ:
-      /* Nothing to do. */
-      break;
-    case IO_METHOD_MMAP:
-    case IO_METHOD_USERPTR:
-      type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
-      
-      if (-1 == xioctl (v4l->fd, VIDIOC_STREAMOFF, &type))
-        return;
-      break;
-    }
-  //  uninit_device                   (void)
-
-  switch (v4l->io)
-    {
-    case IO_METHOD_READ:
+    case BGV4L2_IO_METHOD_RW:
       if(v4l->buffers && v4l->buffers[0].start)
+        {
         free (v4l->buffers[0].start);
+        v4l->buffers[0].start = NULL;
+        }
       break;
 
-    case IO_METHOD_MMAP:
+    case BGV4L2_IO_METHOD_MMAP:
+      type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
+      if (-1 == bgv4l2_ioctl (v4l->fd, VIDIOC_STREAMOFF, &type))
+        {
+        bg_log(BG_LOG_ERROR, LOG_DOMAIN, "VIDIOC_STREAMOFF failed: %s", strerror(errno));
+        return;
+        }
       for (i = 0; i < v4l->n_buffers; ++i)
+        {
         if (-1 == munmap (v4l->buffers[i].start, v4l->buffers[i].length))
           return;
-      break;
-
-    case IO_METHOD_USERPTR:
-      for (i = 0; i < v4l->n_buffers; ++i)
-        free (v4l->buffers[i].start);
+        v4l->buffers[i].start = NULL;
+        }
       break;
     }
   if(v4l->buffers)
+    {
     free (v4l->buffers);
+    v4l->buffers = NULL;
+    }
+  if(v4l->frame)
+    {
+    gavl_video_frame_null(v4l->frame);
+    gavl_video_frame_destroy(v4l->frame);
+    v4l->frame = NULL;
+    }
 
+  
   if(v4l->fd >= 0)
     close(v4l->fd);
   v4l->fd = -1;
@@ -716,6 +487,13 @@ static void close_v4l(void * priv)
     free(v4l->controls);
     v4l->controls = NULL;
     }
+#if HAVE_V4LCONVERT
+  if(v4l->converter)
+    {
+    bg_v4l2_convert_destroy(v4l->converter);
+    v4l->converter = NULL;
+    }
+#endif
   }
 
 static void process_image(v4l2_t * v4l, void * data,
@@ -730,6 +508,13 @@ static void process_image(v4l2_t * v4l, void * data,
   else
     {
 #endif
+
+  if(!v4l->frame)
+    {
+    v4l->frame = gavl_video_frame_create(NULL);
+    bgv4l2_set_strides(&v4l->format,
+                       &v4l->fmt, v4l->frame->strides);
+    }
   gavl_video_frame_set_planes(v4l->frame, &v4l->format, data);
   gavl_video_frame_copy(&v4l->format, frame, v4l->frame);
 #ifdef HAVE_V4LCONVERT
@@ -738,111 +523,108 @@ static void process_image(v4l2_t * v4l, void * data,
   frame->timestamp = gavl_timer_get(v4l->timer) / TIME_DIV;
   }
 
-static int read_frame(v4l2_t * v4l, gavl_video_frame_t * frame)
+static int read_frame_read(v4l2_t * v4l, gavl_video_frame_t * frame)
+  {
+  /* If strides match we can read directly into the frame buffer */
+  if(
+#ifdef HAVE_V4LCONVERT
+     !v4l->converter &&
+#endif
+     bgv4l2_strides_match(frame, v4l->strides, v4l->num_strides))
+    {
+    if (read (v4l->fd, frame->planes[0], v4l->fmt.fmt.pix.sizeimage) < v4l->fmt.fmt.pix.sizeimage)
+      {
+      bg_log(BG_LOG_ERROR, LOG_DOMAIN, "read failed: %s", strerror(errno));
+      return 0;
+      }
+    frame->timestamp = gavl_timer_get(v4l->timer) / TIME_DIV;
+    return 1;
+    }
+
+  if(!v4l->buffers[0].start)
+    v4l->buffers[0].start = malloc(v4l->fmt.fmt.pix.sizeimage);
+  
+  if (-1 == read (v4l->fd, v4l->buffers[0].start, v4l->fmt.fmt.pix.sizeimage))
+    {
+    bg_log(BG_LOG_ERROR, LOG_DOMAIN, "read failed: %s", strerror(errno));
+    switch (errno)
+      {
+      case EAGAIN:
+        return 0;
+        
+      case EIO:
+        /* Could ignore EIO, see spec. */
+            
+        /* fall through */
+            
+      default:
+        return 0;
+      }
+    }
+  process_image (v4l, v4l->buffers[0].start, frame);
+  return 1;
+  }
+
+static int read_frame_mmap(v4l2_t * v4l, gavl_video_frame_t * frame)
   {
   struct v4l2_buffer buf;
-  unsigned int i;
-
-  switch (v4l->io)
-    {
-    case IO_METHOD_READ:
-      if (-1 == read (v4l->fd, v4l->buffers[0].start, v4l->buffers[0].length))
-        {
-        switch (errno)
-          {
-          case EAGAIN:
-            return 0;
-            
-          case EIO:
-            /* Could ignore EIO, see spec. */
-            
-            /* fall through */
-            
-          default:
-            return -1;
-          }
-        }
-      process_image (v4l, v4l->buffers[0].start, frame);
-
-      break;
-
-    case IO_METHOD_MMAP:
-      CLEAR (buf);
-      
-      buf.type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
-      buf.memory = V4L2_MEMORY_MMAP;
-      
-      if (-1 == xioctl (v4l->fd, VIDIOC_DQBUF, &buf))
-        {
-        switch (errno)
-          {
-          case EAGAIN:
-            return 0;
-            
-          case EIO:
-            /* Could ignore EIO, see spec. */
-            
-            /* fall through */
-            
-          default:
-            return -1;
-          }
-        }
-      
-      //      assert (buf.index < n_buffers);
-      
-      process_image (v4l, v4l->buffers[buf.index].start, frame);
-      
-      if (-1 == xioctl (v4l->fd, VIDIOC_QBUF, &buf))
-        return -1;
-      
-      break;
-      
-    case IO_METHOD_USERPTR:
-      CLEAR (buf);
-      
-      buf.type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
-      buf.memory = V4L2_MEMORY_USERPTR;
-      
-      if (-1 == xioctl (v4l->fd, VIDIOC_DQBUF, &buf))
-        {
-        switch (errno)
-          {
-          case EAGAIN:
-            return -1;
-            
-          case EIO:
-            /* Could ignore EIO, see spec. */
-            
-            /* fall through */
-            
-          default:
-            return 0;
-          }
-        }
-      
-      for (i = 0; i < v4l->n_buffers; ++i)
-        if (buf.m.userptr == (unsigned long) v4l->buffers[i].start
-            && buf.length == v4l->buffers[i].length)
-          break;
-      
-      //      assert (i < n_buffers);
-      
-      process_image (v4l, (void *) buf.m.userptr, frame);
-      
-      if (-1 == xioctl (v4l->fd, VIDIOC_QBUF, &buf))
-        return -1;
-      
-      break;
-    }
   
+  CLEAR (buf);
+      
+  buf.type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
+  buf.memory = V4L2_MEMORY_MMAP;
+      
+  if (-1 == bgv4l2_ioctl (v4l->fd, VIDIOC_DQBUF, &buf))
+    {
+    bg_log(BG_LOG_ERROR, LOG_DOMAIN, "VIDIOC_DQBUF failed: %s", strerror(errno));
+    switch (errno)
+      {
+      case EAGAIN:
+        return 0;
+            
+      case EIO:
+        /* Could ignore EIO, see spec. */
+            
+        /* fall through */
+            
+      default:
+        return 0;
+      }
+    }
+
+#if 0  
+  fprintf(stderr, "VIDIOC_DQBUF %d done: %d, queued: %d\n",
+          buf.index,
+          !!(buf.flags & V4L2_BUF_FLAG_DONE),
+          !!(buf.flags & V4L2_BUF_FLAG_QUEUED));
+#endif
+  //      assert (buf.index < n_buffers);
+      
+  process_image (v4l, v4l->buffers[buf.index].start, frame);
+#if 0
+  if (0 == bgv4l2_ioctl (v4l->fd, VIDIOC_QUERYBUF, &buf))
+    {
+    fprintf(stderr, "VIDIOC_QUERYBUF %d done: %d, queued: %d\n",
+            buf.index,
+            !!(buf.flags & V4L2_BUF_FLAG_DONE),
+            !!(buf.flags & V4L2_BUF_FLAG_QUEUED));
+        
+    }
+#endif
+      
+  if (-1 == bgv4l2_ioctl (v4l->fd, VIDIOC_QBUF, &buf))
+    {
+    bg_log(BG_LOG_ERROR, LOG_DOMAIN, "VIDIOC_QBUF failed: %s", strerror(errno));
+    return 0;
+    }
+  //  fprintf(stderr, "VIDIOC_QBUF %d\n", buf.index);
   return 1;
   }
 
 static int read_frame_v4l(void * priv, gavl_video_frame_t * frame, int stream)
   {
   v4l2_t * v4l;
-  v4l = (v4l2_t*)priv;
+  v4l = priv;
 
   
   for (;;)
@@ -857,13 +639,16 @@ static int read_frame_v4l(void * priv, gavl_video_frame_t * frame, int stream)
     /* Timeout. */
     tv.tv_sec = 4;
     tv.tv_usec = 0;
-    
-    r = select (v4l->fd + 1, &fds, NULL, NULL, &tv);
+
+    //    fprintf(stderr, "Select...");
+    r = select(v4l->fd + 1, &fds, NULL, NULL, &tv);
+    //    fprintf(stderr, "Select...done %d\n", r);
     
     if (-1 == r)
       {
       if (EINTR == errno)
         continue;
+      bg_log(BG_LOG_ERROR, LOG_DOMAIN, "Select failed: %s", strerror(errno));
       return 0;
       }
     
@@ -873,19 +658,19 @@ static int read_frame_v4l(void * priv, gavl_video_frame_t * frame, int stream)
       return 0;
       }
 
-    r = read_frame (v4l, frame);
-
-    if(r > 0)
-      break;
-    else if(!r)
-      continue;
-    else
-      return 0;
-    
-    /* EAGAIN - continue select loop. */
+    switch (v4l->io)
+      {
+      case BGV4L2_IO_METHOD_RW:
+        return read_frame_read(v4l, frame);
+        break;
+        
+      case BGV4L2_IO_METHOD_MMAP:
+        return read_frame_mmap(v4l, frame);
+        break;
+      }
     }
   
-  return 1;
+  return 0;
   }
 
 static void * create_v4l()
@@ -893,8 +678,7 @@ static void * create_v4l()
   v4l2_t * v4l;
 
   v4l = calloc(1, sizeof(*v4l));
-
-  v4l->frame = gavl_video_frame_create(NULL);
+  
   v4l->fd = -1;
   //  v4l->device = bg_strdup(v4l->device, "/dev/video4");
   v4l->timer = gavl_timer_create();
@@ -904,13 +688,7 @@ static void * create_v4l()
 static void  destroy_v4l(void * priv)
   {
   v4l2_t * v4l;
-  v4l = (v4l2_t*)priv;
-  gavl_video_frame_null(v4l->frame);
-  gavl_video_frame_destroy(v4l->frame);
-#if HAVE_V4LCONVERT
-  if(v4l->converter)
-    bg_v4l2_convert_destroy(v4l->converter);
-#endif
+  v4l = priv;
   close_v4l(priv);
   gavl_timer_destroy(v4l->timer);
   
@@ -939,6 +717,13 @@ static const bg_parameter_info_t parameters[] =
       .type =        BG_PARAMETER_MULTI_MENU,
       .val_default = { .val_str = "/dev/video0" },
     },
+    {
+      .name =        "force_rw",
+      .long_name =   TRS("Force read"),
+      .type =        BG_PARAMETER_CHECKBUTTON,
+      .val_default = { .val_i = 1 },
+      .help_string = TRS("Don't use memory mapping")
+    },
     {
       .name =        "res",
       .long_name =   TRS("Resolution"),
@@ -956,7 +741,7 @@ static const bg_parameter_info_t parameters[] =
                               "CIF (352x288)", 
                               "VGA (640x480)", 
                               "User defined",
-                              (char*)0 },
+                              NULL },
       .multi_labels =     (char const *[]){ TRS("QSIF (160x112)"),
                                    TRS("QCIF (176x144)"), 
                                    TRS("QVGA (320x240)"), 
@@ -964,7 +749,7 @@ static const bg_parameter_info_t parameters[] =
                                    TRS("CIF (352x288)"), 
                                    TRS("VGA (640x480)"), 
                                    TRS("User defined"),
-                                   (char*)0 },
+                                   NULL },
     },
     {
       .name =        "user_width",
@@ -987,72 +772,17 @@ static const bg_parameter_info_t parameters[] =
 
 static void create_parameters(v4l2_t * v4l)
   {
-  int i;
-  int fd;
   bg_parameter_info_t * info;
-  char * tmp_string;
-  struct v4l2_capability cap;
-  int num_cards = 0;
   v4l->parameters = bg_parameter_info_copy_array(parameters);
-
-  info = v4l->parameters + 1;
-
-  for(i = 0; i < 10; i++)
-    {
-    tmp_string = bg_sprintf("/dev/video%d", i);
-    
-    fd = open(tmp_string, O_RDWR | O_NONBLOCK, 0);
-    if(fd < 0)
-      {
-      free(tmp_string);
-      continue;
-      }
-
-    if(-1 == xioctl(fd, VIDIOC_QUERYCAP, &cap))
-      {
-      close(fd);
-      free(tmp_string);
-      continue;
-      }
-
-    if (!(cap.capabilities & V4L2_CAP_VIDEO_CAPTURE))
-      {
-      close(fd);
-      free(tmp_string);
-      continue;
-      }
-
-    info->multi_names_nc = realloc(info->multi_names_nc, (num_cards + 2)*
-                                sizeof(*info->multi_names));
-
-    info->multi_labels_nc = realloc(info->multi_labels_nc, (num_cards + 2)*
-                                sizeof(*info->multi_labels));
-
-    info->multi_parameters_nc = realloc(info->multi_parameters_nc, (num_cards + 2)*
-                                     sizeof(*info->multi_parameters));
-    
-    info->multi_names_nc[num_cards] = bg_strdup(NULL, tmp_string);
-    info->multi_names_nc[num_cards+1] = (char*)0;
-
-    info->multi_labels_nc[num_cards] = bg_strdup(NULL, (char*)cap.card);
-    info->multi_labels_nc[num_cards+1] = (char*)0;
-
-    info->multi_parameters_nc[num_cards] = create_card_parameters(fd);
-    info->multi_parameters_nc[num_cards+1] = (bg_parameter_info_t*)0;
-
-    bg_parameter_info_set_const_ptrs(info);
-
-    num_cards++;
-    close(fd);
-    free(tmp_string);
-    }
   
+  info = v4l->parameters + 1;
+  bgv4l2_create_device_selector(info, V4L2_CAP_VIDEO_CAPTURE);
   }
 
 static const bg_parameter_info_t * get_parameters_v4l(void * priv)
   {
   v4l2_t * v4l;
-  v4l = (v4l2_t*)priv;
+  v4l = priv;
   if(!v4l->parameters)
     create_parameters(v4l);
   return v4l->parameters;
@@ -1062,34 +792,13 @@ static int get_parameter_v4l(void * priv, const char * name,
                              bg_parameter_value_t * val)
   {
   v4l2_t * v4l;
-  v4l = (v4l2_t*)priv;
+  v4l = priv;
   if(v4l->controls && (v4l->fd >= 0))
     {
-    int i;
-    struct v4l2_control ctrl;
-    
-    for(i = 0; i < v4l->num_controls; i++)
-      {
-      if(!strcmp(name, (char*)v4l->controls[i].name))
-        {
-        if(!val)
-          return 0;
-
-        ctrl.id = v4l->controls[i].id;
-        
-        //        fprintf(stderr, "Get parameter: %s \n", v4l->controls[i].name);
-        
-        if(!xioctl(v4l->fd, VIDIOC_G_CTRL, &ctrl))
-          {
-          //          fprintf(stderr, " Success %d\n", ctrl.value);
-          val->val_i = ctrl.value;
-          return 1;
-          }
-        //        else
-        //          fprintf(stderr, " Failure\n");
-        return 0;
-        }
-      }
+    return bgv4l2_get_device_parameter(v4l->fd,
+                                       v4l->controls,
+                                       v4l->num_controls,
+                                       name, val);
     }
   return 0;
   }
@@ -1098,7 +807,7 @@ static void set_parameter_v4l(void * priv, const char * name,
                               const bg_parameter_value_t * val)
   {
   v4l2_t * v4l;
-  v4l = (v4l2_t*)priv;
+  v4l = priv;
 
   if(!name)
     {
@@ -1110,9 +819,9 @@ static void set_parameter_v4l(void * priv, const char * name,
     return;
     }
   else if(!strcmp(name, "device"))
-    {
     v4l->device = bg_strdup(v4l->device, val->val_str);
-    }
+  else if(!strcmp(name, "force_rw"))
+    v4l->force_rw = val->val_i;
   else if(!strcmp(name, "resolution"))
     {
     if(!strcmp(val->val_str, "QSIF (160x112)"))
@@ -1167,32 +876,11 @@ static void set_parameter_v4l(void * priv, const char * name,
 
   else if(v4l->controls && (v4l->fd >= 0))
     {
-    int i;
-    struct v4l2_control ctrl;
-    
-    for(i = 0; i < v4l->num_controls; i++)
-      {
-      if(!strcmp(name, (char*)v4l->controls[i].name))
-        {
-        if(!val)
-          {
-          //          fprintf(stderr, "Set button: %s", name);
-          ctrl.value = 0;
-          }
-        else
-          {
-          //          fprintf(stderr, "Set parameter: %s %d [%d]", name, val->val_i, v4l->controls[i].id);
-          ctrl.value = val->val_i;
-          }
-        ctrl.id = v4l->controls[i].id;
-        
-        if(xioctl(v4l->fd, VIDIOC_S_CTRL, &ctrl))
-          bg_log(BG_LOG_ERROR, LOG_DOMAIN, "Failure");
-        return;
-        }
-      }
+    bgv4l2_set_device_parameter(v4l->fd,
+                                v4l->controls,
+                                v4l->num_controls,
+                                name, val);
     }
-
   }
 
 const bg_recorder_plugin_t the_plugin =
