@@ -55,7 +55,7 @@ typedef struct
 static int need_restart_colormatrix(void * priv)
   {
   colormatrix_priv_t * vp;
-  vp = (colormatrix_priv_t *)priv;
+  vp = priv;
   return vp->need_restart;
   }
 
@@ -79,7 +79,7 @@ static gavl_video_options_t * get_options_colormatrix(void * priv)
 static void destroy_colormatrix(void * priv)
   {
   colormatrix_priv_t * vp;
-  vp = (colormatrix_priv_t *)priv;
+  vp = priv;
   bg_colormatrix_destroy(vp->mat);
   gavl_video_options_destroy(vp->global_opt);
   free(vp);
@@ -354,7 +354,7 @@ static void set_parameter_colormatrix(void * priv, const char * name,
   {
   int changed = 0;
   colormatrix_priv_t * vp;
-  vp = (colormatrix_priv_t *)priv;
+  vp = priv;
 
   if(!name)
     return;
@@ -400,7 +400,7 @@ static void connect_input_port_colormatrix(void * priv,
                                     void * data, int stream, int port)
   {
   colormatrix_priv_t * vp;
-  vp = (colormatrix_priv_t *)priv;
+  vp = priv;
   
   if(!port)
     {
@@ -414,7 +414,7 @@ static void set_input_format_colormatrix(void * priv, gavl_video_format_t * form
   {
   colormatrix_priv_t * vp;
   int flags = 0;
-  vp = (colormatrix_priv_t *)priv;
+  vp = priv;
   if(vp->force_alpha)
     flags |= BG_COLORMATRIX_FORCE_ALPHA;
 
@@ -429,14 +429,14 @@ static void set_input_format_colormatrix(void * priv, gavl_video_format_t * form
 static void get_output_format_colormatrix(void * priv, gavl_video_format_t * format)
   {
   colormatrix_priv_t * vp;
-  vp = (colormatrix_priv_t *)priv;
+  vp = priv;
   gavl_video_format_copy(format, &vp->format);
   }
 
 static int read_video_colormatrix(void * priv, gavl_video_frame_t * frame, int stream)
   {
   colormatrix_priv_t * vp;
-  vp = (colormatrix_priv_t *)priv;
+  vp = priv;
 
   if(!vp->read_func(vp->read_data, frame, vp->read_stream))
     return 0;
