@@ -90,7 +90,7 @@ static void * create_deinterlace()
   ret->opt = gavl_video_deinterlacer_get_options(ret->deint);
   ret->yadif = bg_yadif_create();
   
-  ret->src_field_1 = gavl_video_frame_create((gavl_video_format_t*)0);
+  ret->src_field_1 = gavl_video_frame_create(NULL);
   ret->global_opt = gavl_video_options_create();
   return ret;
   }
@@ -98,7 +98,7 @@ static void * create_deinterlace()
 static void destroy_deinterlace(void * priv)
   {
   deinterlace_priv_t * vp;
-  vp = (deinterlace_priv_t *)priv;
+  vp = priv;
   if(vp->frame)
     gavl_video_frame_destroy(vp->frame);
 
@@ -120,7 +120,7 @@ static gavl_video_options_t * get_options_deinterlace(void * priv)
 static void reset_deinterlace(void * priv)
   {
   deinterlace_priv_t * vp;
-  vp = (deinterlace_priv_t *)priv;
+  vp = priv;
   bg_yadif_reset(vp->yadif);
   }
 
@@ -141,7 +141,7 @@ static const bg_parameter_info_t parameters[] =
                                "blend",
                                "yadif",
                                "yadif_fast",
-                               (char*)0 },
+                               NULL },
       
       .multi_labels = (char const *[]){ TRS("None"),
                                TRS("Scanline doubler"),
@@ -150,7 +150,7 @@ static const bg_parameter_info_t parameters[] =
                                TRS("Blend"),
                                TRS("Yadif"),
                                TRS("Yadif (fast)"),
-                               (char*)0 },
+                               NULL },
       .multi_descriptions = (char const *[]){ TRS("Do nothing"),
                                      TRS("Simply double all scanlines. Very fast but \
 low image quality"), 
@@ -158,7 +158,7 @@ low image quality"),
                                      TRS("Drop one field and scale the image to the original height"),
                                      TRS("yadif"),
                                      TRS("yadif (fast mode)"),
-                                     (char*)0 },
+                                     NULL },
     },
     {
       .name = "force",
@@ -174,13 +174,13 @@ low image quality"),
       .flags = BG_PARAMETER_SYNC,
       .val_default = { .val_str = "top" },
       .help_string = TRS("Specify which field to output. Outputting both fields is not always supported."),
-      .multi_names = (char const *[]){ "top", "bottom", "first", "second", "both", (char*)0 },
+      .multi_names = (char const *[]){ "top", "bottom", "first", "second", "both", NULL },
       .multi_labels = (char const *[]){ TRS("Top field"),
                                         TRS("Bottom field"),
                                         TRS("First field"),
                                         TRS("Second field"),
                                         TRS("Both fields"),
-                                        (char*)0 },
+                                        NULL },
     },
     BG_GAVL_PARAM_SCALE_MODE,
     { /* End of parameters */ },
@@ -200,7 +200,9 @@ static void set_parameter_deinterlace(void * priv, const char * name,
   int new_output_mode;
   
   deinterlace_priv_t * vp;
-  vp = (deinterlace_priv_t *)priv;
+  vp = priv;
+
+  new_output_mode = vp->output_mode;
   
   if(!name)
     return;
@@ -362,7 +364,7 @@ static void connect_input_port_deinterlace(void * priv,
                                            int port)
   {
   deinterlace_priv_t * vp;
-  vp = (deinterlace_priv_t *)priv;
+  vp = priv;
   
   if(!port)
     {
@@ -399,13 +401,13 @@ set_input_format_deinterlace(void * priv,
   {
   deinterlace_priv_t * vp;
   int yadif_mode;
-  vp = (deinterlace_priv_t *)priv;
+  vp = priv;
   if(!port)
     {
     if(vp->frame)
       {
       gavl_video_frame_destroy(vp->frame);
-      vp->frame = (gavl_video_frame_t*)0;
+      vp->frame = NULL;
       }
     transfer_global_options(vp->opt, vp->global_opt);
     
@@ -459,21 +461,21 @@ set_input_format_deinterlace(void * priv,
   if(vp->frame)
     {
     gavl_video_frame_destroy(vp->frame);
-    vp->frame = (gavl_video_frame_t*)0;
+    vp->frame = NULL;
     }
   }
 
 static int need_restart_deinterlace(void * priv)
   {
   deinterlace_priv_t * vp;
-  vp = (deinterlace_priv_t *)priv;
+  vp = priv;
   return vp->need_restart;
   }
 
 static void get_output_format_deinterlace(void * priv, gavl_video_format_t * format)
   {
   deinterlace_priv_t * vp;
-  vp = (deinterlace_priv_t *)priv;
+  vp = priv;
   
   gavl_video_format_copy(format, &vp->out_format);
   }
@@ -481,7 +483,7 @@ static void get_output_format_deinterlace(void * priv, gavl_video_format_t * for
 static int read_video_deinterlace(void * priv, gavl_video_frame_t * frame, int stream)
   {
   deinterlace_priv_t * vp;
-  vp = (deinterlace_priv_t *)priv;
+  vp = priv;
 
   if(vp->need_reinit)
     {
