@@ -66,7 +66,7 @@ static void * create_tcdisplay()
 static void destroy_tcdisplay(void * priv)
   {
   tc_priv_t * vp;
-  vp = (tc_priv_t *)priv;
+  vp = priv;
   bg_text_renderer_destroy(vp->renderer);
   gavl_overlay_blend_context_destroy(vp->blender);
   free(vp);
@@ -128,8 +128,8 @@ static const bg_parameter_info_t parameters[] =
       .long_name =  TRS("Horizontal justify"),
       .type =       BG_PARAMETER_STRINGLIST,
       .val_default = { .val_str = "right" },
-      .multi_names =  (char const *[]){ "center", "left", "right", (char*)0 },
-      .multi_labels = (char const *[]){ TRS("Center"), TRS("Left"), TRS("Right"), (char*)0  },
+      .multi_names =  (char const *[]){ "center", "left", "right", NULL },
+      .multi_labels = (char const *[]){ TRS("Center"), TRS("Left"), TRS("Right"), NULL  },
             
     },
     {
@@ -137,8 +137,8 @@ static const bg_parameter_info_t parameters[] =
       .long_name =  TRS("Vertical justify"),
       .type =       BG_PARAMETER_STRINGLIST,
       .val_default = { .val_str = "top" },
-      .multi_names =  (char const *[]){ "center", "top", "bottom", (char*)0  },
-      .multi_labels = (char const *[]){ TRS("Center"), TRS("Top"), TRS("Bottom"), (char*)0 },
+      .multi_names =  (char const *[]){ "center", "top", "bottom", NULL  },
+      .multi_labels = (char const *[]){ TRS("Center"), TRS("Top"), TRS("Bottom"), NULL },
     },
     {
       .name =        "cache_size",
@@ -194,42 +194,6 @@ static const bg_parameter_info_t parameters[] =
       .flags = BG_PARAMETER_HIDE_DIALOG,
       .help_string = TRS("Ignore linebreaks")
     },
-    {
-      .name =       "default_width",
-      .long_name =  TRS("Default width"),
-      .type =       BG_PARAMETER_INT,
-      .flags = BG_PARAMETER_HIDE_DIALOG,
-      .val_min =     { .val_i = 0     },
-      .val_max =     { .val_i = 65535 },
-      .val_default = { .val_i = 640   },
-    },
-    {
-      .name =       "default_height",
-      .long_name =  TRS("Default height"),
-      .type =       BG_PARAMETER_INT,
-      .flags = BG_PARAMETER_HIDE_DIALOG,
-      .val_min =     { .val_i = 0     },
-      .val_max =     { .val_i = 65535 },
-      .val_default = { .val_i = 480   },
-    },
-    {
-      .name =       "default_csp",
-      .long_name =  TRS("Default Colorspace"),
-      .type =       BG_PARAMETER_STRINGLIST,
-      .flags = BG_PARAMETER_HIDE_DIALOG,
-      .val_default =  { .val_str = "yuv" },
-      .multi_names =  (char const *[]){ "yuv", "rgb", (char*)0 },
-      .multi_labels = (char const *[]){ TRS("YCrCb"), TRS("RGB"), (char*)0 },
-    },
-    {
-      .name =       "default_framerate",
-      .long_name =  TRS("Default Framerate"),
-      .flags = BG_PARAMETER_HIDE_DIALOG,
-      .type =       BG_PARAMETER_FLOAT,
-      .val_default =  { .val_f = 10.0 },
-      .num_digits = 3,
-    },
-    
     { /* End of parameters */ },
   };
 
@@ -243,7 +207,7 @@ set_parameter_tcdisplay(void * priv, const char * name,
                       const bg_parameter_value_t * val)
   {
   tc_priv_t * vp;
-  vp = (tc_priv_t *)priv;
+  vp = priv;
 
   if(!name)
     {
@@ -265,7 +229,7 @@ static void connect_input_port_tcdisplay(void * priv,
                                     void * data, int stream, int port)
   {
   tc_priv_t * vp;
-  vp = (tc_priv_t *)priv;
+  vp = priv;
 
   if(!port)
     {
@@ -280,7 +244,7 @@ static void set_input_format_tcdisplay(void * priv,
                                        gavl_video_format_t * format, int port)
   {
   tc_priv_t * vp;
-  vp = (tc_priv_t *)priv;
+  vp = priv;
   
   if(port)
     return;
@@ -308,7 +272,7 @@ static void get_output_format_tcdisplay(void * priv,
                                  gavl_video_format_t * format)
   {
   tc_priv_t * vp;
-  vp = (tc_priv_t *)priv;
+  vp = priv;
   
   gavl_video_format_copy(format, &vp->format);
   }
@@ -319,7 +283,7 @@ static int read_video_tcdisplay(void * priv, gavl_video_frame_t * frame,
   tc_priv_t * vp;
   char str[GAVL_TIMECODE_STRING_LEN];
   char * pos;
-  vp = (tc_priv_t *)priv;
+  vp = priv;
   
   if(!vp->read_func(vp->read_data, frame, vp->read_stream))
     return 0;
@@ -370,7 +334,7 @@ static int read_video_tcdisplay(void * priv, gavl_video_frame_t * frame,
 static void reset_tcdisplay(void * priv)
   {
   tc_priv_t * vp;
-  vp = (tc_priv_t *)priv;
+  vp = priv;
   vp->last_timecode = GAVL_TIMECODE_UNDEFINED;
   }
 
