@@ -38,6 +38,8 @@
 #include <gmerlin/log.h>
 #define LOG_DOMAIN "e_wav"
 
+#include <gavl/metatags.h>
+
 /* Speaker configurations for WAVEFORMATEXTENSIBLE */
 
 #define SPEAKER_FRONT_LEFT 	        0x1
@@ -70,7 +72,7 @@ typedef struct wav_s
   gavl_audio_format_t format;
 
   int write_info_chunk;
-  bg_metadata_t metadata;
+  gavl_metadata_t metadata;
   char * filename;
   uint32_t channel_mask;
 
@@ -222,7 +224,7 @@ typedef struct
 
 #define BUFFER_SIZE 256
 
-static int write_info_chunk(FILE * output, bg_metadata_t * m)
+static int write_info_chunk(FILE * output, gavl_metadata_t * m)
   {
   int len;
   int total_len;
@@ -242,11 +244,11 @@ static int write_info_chunk(FILE * output, bg_metadata_t * m)
   strftime(date_string, BUFFER_SIZE, "%Y-%m-%d", &time_date);
   sprintf(software_string, "%s-%s", PACKAGE, VERSION);
 
-  info.IART = m->artist;
-  info.INAM = m->title;
-  info.ICMT = m->comment;
-  info.ICOP = m->copyright;
-  info.IGNR = m->genre;
+  info.IART = gavl_metadata_get(m, GAVL_META_ARTIST);
+  info.INAM = gavl_metadata_get(m, GAVL_META_TITLE);
+  info.ICMT = gavl_metadata_get(m, GAVL_META_COMMENT);
+  info.ICOP = gavl_metadata_get(m, GAVL_META_COPYRIGHT);
+  info.IGNR = gavl_metadata_get(m, GAVL_META_GENRE);
   info.ICRD = date_string;
   info.ISFT = software_string;
 
@@ -298,7 +300,7 @@ static void set_callbacks_wav(void * data, bg_encoder_callbacks_t * cb)
 static void destroy_wav(void * priv)
   {
   wav_t * wav;
-  wav = (wav_t*)priv;
+  wav = priv;
 
   if(wav->output)
     fclose(wav->output);
@@ -315,7 +317,7 @@ static const bg_parameter_info_t audio_parameters[] =
       .long_name =   TRS("Bits per sample"),
       .type =        BG_PARAMETER_STRINGLIST,
       .val_default = { .val_str = "16" },
-      .multi_names =     (char const *[]){ "8", "16", "24", "32", (char*)0 },
+      .multi_names =     (char const *[]){ "8", "16", "24", "32", NULL },
     },
     { /* End of parameters */ }
   };
@@ -423,7 +425,7 @@ static void set_audio_parameter_wav(void * data, int stream,
                                     const bg_parameter_value_t * v)
   {
   wav_t * wav;
-  wav = (wav_t*)data;
+  wav = data;
   
   if(stream)
     return;
@@ -442,7 +444,7 @@ static void set_parameter_wav(void * data, const char * name,
                               const bg_parameter_value_t * v)
   {
   wav_t * wav;
-  wav = (wav_t*)data;
+  wav = data;
   
   if(!name)
     return;
@@ -451,12 +453,12 @@ static void set_parameter_wav(void * data, const char * name,
   }
 
 static int open_wav(void * data, const char * filename,
-                    const bg_metadata_t * metadata,
+                    const gavl_metadata_t * metadata,
                     const bg_chapter_list_t * chapter_list)
   {
   int result;
   wav_t * wav;
-  wav = (wav_t*)data;
+  wav = data;
   
   wav->filename = bg_filename_ensure_extension(filename, "wav");
 
@@ -475,18 +477,19 @@ static int open_wav(void * data, const char * filename,
     result = 1;
 
   if(metadata)
-    bg_metadata_copy(&wav->metadata, metadata);
+    gavl_metadata_copy(&wav->metadata, metadata);
   
   return result;
   }
 
 
-static int add_audio_stream_wav(void * data, const char * language,
+static int add_audio_stream_wav(void * data,
+                                const gavl_metadata_t * m,
                                 const gavl_audio_format_t * format)
   {
   wav_t * wav;
   
-  wav = (wav_t*)data;
+  wav = data;
 
   gavl_audio_format_copy(&wav->format, format);
 
@@ -501,7 +504,7 @@ static int write_audio_frame_wav(void * data, gavl_audio_frame_t * frame,
   int num_samples, num_bytes;
   wav_t * wav;
   
-  wav = (wav_t*)data;
+  wav = data;
   
   num_samples = frame->valid_samples * wav->format.num_channels;
   num_bytes = num_samples * wav->bytes_per_sample;
@@ -529,14 +532,14 @@ static void get_audio_format_wav(void * data, int stream,
                                  gavl_audio_format_t * ret)
   {
   wav_t * wav;
-  wav = (wav_t*)data;
+  wav = data;
   gavl_audio_format_copy(ret, &wav->format);
   }
 
 static int start_wav(void * data)
   {
   wav_t * wav;
-  wav = (wav_t*)data;
+  wav = data;
 
   /* Write the header and adjust format */
 
@@ -599,7 +602,7 @@ static int close_wav(void * data, int do_delete)
   int ret = 1;
   wav_t * wav;
   int64_t total_bytes;
-  wav = (wav_t*)data;
+  wav = data;
 
   if(!do_delete)
     {
@@ -625,7 +628,7 @@ static int close_wav(void * data, int do_delete)
   if(do_delete)
     remove(wav->filename);
 
-  bg_metadata_free(&wav->metadata);
+  gavl_metadata_free(&wav->metadata);
   
   wav->output = NULL;
   return ret;
